@@ -3,3 +3,6 @@
 #include <util/keyval/LIBS.h>
 #include <math/isosurf/LIBS.h>
 #include <chemistry/molecule/LIBS.h>
+#ifdef HAVE_CHEMISTRY_CCA
+  #include <util/misc/LIBS.h>
+#endif
