@@ -25,7 +25,7 @@
 // The U.S. Government is granted a limited license as per AL 91-7.
 //
 
-#include <math.h>
+#include <util/misc/math.h>
 
 #include <util/misc/formio.h>
 #include <chemistry/molecule/molecule.h>
