@@ -528,6 +528,7 @@ main(int, char *argv[])
   
   Ref<Integral> intgrl = new IntegralV3;
 
+  int doconcat = keyval->booleanvalue("concat");
   int dooverlap = keyval->booleanvalue("overlap");
   int doeigvals = keyval->booleanvalue("eigvals");
   int dostate = keyval->booleanvalue("state");
@@ -539,6 +540,18 @@ main(int, char *argv[])
   int doextent = keyval->booleanvalue("extent");
   int doaoorthog = keyval->booleanvalue("aoorthog");
 
+  if (doconcat) {
+      Ref<GaussianBasisSet> b1, b2;
+      b1 << keyval->describedclassvalue("concat1");
+      b2 << keyval->describedclassvalue("concat2");
+      Ref<GaussianBasisSet> b12 = b1->operator+(b2);
+      Ref<GaussianBasisSet> b121 = b12->operator+(b1);
+      b1->print();
+      b2->print();
+      b12->print();
+      b121->print();
+    }
+
   for (i=0; i<keyval->count("test"); i++) {
       Ref<GaussianBasisSet> gbs;
       gbs << keyval->describedclassvalue("test", i);
@@ -588,11 +601,11 @@ main(int, char *argv[])
 
       // Make H, C, and P molecules
       Ref<Molecule> hmol = new Molecule();
-      hmol->add_atom(AtomInfo::string_to_Z("H"),0,0,0);
+      hmol->add_atom(hmol->atominfo()->string_to_Z("H"),0,0,0);
       Ref<Molecule> cmol = new Molecule();
-      cmol->add_atom(AtomInfo::string_to_Z("C"),0,0,0);
+      cmol->add_atom(cmol->atominfo()->string_to_Z("C"),0,0,0);
       Ref<Molecule> pmol = new Molecule();
-      pmol->add_atom(AtomInfo::string_to_Z("P"),0,0,0);
+      pmol->add_atom(pmol->atominfo()->string_to_Z("P"),0,0,0);
 
       perlout << "%basissets = (" << endl;
       int nbasis = keyval->count("basislist");
@@ -614,7 +627,7 @@ main(int, char *argv[])
               Ref<KeyVal> atombaskv(atombaskv_a);
               char keyword[256];
               strcpy(keyword,":basis:");
-              strcat(keyword,AtomInfo::name(j+1));
+              strcat(keyword,hmol->atominfo()->name(j+1).c_str());
               strcat(keyword,":");
               strcat(keyword,basisname);
               if (basiskv->exists(keyword)) {
@@ -624,10 +637,13 @@ main(int, char *argv[])
                   else {
                       first_element = 0;
                     }
-                  perlout << "\"" << AtomInfo::symbol(j+1) << "\"";
+                  // This will print the symbol:
+                  //perlout << "\"" << AtomInfo::symbol(j+1) << "\"";
+                  // This will print the atomic number:
+                  perlout << j+1;
                   if (!last_elem_exists) {
                       if (elemstr[0] != '\0') strcat(elemstr,", ");
-                      strcat(elemstr,AtomInfo::symbol(j+1));
+                      strcat(elemstr,hmol->atominfo()->symbol(j+1).c_str());
                     }
                   else if (last_elem_exists == 2) {
                       strcat(elemstr,"-");
@@ -655,7 +671,7 @@ main(int, char *argv[])
               else {
                   if (last_elem_exists > 1) {
                       if (last_elem_exists == 2) strcat(elemstr,", ");
-                      strcat(elemstr, AtomInfo::symbol(j));
+                      strcat(elemstr, hmol->atominfo()->symbol(j).c_str());
                     }
                   last_elem_exists = 0;
                 }
