@@ -30,6 +30,8 @@
 
 #include <util/keyval/keyval.h>
 
+namespace sc {
+
 class BasisFileSet {
   private:
     char *dir_[2];
@@ -41,6 +43,8 @@ class BasisFileSet {
     Ref<KeyVal> keyval(const Ref<KeyVal>&, const char *name);
 };
 
+}
+
 #endif
 
 // Local Variables:
