@@ -51,7 +51,12 @@ class CartesianIter;
 class SphericalTransformIter;
 
 /** The GaussianBasisSet class is used describe a basis set composed of
-atomic gaussian orbitals.
+atomic gaussian orbitals.  Inputs for common basis sets are included in the
+MPQC distribution.  They have been obtained from the EMSL Basis Set
+Database and translated into the MPQC format.  The citation for this
+database is below.  The technical citation for each basis set is listed in
+the individual basis set data files, in MPQC's <tt>lib/basis</tt>
+directory.
 
 Following is a table with available basis sets listing the supported
 elements for each basis and the number of basis functions for H, \f$n_0\f$,
@@ -63,10 +68,10 @@ non-alpha-numerical characters in their name must be given in quotes.
 <tr><td><tt>STO-2G</tt><td>H-Ca<td>1<td>5<td>9
 <tr><td><tt>STO-3G</tt><td>H-Kr<td>1<td>5<td>9
 <tr><td><tt>STO-3G*</tt><td>H-Ar<td>1<td>5<td>14
-<tr><td><tt>STO-6G</tt><td>H-Be, C-Kr<td>1<td>5<td>9
+<tr><td><tt>STO-6G</tt><td>H-Kr<td>1<td>5<td>9
 <tr><td><tt>MINI (Huzinaga)</tt><td>H-Ca<td>1<td>5<td>9
 <tr><td><tt>MINI (Scaled)</tt><td>H-Ca<td>1<td>5<td>9
-<tr><td><tt>MIDI (Huzinaga)</tt><td>H-Na<td>2<td>9<td>
+<tr><td><tt>MIDI (Huzinaga)</tt><td>H-Na, Al-K<td>2<td>9<td>13
 <tr><td><tt>DZ (Dunning)</tt><td>H, Li, B-Ne, Al-Cl<td>2<td>10<td>18
 <tr><td><tt>DZP (Dunning)</tt><td>H, Li, B-Ne, Al-Cl<td>5<td>16<td>24
 <tr><td><tt>DZP + Diffuse (Dunning)</tt><td>H, B-Ne<td>6<td>19<td>
@@ -75,46 +80,75 @@ non-alpha-numerical characters in their name must be given in quotes.
 <tr><td><tt>3-21++G</tt><td>H-Ar<td>3<td>13<td>17
 <tr><td><tt>3-21++G*</tt><td>H-Ar<td>3<td>13<td>23
 <tr><td><tt>4-31G</tt><td>H-Ne, P-Cl<td>2<td>9<td>13
-<tr><td><tt>4-31G*</tt><td>H-Ne, P-Cl<td>2<td>15<td>19
-<tr><td><tt>4-31G**</tt><td>H-Ne, P-Cl<td>5<td>15<td>19
-<tr><td><tt>6-31G</tt><td>H-Ar<td>2<td>9<td>13
-<tr><td><tt>6-31G*</tt><td>H-Ar<td>2<td>15<td>19
-<tr><td><tt>6-31G**</tt><td>H-Ar<td>5<td>15<td>19
+<tr><td><tt>6-31G</tt><td>H-Zn<td>2<td>9<td>13
+<tr><td><tt>6-31G*</tt><td>H-Zn<td>2<td>15<td>19
+<tr><td><tt>6-31G**</tt><td>H-Zn<td>5<td>15<td>19
 <tr><td><tt>6-31+G*</tt><td>H-Ar<td>2<td>19<td>23
-<tr><td><tt>6-31++G</tt><td>H-Ar<td>3<td>13<td>17
+<tr><td><tt>6-31++G</tt><td>H-Ca<td>3<td>13<td>17
 <tr><td><tt>6-31++G*</tt><td>H-Ar<td>3<td>19<td>23
 <tr><td><tt>6-31++G**</tt><td>H-Ar<td>6<td>19<td>23
-<tr><td><tt>6-311G</tt><td>H-Ar, Ga-Kr<td>3<td>13<td>21
-<tr><td><tt>6-311G*</tt><td>H-Ar, Ga-Kr<td>3<td>18<td>26
-<tr><td><tt>6-311G**</tt><td>H-Ar, Ga-Kr<td>6<td>18<td>26
-<tr><td><tt>6-311G(2df,2pd)</tt><td>H-Ne<td>14<td>30<td>
-<tr><td><tt>6-311++G**</tt><td>H-Ne<td>7<td>23<td>
-<tr><td><tt>6-311++G(2d,2p)</tt><td>H-Ne<td>10<td>29<td>
-<tr><td><tt>6-311++G(3df,3pd)</tt><td>H-Ar<td>19<td>42<td>50
-<tr><td><tt>cc-pVDZ</tt><td>H, He, B-Ne, Al-Ar, Ga-Kr<td>5<td>14<td>18
-<tr><td><tt>cc-pVTZ</tt><td>H, He, B-Ne, Al-Ar, Ga-Se<td>14<td>30<td>34
-<tr><td><tt>cc-pVQZ</tt><td>H, He, B-Ne, Al-Ar<td>30<td>55<td>59
-<tr><td><tt>cc-pV5Z</tt><td>H-Ne, Al-Ar<td>55<td>91<td>95
-<tr><td><tt>aug-cc-pVDZ</tt><td>H, He, B-Ne, Al-Ar<td>9<td>23<td>27
-<tr><td><tt>aug-cc-pVTZ</tt><td>H, He, B-Ne, Al-Ar<td>23<td>46<td>50
-<tr><td><tt>aug-cc-pVQZ</tt><td>H, He, B-Ne, Al-Ar<td>46<td>80<td>84
-<tr><td><tt>aug-cc-pV5Z</tt><td>H, He, B-Ne, Al-Ar<td>80<td>127<td>131
-<tr><td><tt>cc-pCVDZ</tt><td>B-Ne<td><td>18<td>
-<tr><td><tt>cc-pCVTZ</tt><td>B-Ne<td><td>43<td>
-<tr><td><tt>cc-pCVQZ</tt><td>B-Ne<td><td>84<td>
+<tr><td><tt>6-311G</tt><td>H-Ca, Ga-Kr<td>3<td>13<td>21
+<tr><td><tt>6-311G*</tt><td>H-Ca, Ga-Kr<td>3<td>18<td>26
+<tr><td><tt>6-311G**</tt><td>H-Ca, Ga-Kr<td>6<td>18<td>26
+<tr><td><tt>6-311G(2df,2pd)</tt><td>H-Ne, K, Ca<td>14<td>30<td>
+<tr><td><tt>6-311++G**</tt><td>H-Ne<td>7<td>22<td>
+<tr><td><tt>6-311++G(2d,2p)</tt><td>H-Ca<td>10<td>27<td>35
+<tr><td><tt>6-311++G(3df,3pd)</tt><td>H-Ar<td>18<td>39<td>47
+<tr><td><tt>cc-pVDZ</tt><td>H-Ar, Ca, Ga-Kr<td>5<td>14<td>18
+<tr><td><tt>cc-pVTZ</tt><td>H-Ar, Ca, Ga-Kr<td>14<td>30<td>34
+<tr><td><tt>cc-pVQZ</tt><td>H-Ar, Ca, Ga-Kr<td>30<td>55<td>59
+<tr><td><tt>cc-pV5Z</tt><td>H-Ar, Ca, Ga-Kr<td>55<td>91<td>95
+<tr><td><tt>cc-pV6Z</tt><td>H, He, B-Ne, Al-Ar<td>91<td>140<td>144
+<tr><td><tt>aug-cc-pVDZ</tt><td>H, He, B-Ne, Al-Ar, Ga-Kr<td>9<td>23<td>27
+<tr><td><tt>aug-cc-pVTZ</tt><td>H, He, B-Ne, Al-Ar, Ga-Kr<td>23<td>46<td>50
+<tr><td><tt>aug-cc-pVQZ</tt><td>H, He, B-Ne, Al-Ar, Ga-Kr<td>46<td>80<td>84
+<tr><td><tt>aug-cc-pV5Z</tt><td>H, He, B-Ne, Al-Ar, Ga-Kr<td>80<td>127<td>131
+<tr><td><tt>aug-cc-pV6Z</tt><td>H, He, B-Ne, Al-Ar<td>127<td>189<td>193
+<tr><td><tt>cc-pCVDZ</tt><td>Li, B-Ar<td><td>18<td>27
+<tr><td><tt>cc-pCVTZ</tt><td>Li, B-Ar<td><td>43<td>59
+<tr><td><tt>cc-pCVQZ</tt><td>Li, B-Ar<td><td>84<td>109
 <tr><td><tt>cc-pCV5Z</tt><td>B-Ne<td><td>145<td>
-<tr><td><tt>aug-cc-pCVDZ</tt><td>B-F<td><td>27<td>
-<tr><td><tt>aug-cc-pCVTZ</tt><td>B-Ne<td><td>59<td>
-<tr><td><tt>aug-cc-pCVQZ</tt><td>B-Ne<td><td>109<td>
+<tr><td><tt>aug-cc-pCVDZ</tt><td>B-F, Al-Ar<td><td>27<td>36
+<tr><td><tt>aug-cc-pCVTZ</tt><td>B-Ne, Al-Ar<td><td>59<td>75
+<tr><td><tt>aug-cc-pCVQZ</tt><td>B-Ne, Al-Ar<td><td>109<td>134
 <tr><td><tt>aug-cc-pCV5Z</tt><td>B-F<td><td>181<td>
 <tr><td><tt>NASA Ames ANO</tt><td>H, B-Ne, Al, P, Ti, Fe, Ni<td>30<td>55<td>59
+<tr><td><tt>pc-0</tt><td>H, C-F, Si-Cl<td>2<td>9<td>13
+<tr><td><tt>pc-1</tt><td>H, C-F, Si-Cl<td>5<td>14<td>18
+<tr><td><tt>pc-2</tt><td>H, C-F, Si-Cl<td>14<td>30<td>34
+<tr><td><tt>pc-3</tt><td>H, C-F, Si-Cl<td>34<td>64<td>64
+<tr><td><tt>pc-4</tt><td>H, C-F, Si-Cl<td>63<td>109<td>105
+<tr><td><tt>pc-0-aug</tt><td>H, C-F, Si-Cl<td>3<td>13<td>17
+<tr><td><tt>pc-1-aug</tt><td>H, C-F, Si-Cl<td>9<td>23<td>27
+<tr><td><tt>pc-2-aug</tt><td>H, C-F, Si-Cl<td>23<td>46<td>50
+<tr><td><tt>pc-3-aug</tt><td>H, C-F, Si-Cl<td>50<td>89<td>89
+<tr><td><tt>pc-4-aug</tt><td>H, C-F, Si-Cl<td>88<td>145<td>141
 </table>
 
+All basis sets except for the pc-<i>n</i> and pc-<i>n</i>-aug basis sets
+were obtained from the Extensible Computational Chemistry
+Environment Basis Set Database, Version 12/03/03, as developed and
+distributed by the Molecular Science Computing Facility, Environmental and
+Molecular Sciences Laboratory which is part of the Pacific Northwest
+Laboratory, P.O. Box 999, Richland, Washington 99352, USA, and funded by
+the U.S. Department of Energy. The Pacific Northwest Laboratory is a
+multi-program laboratory operated by Battelle Memorial Institute for the
+U.S. Department of Energy under contract DE-AC06-76RLO 1830. Contact David
+Feller or Karen Schuchardt for further information.
+
+The pc-<i>n</i> and pc-<i>n</i>-aug basis sets are the polarization
+consistent basis sets of Frank Jensen.  See J. Chem. Phys. 115 (2001) 9113;
+J. Chem. Phys. 116 (2002) 7372; J. Chem. Phys. 117 (2002) 9234; and
+J. Chem. Phys. 121 (2004) 3463.
+
 */
 class GaussianBasisSet: public SavableState
 {
   private:
+    // nonnull if keyword "name" was provided
     char* name_;
+    // same as name_ if name_!=0, else something else
+    char* label_;
     GaussianShell** shell_;
     std::vector<int> shell_to_function_;
     std::vector<int> function_to_shell_;
@@ -136,16 +170,37 @@ class GaussianBasisSet: public SavableState
     int nshell_;
     int nbasis_;
     int nprim_;
+    bool has_pure_;
 
+    GaussianBasisSet(const char* name, const char* label, const Ref<Molecule>& molecule,
+                     const Ref<SCMatrixKit>& matrixkit,
+                     const RefSCDimension& basisdim,
+                     const int ncenter, const int nshell,
+                     GaussianShell** shell,
+                     const std::vector<int>& center_to_nshell);
+
+    // Counts shells in this basis for this chemical element
+    int count_shells_(Ref<KeyVal>& keyval, const char* elemname, const char* sbasisname, BasisFileSet& bases,
+		      int havepure, int pure, bool missing_ok);
+    // Constructs this basis
+    void get_shells_(int& ishell, Ref<KeyVal>& keyval, const char* elemname, const char* sbasisname, BasisFileSet& bases,
+		     int havepure, int pure, bool missing_ok);
+    // Counts shells in an even-tempered primitive basis
+    int count_even_temp_shells_(Ref<KeyVal>& keyval, const char* elemname, const char* sbasisname,
+                                int havepure, int pure);
+    // Constructs an even-tempered primitive basis
+    void get_even_temp_shells_(int& ishell, Ref<KeyVal>& keyval, const char* elemname, const char* sbasisname,
+                               int havepure, int pure);
+    // Constructs basis set specified as an array of shells
     void recursively_get_shell(int&,Ref<KeyVal>&,
                                const char*,const char*,BasisFileSet&,
-                               int,int,int);
+                               int,int,int,bool missing_ok);
 
     void init(Ref<Molecule>&,Ref<KeyVal>&,
               BasisFileSet&,
               int have_userkeyval,
               int pure);
-    void init2(int skip_ghosts=0);
+    void init2(int skip_ghosts=0,bool include_q=0);
     
   protected:
     GaussianBasisSet(const GaussianBasisSet&);
@@ -165,6 +220,9 @@ class GaussianBasisSet: public SavableState
         SphericalTransformIter **sivec() { return sivec_; }
     };
 
+    /// This can be given to a CTOR to construct a unit basis function.
+    enum UnitType {Unit};
+
     /** The KeyVal constructor.
 
         <dl>
@@ -193,7 +251,7 @@ class GaussianBasisSet: public SavableState
 
         <dt><tt>basisdir</tt><dd> A string giving a directory where basis
         set data files are to be sought.  See the text below for a complete
-        description of what directors are consulted.
+        description of what directories are consulted.
 
         <dt><tt>basisfiles</tt><dd> Each keyword in this vector of files is
         appended to the directory specified with basisdir and basis set
@@ -222,10 +280,14 @@ class GaussianBasisSet: public SavableState
         necessary to copy the library files to your machine and set the
         SCLIBDIR environmental variable.
 
-        The basis set itself is also given in the ParsedKeyVal format.  It
-        is a vector of shells with the keyword :basis: followed by the
+        The basis set itself is also given in the ParsedKeyVal format. There are two
+        recognized formats for basis sets:
+        <dl>
+
+        <dt>array of shells<dd> One must specify the keyword :basis: followed by the
         lowercase atomic name followed by : followed by the basis set name
-        (which may need to be placed inside double quotes).  Each shell
+        (which may need to be placed inside double quotes). The value for the keyword
+        is an array of shells. Each shell
         reads the following keywords:
 
         <dl>
@@ -256,7 +318,7 @@ class GaussianBasisSet: public SavableState
 
         </dl>
 
-        An example might be easier to understand.  This is a basis set
+        <dt><dd>An example might be easier to understand.  This is a basis set
         specificition for STO-2G carbon:
 
         <pre>
@@ -274,15 +336,71 @@ class GaussianBasisSet: public SavableState
            })
          ]
         )
-        </pre> */
+        </pre>
+
+        <dt>basis set of even-tempered primitive Gaussians<dd>
+        Such basis set format is given as a group of keywords. The name of the group is :basis: followed by the
+        lowercase atomic name followed by : followed by the basis set name
+        (which may need to be placed inside double quotes).
+        The group of keywords must contain vectors <tt>am</tt> and <tt>nprim</tt>,
+        which specify the angular momentum and the number of shells in each
+        block of even-tempered primitives. In addition, one must provide any
+        two of the following vectors:
+
+        <dl>
+          <dt><tt>first_exp</tt><dd> The exponent of the "tightest" primitive Gaussian in the block.
+
+          <dt><tt>last_exp</tt><dd> The exponent of the most "diffuse" primitive Gaussian in the block.
+
+          <dt><tt>exp_ratio</tt><dd> The ratio of exponents of consecutive primitive Gaussians
+          in the block.
+
+        </dl>
+
+        <dt><dd>Note that the dimensions of each vector must be the same.
+
+        Here's an example of a basis set composed of 2 blocks of even-tempered s-functions
+        and 1 block of even-tempered p-functions.
+
+        <pre>
+        basis: (
+         neon: "20s5s13p":(
+
+           am = [ 0 0 1 ]
+           nprim = [ 20 5 13 ]
+           first_exp = [ 1000.0 0.1  70.0 ]
+           last_exp =  [    1.0 0.01  0.1 ]
+
+         )
+        )
+        </pre>
+
+        </dl>
+
+        */
     GaussianBasisSet(const Ref<KeyVal>&);
+    /** This can be given GaussianBasisSet::Unit to construct a basis
+        set with a single basis function that is one everywhere.  This
+        can be used with integral evaluators to compute certain classes
+        of integrals, with limitations. */
+    GaussianBasisSet(UnitType);
     GaussianBasisSet(StateIn&);
     virtual ~GaussianBasisSet();
 
+    /** Returns a GaussianBasisSet object that consists of the basis
+        functions for each atom in this followed by the basis functions in
+        B for the corresponding atom.  The Molecule object for the two
+        basis sets must be identical.  */
+    Ref<GaussianBasisSet> operator+(const Ref<GaussianBasisSet>& B);
+
     void save_data_state(StateOut&);
 
-    /// Return the name of the basis set.
+    /// Return the name of the basis set (is nonnull only if keyword "name" was provided)
     const char* name() const { return name_; }
+    /** Return the label of the basis set. label() return the same string as name() if
+        keyword "name" was provided, otherwise it is a unique descriptive string which
+        can be arbitrarily long. */
+    const char* label() const { if (name()) { return name(); } else { return label_; } }
 
     /// Return the Molecule object.
     Ref<Molecule> molecule() const { return molecule_; }
@@ -312,6 +430,8 @@ class GaussianBasisSet: public SavableState
     int nbasis_on_center(int icenter) const;
     /// Return the number of primitive Gaussians.
     int nprimitive() const { return nprim_; }
+    /// Return true if basis contains solid harmonics Gaussians
+    int has_pure() const { return has_pure_; }
 
     /// Return the maximum number of functions that any shell has.
     int max_nfunction_in_shell() const;
