@@ -33,6 +33,7 @@
 #include <math.h>
 
 #include <util/misc/formio.h>
+#include <util/misc/math.h>
 #include <util/keyval/keyval.h>
 #include <util/state/stateio.h>
 
@@ -53,7 +54,8 @@ static ClassDesc GaussianShell_cd(
 // this GaussianShell ctor allocates and computes normalization constants
 // and computes nfunc
 GaussianShell::GaussianShell(
-  int ncn,int nprm,double*e,int*am,int*pure,double**c,PrimitiveType pt
+  int ncn,int nprm,double*e,int*am,int*pure,double**c,PrimitiveType pt,
+  bool do_normalize_shell
   ):
 nprim(nprm),
 ncon(ncn),
@@ -70,7 +72,7 @@ coef(c)
   if (pt == Normalized) convert_coef();
 
   // Compute the normalization constants
-  normalize_shell();
+  if (do_normalize_shell) normalize_shell();
 }
 
 // this GaussianShell ctor is much like the above except the puream
@@ -317,7 +319,7 @@ void GaussianShell::convert_coef()
   for (gc=0; gc<ncon; gc++) {
       for (i=0; i<nprim; i++) {
 	  c = 0.25/exp[i];
-	  ss = pow(3.141592653589793/(exp[i]+exp[i]),1.5);
+	  ss = pow(M_PI/(exp[i]+exp[i]),1.5);
 	  coef[gc][i]
 	    *= 1.0/sqrt(::norm(l[gc],l[gc],c,ss));
 	}
@@ -327,7 +329,7 @@ void GaussianShell::convert_coef()
 double GaussianShell::coefficient_norm(int con,int prim) const
 {
   double c = 0.25/exp[prim];
-  double ss = pow(3.141592653589793/(exp[prim]+exp[prim]),1.5);
+  double ss = pow(M_PI/(exp[prim]+exp[prim]),1.5);
   return coef[con][prim] * sqrt(::norm(l[con],l[con],c,ss));
 }
 
@@ -347,7 +349,7 @@ GaussianShell::shell_normalization(int gc)
   for (i=0; i<nprim; i++) {
     for (j=0; j<nprim; j++) {
       c = 0.50/(exp[i] + exp[j]);
-      ss = pow(3.141592653589793/(exp[i]+exp[j]),1.5);
+      ss = pow(M_PI/(exp[i]+exp[j]),1.5);
       result += coef[gc][i] * coef[gc][j] *
                ::norm(l[gc],l[gc],c,ss);
       }
@@ -511,10 +513,15 @@ GaussianShell::equiv(const GaussianShell *s)
   for (int i=0; i<ncon; i++) {
       if (l[i] != s->l[i]) return 0;
       if (puream[i] != s->puream[i]) return 0;
-      if (exp[i] != s->exp[i]) return 0;
+      if (fabs((exp[i] - s->exp[i])/exp[i]) > 1.0e-13) return 0;
       for (int j=0; j<nprim; j++) {
-          if (coef[i][j] != s->coef[i][j]) return 0;
+        if (coef[i][j] != 0.0) { 
+          if (fabs((coef[i][j] - s->coef[i][j])/coef[i][j]) > 1.0e-13) return 0;
         }
+        else {
+          if (fabs((coef[i][j] - s->coef[i][j])) > 1.0e-13) return 0;
+        }
+      }
     }
   return 1;
 }
