@@ -37,6 +37,7 @@
 #include <chemistry/qc/basis/transform.h>
 
 using namespace std;
+using namespace sc;
 
 #define MAX_NPRIM 20
 #define MAX_NCON  10
@@ -75,7 +76,7 @@ GaussianShell::hessian_values(CartesianIter **civec,
 
   // check limitations
   if (nprim > MAX_NPRIM || ncon > MAX_NCON || maxam >= MAX_AM) {
-      ExEnv::err() << node0 << indent
+      ExEnv::err0() << indent
            << "GaussianShell::grad_values: limit exceeded:\n"
            << indent
            << scprintf(
@@ -416,7 +417,7 @@ GaussianShell::test_monobound(double &r, double &bound) const
 
   // check limitations
   if (nprim > MAX_NPRIM || ncon > MAX_NCON || maxam >= MAX_AM) {
-      ExEnv::err() << node0 << indent
+      ExEnv::err0() << indent
            << "GaussianShell::gaussshval: limit exceeded:\n"
            << indent
            << scprintf(
@@ -481,7 +482,7 @@ GaussianShell::test_monobound(double &r, double &bound) const
               double rold = r;
               r = sqrt(l[i]*precon[i]/(2.0*precon_w[i]));
               if (r<rold+0.01) r = rold+0.01;
-              //ExEnv::out() << "rejected at " << rold << " trying again at "
+              //ExEnv::outn() << "rejected at " << rold << " trying again at "
               //     << r << endl;
               return 1;
             }
