@@ -44,6 +44,10 @@ using namespace sc;
 
 ///////////////////////////////////////////////////////////////////////
 
+EfieldDotVectorData::~EfieldDotVectorData()
+{
+}
+
 void
 EfieldDotVectorData::set_position(double*p)
 {
@@ -62,6 +66,10 @@ EfieldDotVectorData::set_vector(double*v)
 
 ///////////////////////////////////////////////////////////////////////
 
+DipoleData::~DipoleData()
+{
+}
+
 void
 DipoleData::set_origin(double*o)
 {
@@ -202,6 +210,97 @@ OneBodyInt::clone()
   throw std::runtime_error("OneBodyInt::clone() not implemented");
 }
 
+///////////////////////////////////////////////////////////////////////
+
+OneBodyOneCenterInt::OneBodyOneCenterInt(Integral* integral,
+                                         const Ref<GaussianBasisSet>&bs1) :
+  integral_(integral),
+  bs1_(bs1)
+{
+  buffer_ = 0;
+}
+
+OneBodyOneCenterInt::~OneBodyOneCenterInt()
+{
+}
+
+int
+OneBodyOneCenterInt::nbasis() const
+{
+  return bs1_->nbasis();
+}
+
+int
+OneBodyOneCenterInt::nbasis1() const
+{
+  return bs1_->nbasis();
+}
+
+int
+OneBodyOneCenterInt::nshell() const
+{
+  return bs1_->nshell();
+}
+
+int
+OneBodyOneCenterInt::nshell1() const
+{
+  return bs1_->nshell();
+}
+
+Ref<GaussianBasisSet>
+OneBodyOneCenterInt::basis()
+{
+  return bs1_;
+}
+
+Ref<GaussianBasisSet>
+OneBodyOneCenterInt::basis1()
+{
+  return bs1_;
+}
+
+const double *
+OneBodyOneCenterInt::buffer() const
+{
+  return buffer_;
+}
+
+void
+OneBodyOneCenterInt::reinitialize()
+{
+}
+
+bool
+OneBodyOneCenterInt::cloneable()
+{
+  return false;
+}
+
+Ref<OneBodyOneCenterInt>
+OneBodyOneCenterInt::clone()
+{
+  throw std::runtime_error("OneBodyOneCenterInt::clone() not implemented");
+}
+
+///////////////////////////////////////////////////////////////////////
+
+OneBodyOneCenterWrapper::OneBodyOneCenterWrapper(const Ref<OneBodyInt>& ob,
+                                                 int jsh):
+  OneBodyOneCenterInt(ob->integral(),ob->basis1()),
+  ob_(ob),
+  jsh_(jsh)
+{
+  buffer_ = const_cast<double*>(ob_->buffer());
+}
+
+void
+OneBodyOneCenterWrapper::compute_shell(int ish)
+{
+  ob_->compute_shell(ish,jsh_);
+}
+
+
 ///////////////////////////////////////////////////////////////////////
 
 ShellPairIter::ShellPairIter()
@@ -759,6 +858,70 @@ OneBodyDerivInt::buffer() const
   return buffer_;
 }
 
+///////////////////////////////////////////////////////////////////////
+
+OneBodyOneCenterDerivInt::OneBodyOneCenterDerivInt(Integral *integral,
+                                 const Ref<GaussianBasisSet>&b) :
+  integral_(integral),
+  bs1(b)
+{
+  // allocate a buffer
+  int biggest_shell = b->max_nfunction_in_shell();
+  biggest_shell *= biggest_shell * 3;
+
+  if (biggest_shell) {
+    buffer_ = new double[biggest_shell];
+  } else {
+    buffer_ = 0;
+  }
+}
+
+OneBodyOneCenterDerivInt::~OneBodyOneCenterDerivInt()
+{
+}
+
+int
+OneBodyOneCenterDerivInt::nbasis() const
+{
+  return bs1->nbasis();
+}
+
+int
+OneBodyOneCenterDerivInt::nbasis1() const
+{
+  return bs1->nbasis();
+}
+
+int
+OneBodyOneCenterDerivInt::nshell() const
+{
+  return bs1->nshell();
+}
+
+int
+OneBodyOneCenterDerivInt::nshell1() const
+{
+  return bs1->nshell();
+}
+
+Ref<GaussianBasisSet>
+OneBodyOneCenterDerivInt::basis()
+{
+  return bs1;
+}
+
+Ref<GaussianBasisSet>
+OneBodyOneCenterDerivInt::basis1()
+{
+  return bs1;
+}
+
+const double *
+OneBodyOneCenterDerivInt::buffer() const
+{
+  return buffer_;
+}
+
 /////////////////////////////////////////////////////////////////////////////
 
 // Local Variables:
