@@ -49,6 +49,9 @@ class Integral;
 class EfieldDotVectorData: public RefCount
 {
   public:
+    EfieldDotVectorData() {};
+    ~EfieldDotVectorData();
+
     double position[3];
     double vector[3];
 
@@ -64,6 +67,7 @@ class DipoleData: public RefCount
 
     DipoleData(double *d) {origin[0]=d[0]; origin[1]=d[1]; origin[2]=d[2];}
     DipoleData() {origin[0]=origin[1]=origin[2]=0.0;}
+    ~DipoleData();
     void set_origin(double*);
 };
 
@@ -113,29 +117,26 @@ class OneBodyInt : public RefCount {
     /// Returns the number of basis functions on center one.
     int nbasis() const;
 
-    /// Returns the number of basis functions on the given center.
-    //@{
+    /// Returns the number of basis functions on the center one.
     int nbasis1() const;
+    /// Returns the number of basis functions on the center two.
     int nbasis2() const;
-    //@}
 
     /// Return the number of shells on center one.
     int nshell() const;
 
-    /// Return the number of shells on the given center.
-    //@{
+    /// Return the number of shells on the center one.
     int nshell1() const;
+    /// Return the number of shells on the center two.
     int nshell2() const;
-    //@}
 
     /// Return the basis set on center one.
     Ref<GaussianBasisSet> basis();
 
-    /// Return the basis set on the given center.
-    //@{
+    /// Return the basis set on the center one.
     Ref<GaussianBasisSet> basis1();
+    /// Return the basis set on the center two.
     Ref<GaussianBasisSet> basis2();
-    //@}
 
     /// Returns the buffer where the integrals are placed.
     const double * buffer() const;
@@ -159,7 +160,75 @@ class OneBodyInt : public RefCount {
     Integral *integral() const { return integral_; }
 };
 
+// //////////////////////////////////////////////////////////////////////////
 
+/** OneBodyOneCenterInt is an abstract base class for objects that
+    compute integrals between two basis functions. */
+class OneBodyOneCenterInt : public RefCount {
+  protected:
+    // this is who created me
+    Integral *integral_;
+
+    Ref<GaussianBasisSet> bs1_;
+
+    double *buffer_;
+
+    OneBodyOneCenterInt(Integral *integral,
+               const Ref<GaussianBasisSet>&b1);
+
+  public:
+    virtual ~OneBodyOneCenterInt();
+  
+    /// Returns the number of basis functions on center one.
+    int nbasis() const;
+
+    /// Returns the number of basis functions on the center one.
+    int nbasis1() const;
+
+    /// Return the number of shells on center one.
+    int nshell() const;
+
+    /// Return the number of shells on the center one.
+    int nshell1() const;
+
+    /// Return the basis set on center one.
+    Ref<GaussianBasisSet> basis();
+
+    /// Return the basis set on the center one.
+    Ref<GaussianBasisSet> basis1();
+
+    /// Returns the buffer where the integrals are placed.
+    const double * buffer() const;
+    
+    /** Computes the integrals for basis functions on the
+        given shell. */
+    virtual void compute_shell(int) = 0;
+
+    /** This is called for one body integrals that take data to let
+        them know that the data they reference has changed. */
+    virtual void reinitialize();
+
+    /** Return true if the clone member can be called.  The default
+     * implementation returns false. */
+    virtual bool cloneable();
+
+    /** Returns a clone of this.  The default implementation throws an
+     * exception. */
+    virtual Ref<OneBodyOneCenterInt> clone();
+
+    Integral *integral() const { return integral_; }
+};
+
+// //////////////////////////////////////////////////////////////////////////
+
+class OneBodyOneCenterWrapper : public OneBodyOneCenterInt {
+    Ref<OneBodyInt> ob_;
+    int jsh_;
+  public:
+    OneBodyOneCenterWrapper(const Ref<OneBodyInt>& ob,
+                            int sh2 = 0);
+    void compute_shell(int);
+};
 
 // //////////////////////////////////////////////////////////////////////////
 
@@ -316,7 +385,7 @@ class OneBody3IntOp: public SCElementOp3 {
 
 // //////////////////////////////////////////////////////////////////////////
 
-/** OneBodyInt is an abstract base class for objects that
+/** OneBodyDerivInt is an abstract base class for objects that
     compute one body derivative integrals. */
 class OneBodyDerivInt : public RefCount {
   protected:
@@ -337,38 +406,79 @@ class OneBodyDerivInt : public RefCount {
   
     /// Return the number of basis functions on center one.
     int nbasis() const;
-    /// Return the number of basis functions on the given center.
-    //@{
+    /// Return the number of basis functions on the center one.
     int nbasis1() const;
+    /// Return the number of basis functions on the center two.
     int nbasis2() const;
-    //@}
 
     /// Return the number of shells on center one.
     int nshell() const;
-    /// Return the number of shells on the given center.
-    //@{
+    /// Return the number of shells on center one.
     int nshell1() const;
+    /// Return the number of shells on center two.
     int nshell2() const;
-    //@}
 
     /// Return the basis set on center one.
     Ref<GaussianBasisSet> basis();
-    /// Return the basis set on the given center.
-    //@{
+    /// Return the basis set on center one.
     Ref<GaussianBasisSet> basis1();
+    /// Return the basis set on center two.
     Ref<GaussianBasisSet> basis2();
-    //@}
 
     /** The computed shell integrals will be put in the buffer returned by
         this member.  */
     const double * buffer() const;
     
-    /** Given for shell indices, these will cause the integral buffer
-        to be filled in. */
-    //@{
+    /** Compute the derivative integrals and place the result in the buffer
+        returned by buffer(). */
     virtual void compute_shell(int ish, int jsh, DerivCenters&) = 0;
+    /** Compute the derivative integrals with respect to the given center
+        and place the result in the buffer returned by buffer(). */
     virtual void compute_shell(int ish, int jsh, int center) = 0;
-    //@}
+};
+
+// //////////////////////////////////////////////////////////////////////////
+
+/** OneBodyOneCenterDerivInt is an abstract base class for objects that
+    compute one body derivative integrals on a single center. */
+class OneBodyOneCenterDerivInt : public RefCount {
+  protected:
+    // this is who created me
+    Integral *integral_;
+
+    Ref<GaussianBasisSet> bs1;
+
+    double *buffer_;
+
+  public:
+    OneBodyOneCenterDerivInt(Integral *, const Ref<GaussianBasisSet>&b);
+    virtual ~OneBodyOneCenterDerivInt();
+  
+    /// Return the number of basis functions on center one.
+    int nbasis() const;
+    /// Return the number of basis functions on center one.
+    int nbasis1() const;
+
+    /// Return the number of shells on center one.
+    int nshell() const;
+    /// Return the number of shells on center one.
+    int nshell1() const;
+
+    /// Return the basis set on center one.
+    Ref<GaussianBasisSet> basis();
+    /// Return the basis set on center one.
+    Ref<GaussianBasisSet> basis1();
+
+    /** The computed shell integrals will be put in the buffer returned by
+        this member.  */
+    const double * buffer() const;
+    
+    /** Compute the derivative integrals and place the result in the buffer
+        returned by buffer(). */
+    virtual void compute_shell(int ish, DerivCenters&) = 0;
+    /** Compute the derivative integrals with respect to the given center
+        and place the result in the buffer returned by buffer(). */
+    virtual void compute_shell(int ish, int center) = 0;
 };
 
 }
