@@ -28,8 +28,6 @@
 #ifndef _chemistry_qc_cints_linkage_h
 #define _chemistry_qc_cints_linkage_h
 
-#ifndef __PIC__
-
 #include <util/class/class.h>
 #include <chemistry/qc/cints/cints.h>
 
@@ -39,6 +37,4 @@ static ForceLink<IntegralCints> cints_force_link_a_;
 
 }
 
-#endif /* __PIC__ */
-
 #endif
