@@ -61,6 +61,41 @@ template Ref<AngularIntegrator>***
 //#define CHECK_ALIGN(v) if(int(&v)&7)ExEnv::outn()<<"Bad Alignment: "<< ## v <<endl;
 #define CHECK_ALIGN(v)
 
+///////////////////////////////////////////////////////////////////////////
+// utility functions
+
+inline static double
+norm(double v[3])
+{
+  double x,y,z;
+  return sqrt((x=v[0])*x + (y=v[1])*y + (z=v[2])*z);
+}
+
+static double
+get_radius(const Ref<Molecule> &mol, int iatom)
+{
+  double r = mol->atominfo()->maxprob_radius(mol->Z(iatom));
+  if (r == 0) {
+      static bool warned = false;
+      if (!warned) {
+          ExEnv::out0()
+              << indent << "WARNING: BeckeIntegrationWeight usually uses the atomic maximum" << std::endl
+              << indent << "         probability radius, however this is not available for" << std::endl
+              << indent << "         one of the atoms in your system. The Bragg radius will" << std::endl
+              << indent << "         be used instead." << std::endl;
+          warned = true;
+        }
+      r = mol->atominfo()->bragg_radius(mol->Z(iatom));
+    }
+  if (r == 0) {
+      ExEnv::out0()
+          << indent << "ERROR: BeckeIntegrationWeight could not find a maximum probability" << std::endl
+          << indent << "       or a Bragg radius for an atom" << std::endl;
+      abort();
+    }
+  return r;
+}
+
 ///////////////////////////////////////////////////////////////////////////
 // DenIntegratorThread
 
@@ -70,58 +105,44 @@ class DenIntegratorThread: public Thread {
   protected:
     // data common to all threads
     int nthread_;
-    double *alpha_dmat_;
-    double *beta_dmat_;
-    double *dmat_bound_;
     int nshell_;
     int nbasis_;
     int natom_;
+    int n_integration_center_;
     DenIntegrator *integrator_;
     int spin_polarized_;
     int need_hessian_;
     int need_gradient_;
     GaussianBasisSet *basis_;
-    int linear_scaling_;
-    int use_dmat_bound_;
+    bool linear_scaling_;
+    bool use_dmat_bound_;
     double value_;
     DenFunctional *func_;
 
-    // not yet initialized
-    ShellExtent *extent_;
     double accuracy_;
     int compute_potential_integrals_;
 
     // data local to thread
     int ithread_;
-    int ncontrib_;
-    int *contrib_;
-    int ncontrib_bf_;
-    int *contrib_bf_;
-    double *bs_values_;
-    double *bsg_values_;
-    double *bsh_values_;
+    Ref<BatchElectronDensity> den_;
     double *alpha_vmat_; // lower triangle of xi_i(r) v(r) xi_j(r) integrals
     double *beta_vmat_; // lower triangle of xi_i(r) v(r) xi_j(r) integrals
     double *nuclear_gradient_;
     double *w_gradient_;
     double *f_gradient_;
-    GaussianBasisSet::ValueData *valdat_;
 
   public:
     DenIntegratorThread(int ithread, int nthread,
                         DenIntegrator *integrator,
                         DenFunctional *func,
-                        double *alpha_dmat,
-                        double *beta_dmat,
-                        double *dmat_bound,
-                        int linear_scaling, int use_dmat_bound,
-                        ShellExtent *extent,
+                        const Ref<BatchElectronDensity> &den,
+                        int linear_scaling,
+                        int use_dmat_bound,
                         double accuracy,
                         int compute_potential_integrals,
                         int need_nuclear_gradient);
     virtual ~DenIntegratorThread();
-    void get_density(double *dmat, PointInputData::SpinData &d);
-    double do_point(int acenter, const SCVector3 &r,
+    double do_point(int iatom, const SCVector3 &r,
                     double weight, double multiplier,
                     double *nuclear_gradient,
                     double *f_gradient, double *w_gradient);
@@ -134,18 +155,16 @@ class DenIntegratorThread: public Thread {
 DenIntegratorThread::DenIntegratorThread(int ithread, int nthread,
                                          DenIntegrator *integrator,
                                          DenFunctional *func,
-                                         double *alpha_dmat,
-                                         double *beta_dmat,
-                                         double *dmat_bound,
+                                         const Ref<BatchElectronDensity> &den,
                                          int linear_scaling,
                                          int use_dmat_bound,
-                                         ShellExtent *extent,
                                          double accuracy,
                                          int compute_potential_integrals,
                                          int need_nuclear_gradient)
 {
   value_ = 0.0;
 
+  den_ = den;
   ithread_ = ithread;
   nthread_ = nthread;
   integrator_ = integrator;
@@ -153,23 +172,17 @@ DenIntegratorThread::DenIntegratorThread(int ithread, int nthread,
   nshell_ = integrator->wavefunction()->basis()->nshell();
   nbasis_ = integrator->wavefunction()->basis()->nbasis();
   natom_ = integrator->wavefunction()->molecule()->natom();
+  n_integration_center_
+      = integrator->wavefunction()->molecule()->n_non_q_atom();
   need_gradient_ = func->need_density_gradient();
   need_hessian_ = func->need_density_hessian();
   basis_ = integrator->wavefunction()->basis().pointer();
   linear_scaling_ = linear_scaling;
   use_dmat_bound_ = use_dmat_bound;
   func_ = func;
-  extent_ = extent;
   accuracy_ = accuracy;
   compute_potential_integrals_ = compute_potential_integrals;
-
-  alpha_dmat_ = alpha_dmat;
-  beta_dmat_ = beta_dmat;
-  dmat_bound_ = dmat_bound;
-
-  valdat_ = new GaussianBasisSet::ValueData(
-      integrator->wavefunction()->basis(),
-      integrator->wavefunction()->integral());
+  den_->set_accuracy(accuracy);
 
   if (need_nuclear_gradient) {
       nuclear_gradient_ = new double[3*natom_];
@@ -177,12 +190,6 @@ DenIntegratorThread::DenIntegratorThread(int ithread, int nthread,
     }
   else nuclear_gradient_ = 0;
 
-  contrib_ = new int[nshell_];
-
-  contrib_bf_ = new int[nbasis_];
-
-  bs_values_ = new double[nbasis_];
-
   alpha_vmat_ = 0;
   beta_vmat_ = 0;
   if (compute_potential_integrals_) {
@@ -195,33 +202,21 @@ DenIntegratorThread::DenIntegratorThread(int ithread, int nthread,
         }
     }
 
-  bsg_values_=0;
-  bsh_values_=0;
-  if (need_gradient_ || nuclear_gradient_) bsg_values_ = new double[3*nbasis_];
-  if (need_hessian_ || (need_gradient_ && nuclear_gradient_))
-      bsh_values_ = new double[6*nbasis_];
-
   w_gradient_ = 0;
   f_gradient_ = 0;
   if (nuclear_gradient_) {
-      w_gradient_ = new double[natom_*3];
+      w_gradient_ = new double[n_integration_center_*3];
       f_gradient_ = new double[natom_*3];
     }
 }
 
 DenIntegratorThread::~DenIntegratorThread()
 {
-  delete[] contrib_;
-  delete[] contrib_bf_;
-  delete[] bs_values_;
-  delete[] bsg_values_;
-  delete[] bsh_values_;
   delete[] alpha_vmat_;
   delete[] beta_vmat_;
   delete[] nuclear_gradient_;
   delete[] f_gradient_;
   delete[] w_gradient_;
-  delete valdat_;
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -256,9 +251,6 @@ DenIntegrator::DenIntegrator(const Ref<KeyVal>& keyval)
 
 DenIntegrator::~DenIntegrator()
 {
-  delete[] dmat_bound_;
-  delete[] alpha_dmat_;
-  delete[] beta_dmat_;
 }
 
 void
@@ -277,9 +269,6 @@ DenIntegrator::init_object()
   accuracy_ = DBL_EPSILON;
   linear_scaling_ = 1;
   use_dmat_bound_ = 1;
-  dmat_bound_ = 0;
-  alpha_dmat_ = 0;
-  beta_dmat_ = 0;
   alpha_vmat_ = 0;
   beta_vmat_ = 0;
 }
@@ -294,38 +283,24 @@ void
 DenIntegrator::init(const Ref<Wavefunction> &wfn)
 {
   wfn_ = wfn;
-  if (linear_scaling_) {
-      ExEnv::out0() << indent << "Initializing ShellExtent" << endl;
-      extent_ = new ShellExtent;
-      extent_->init(wfn_->basis());
-      ExEnv::out0() << indent
-           << "  nshell = " << wfn_->basis()->nshell() << endl;
-      int ncell = extent_->n(0)*extent_->n(1)*extent_->n(2);
-      ExEnv::out0() << indent << "  ncell = " << ncell << endl;
-      int maxval = 0;
-      double ave = 0;
-      for (int i=0; i<extent_->n(0); i++) {
-          for (int j=0; j<extent_->n(1); j++) {
-              for (int k=0; k<extent_->n(2); k++) {
-                  const std::vector<ExtentData> &e
-                      = extent_->contributing_shells(i,j,k);
-                  int val = e.size();
-                  if (val > maxval) maxval = val;
-                  ave += val;
-                }
-            }
-        }
-      ave /= ncell;
-      ExEnv::out0() << indent << "  ave nsh/cell = " << ave << endl;
-      ExEnv::out0() << indent << "  max nsh/cell = " << maxval << endl;
-    }
+  den_ = new BatchElectronDensity(wfn,accuracy_);
+  den_->set_linear_scaling(linear_scaling_);
+  den_->set_use_dmat_bound(use_dmat_bound_);
+  den_->init(false);
+}
+
+void
+DenIntegrator::set_accuracy(double a)
+{
+  accuracy_ = a;
+  if (den_.nonnull()) den_->set_accuracy(a);
 }
 
 void
 DenIntegrator::done()
 {
   wfn_ = 0;
-  extent_ = 0;
+  den_ = 0;
 }
 
 void
@@ -344,26 +319,13 @@ DenIntegrator::init_integration(const Ref<DenFunctional> &func,
   func->set_spin_polarized(spin_polarized_);
 
   natom_ = wfn_->molecule()->natom();
+  n_integration_center_
+      = wfn_->molecule()->n_non_q_atom();
 
   nshell_ = wfn_->basis()->nshell();
   nbasis_ = wfn_->basis()->nbasis();
    
-  delete[] alpha_dmat_;
-  RefSymmSCMatrix adens = densa;
-  if (adens.null())
-      adens = wfn_->alpha_ao_density();
-  alpha_dmat_ = new double[(nbasis_*(nbasis_+1))/2];
-  adens->convert(alpha_dmat_);
-
-  delete[] beta_dmat_;
-  beta_dmat_ = 0;
-  if (spin_polarized_) {
-      RefSymmSCMatrix bdens = densb;
-      if (bdens.null())
-          bdens = wfn_->beta_ao_density();
-      beta_dmat_ = new double[(nbasis_*(nbasis_+1))/2];
-      bdens->convert(beta_dmat_);
-    }
+  den_->set_densities(densa,densb);
 
   delete[] alpha_vmat_;
   delete[] beta_vmat_;
@@ -378,33 +340,6 @@ DenIntegrator::init_integration(const Ref<DenFunctional> &func,
           memset(beta_vmat_, 0, sizeof(double)*ntri);
         }
     }
-
-  delete[] dmat_bound_;
-  dmat_bound_ = new double[(nshell_*(nshell_+1))/2];
-  int ij = 0;
-  for (i=0; i<nshell_; i++) {
-      int ni = wfn_->basis()->shell(i).nfunction();
-      for (int j=0; j<=i; j++,ij++) {
-          int nj = wfn_->basis()->shell(j).nfunction();
-          double bound = 0.0;
-          int ibf = wfn_->basis()->shell_to_function(i);
-          for (int k=0; k<ni; k++,ibf++) {
-              int lmax = nj-1;
-              if (i==j) lmax = k;
-              int jbf = wfn_->basis()->shell_to_function(j);
-              int ijbf = (ibf*(ibf+1))/2 + jbf;
-              for (int l=0; l<=lmax; l++,ijbf++) {
-                  double a = fabs(alpha_dmat_[ijbf]);
-                  if (a > bound) bound = a;
-                  if (beta_dmat_) {
-                      double b = fabs(beta_dmat_[ijbf]);
-                      if (b > bound) bound = b;
-                    }
-                }
-            }
-          dmat_bound_[ij] = bound;
-        }
-    }
 }
 
 void
@@ -418,169 +353,10 @@ DenIntegrator::done_integration()
           messagegrp_->sum(beta_vmat_,ntri);
         }
     }
-  delete[] alpha_dmat_; alpha_dmat_ = 0;
-  delete[] beta_dmat_;  beta_dmat_ = 0;
-  delete[] dmat_bound_; dmat_bound_ = 0;
-}
-
-inline static double
-norm(double v[3])
-{
-  double x,y,z;
-  return sqrt((x=v[0])*x + (y=v[1])*y + (z=v[2])*z);
-}
-
-inline static double
-dot(double v[3], double w[3])
-{
-  return v[0]*w[0] + v[1]*w[1] + v[2]*w[2];
-}
-
-void
-DenIntegratorThread::get_density(double *dmat, PointInputData::SpinData &d)
-{
-  int i, j;
-
-  double tmp = 0.0;
-  double densij;
-  double bvi, bvix, bviy, bviz;
-  double bvixx, bviyx, bviyy, bvizx, bvizy, bvizz;
-
-  const int X = PointInputData::X;
-  const int Y = PointInputData::Y;
-  const int Z = PointInputData::Z;
-  const int XX = PointInputData::XX;
-  const int YX = PointInputData::YX;
-  const int YY = PointInputData::YY;
-  const int ZX = PointInputData::ZX;
-  const int ZY = PointInputData::ZY;
-  const int ZZ = PointInputData::ZZ;
-
-  double grad[3], hess[6];
-  if (need_gradient_) for (i=0; i<3; i++) grad[i] = 0.0;
-  if (need_hessian_) for (i=0; i<6; i++) hess[i] = 0.0;
-
-  CHECK_ALIGN(tmp);
-  CHECK_ALIGN(grad[0]);
-
-  if (need_gradient_) {
-      for (i=0; i < ncontrib_bf_; i++) {
-          int it = contrib_bf_[i];
-          bvi = bs_values_[i];
-          if (need_gradient_) {
-              bvix = bsg_values_[i*3+X];
-              bviy = bsg_values_[i*3+Y];
-              bviz = bsg_values_[i*3+Z];
-            }
-          if (need_hessian_) {
-              bvixx = bsh_values_[i*6+XX];
-              bviyx = bsh_values_[i*6+YX];
-              bviyy = bsh_values_[i*6+YY];
-              bvizx = bsh_values_[i*6+ZX];
-              bvizy = bsh_values_[i*6+ZY];
-              bvizz = bsh_values_[i*6+ZZ];
-            }
-          int j3 = 0, j6 = 0;
-          int itoff = (it*(it+1))>>1;
-          int itjt;
-          double t = 0.0;
-          for (j=0; j < i; j++) {
-              int jt = contrib_bf_[j];
-              itjt = itoff+jt;
-
-              densij = dmat[itjt];
-              double bvj = bs_values_[j];
-
-              CHECK_ALIGN(densij);
-              CHECK_ALIGN(bvj);
-
-              t += densij*bvi*bvj;
-
-              double bvjx, bvjy, bvjz;
-              if (need_gradient_) {
-                  bvjx = bsg_values_[j3+X];
-                  bvjy = bsg_values_[j3+Y];
-                  bvjz = bsg_values_[j3+Z];
-                  grad[X] += densij*(bvi*bvjx + bvj*bvix);
-                  grad[Y] += densij*(bvi*bvjy + bvj*bviy);
-                  grad[Z] += densij*(bvi*bvjz + bvj*bviz);
-                  j3 += 3;
-                }
-
-              if (need_hessian_) {
-                  double bvjxx = bsh_values_[j6+XX];
-                  double bvjyx = bsh_values_[j6+YX];
-                  double bvjyy = bsh_values_[j6+YY];
-                  double bvjzx = bsh_values_[j6+ZX];
-                  double bvjzy = bsh_values_[j6+ZY];
-                  double bvjzz = bsh_values_[j6+ZZ];
-
-                  hess[XX] += densij*(bvi*bvjxx+bvix*bvjx+bvjx*bvix+bvixx*bvj);
-                  hess[YX] += densij*(bvi*bvjyx+bviy*bvjx+bvjy*bvix+bviyx*bvj);
-                  hess[YY] += densij*(bvi*bvjyy+bviy*bvjy+bvjy*bviy+bviyy*bvj);
-                  hess[ZX] += densij*(bvi*bvjzx+bviz*bvjx+bvjz*bvix+bvizx*bvj);
-                  hess[ZY] += densij*(bvi*bvjzy+bviz*bvjy+bvjz*bviy+bvizy*bvj);
-                  hess[ZZ] += densij*(bvi*bvjzz+bviz*bvjz+bvjz*bviz+bvizz*bvj);
-
-                  j6 += 6;
-                }
-            }
-          densij = dmat[itoff+it]*bvi;
-          tmp += t + 0.5*densij*bvi;
-          if (need_gradient_) {
-              grad[X] += densij*bvix;
-              grad[Y] += densij*bviy;
-              grad[Z] += densij*bviz;
-            }
-          if (need_hessian_) {
-              hess[XX] += densij*bvixx;
-              hess[YX] += densij*bviyx;
-              hess[YY] += densij*bviyy;
-              hess[ZX] += densij*bvizx;
-              hess[ZY] += densij*bvizy;
-              hess[ZZ] += densij*bvizz;
-            }
-        }
-    }
-  else {
-      for (i=0; i < ncontrib_bf_; i++) {
-          int it = contrib_bf_[i];
-          bvi = bs_values_[i];
-          int itoff = (it*(it+1))>>1;
-          int itjt;
-          double t = 0.0;
-          for (j=0; j < i; j++) {
-              int jt = contrib_bf_[j];
-              itjt = itoff+jt;
-
-              densij = dmat[itjt];
-              double bvj = bs_values_[j];
-
-              CHECK_ALIGN(densij);
-              CHECK_ALIGN(bvj);
-
-              t += densij*bvi*bvj;
-            }
-          densij = dmat[itoff+it]*bvi;
-          tmp += t + 0.5*densij*bvi;
-        }
-    }
-  d.rho = 2.0 * tmp;
-
-  if (need_gradient_) {
-      for (i=0; i<3; i++) d.del_rho[i] = 2.0 * grad[i];
-      d.gamma = dot(d.del_rho,d.del_rho);
-    }
-
-  if (need_hessian_) {
-      for (i=0; i<6; i++) d.hes_rho[i] = 2.0 * hess[i];
-      d.lap_rho = d.hes_rho[XX] + d.hes_rho[YY] + d.hes_rho[ZZ];
-    }
-
 }
 
 double
-DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
+DenIntegratorThread::do_point(int iatom, const SCVector3 &r,
                         double weight, double multiplier,
                         double *nuclear_gradient,
                         double *f_gradient, double *w_gradient)
@@ -590,75 +366,25 @@ DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
 
   CHECK_ALIGN(w_mult);
 
-  // only consider those shells for which phi_i * (Max_j D_ij phi_j) > tol
-  if (linear_scaling_ && use_dmat_bound_) {
-      const std::vector<ExtentData> &cs = extent_->contributing_shells(r[0],r[1],r[2]);
-      ncontrib_ = 0;
-      for (i=0; i<cs.size(); i++) {
-          int ish = cs[i].shell;
-          int contrib = 0;
-          for (j=0; j<cs.size(); j++) {
-              int jsh = cs[j].shell;
-              int ijsh = (ish>jsh)?((ish*(ish+1))/2+jsh):((jsh*(jsh+1))/2+ish);
-              if (cs[i].bound*cs[j].bound*dmat_bound_[ijsh] > 0.00001*accuracy_) {
-                  contrib = 1;
-                  break;
-                }
-            }
-          if (contrib) {
-              contrib_[ncontrib_++] = ish;
-            }
-        }
-    }
-  else if (linear_scaling_) {
-      const std::vector<ExtentData> &cs = extent_->contributing_shells(r[0],r[1],r[2]);
-      ncontrib_ = cs.size();
-      for (i=0; i<ncontrib_; i++) {
-          contrib_[i] = cs[i].shell;
-        }
-    }
-  else {
-      ncontrib_ = nshell_;
-      for (i=0; i<nshell_; i++) contrib_[i] = i;
-    }
-  if (ncontrib_ > nshell_) {
-      ExEnv::outn() << "DenIntegratorThread::do_point: ncontrib invalid"
-                   << endl;
-      abort();
-    }
-
-  ncontrib_bf_ = 0;
-  for (i=0; i<ncontrib_; i++) {
-      int nbf = basis_->shell(contrib_[i]).nfunction();
-      int bf = basis_->shell_to_function(contrib_[i]);
-      for (j=0; j<nbf; j++, bf++) {
-          contrib_bf_[ncontrib_bf_++] = bf;
-        }
-    }
-
-  // compute the basis set values
-  double *bsh = bsh_values_, *bsg = bsg_values_, *bsv = bs_values_;
-  for (i=0; i<ncontrib_; i++) {
-      basis_->hessian_shell_values(r,contrib_[i],valdat_,bsh,bsg,bsv);
-      int shsize = basis_->shell(contrib_[i]).nfunction();
-      if (bsh) bsh += 6 * shsize;
-      if (bsg) bsg += 3 * shsize;
-      if (bsv) bsv += shsize;
-    }
-
-  // loop over basis functions adding contributions to the density
   PointInputData id(r);
 
-  get_density(alpha_dmat_, id.a);
-  if (spin_polarized_) {
-      get_density(beta_dmat_, id.b);
-      if (need_gradient_) {
-          id.gamma_ab = id.a.del_rho[0]*id.b.del_rho[0]
-                      + id.a.del_rho[1]*id.b.del_rho[1] 
-                      + id.a.del_rho[2]*id.b.del_rho[2];
-        }
-    }
-  id.compute_derived(spin_polarized_, need_gradient_);
+  den_->compute_density(r,
+                        &id.a.rho,
+                        (need_gradient_?id.a.del_rho:0),
+                        (need_hessian_?id.a.hes_rho:0),
+                        &id.b.rho,
+                        (need_gradient_?id.b.del_rho:0),
+                        (need_hessian_?id.b.hes_rho:0));
+
+  id.compute_derived(spin_polarized_, need_gradient_, need_hessian_);
+
+  int ncontrib = den_->ncontrib();
+  int *contrib = den_->contrib();
+  int ncontrib_bf = den_->ncontrib_bf();
+  int *contrib_bf = den_->contrib_bf();
+  double *bs_values = den_->bs_values();
+  double *bsg_values = den_->bsg_values();
+  double *bsh_values = den_->bsh_values();
 
   PointOutputData od;
   if ( (id.a.rho + id.b.rho) > 1e2*DBL_EPSILON) {
@@ -666,10 +392,13 @@ DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
           func_->point(id, od);
         }
       else {
-          func_->gradient(id, od, f_gradient, acenter, basis_,
-                         alpha_dmat_, (spin_polarized_?beta_dmat_:alpha_dmat_),
-                         ncontrib_, contrib_, ncontrib_bf_, contrib_bf_,
-                         bs_values_, bsg_values_, bsh_values_);
+          func_->gradient(id, od, f_gradient, iatom, basis_,
+                          den_->alpha_density_matrix(),
+                          den_->beta_density_matrix(),
+                          ncontrib, contrib,
+                          ncontrib_bf, contrib_bf,
+                          bs_values, bsg_values,
+                          bsh_values);
         }
     }
   else {
@@ -699,39 +428,39 @@ DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
                                       od.df_dgamma_ab*id.a.del_rho[2]);
             }
 
-          for (int j=0; j<ncontrib_bf_; j++) {
-              int jt = contrib_bf_[j];
-              double dfdra_phi_m = drhoa*bs_values_[j];
-              double dfdga_phi_m = gradsa[0]*bsg_values_[j*3+0] +
-                                   gradsa[1]*bsg_values_[j*3+1] +
-                                   gradsa[2]*bsg_values_[j*3+2];
+          for (int j=0; j<ncontrib_bf; j++) {
+              int jt = contrib_bf[j];
+              double dfdra_phi_m = drhoa*bs_values[j];
+              double dfdga_phi_m = gradsa[0]*bsg_values[j*3+0] +
+                                   gradsa[1]*bsg_values[j*3+1] +
+                                   gradsa[2]*bsg_values[j*3+2];
               double vamu = dfdra_phi_m + dfdga_phi_m, vbmu=0.0;
               double dfdrb_phi_m, dfdgb_phi_m;
               if (spin_polarized_) {
-                  dfdrb_phi_m = drhob*bs_values_[j];
-                  dfdgb_phi_m = gradsb[0]*bsg_values_[j*3+0] +
-                                       gradsb[1]*bsg_values_[j*3+1] +
-                                       gradsb[2]*bsg_values_[j*3+2];
+                  dfdrb_phi_m = drhob*bs_values[j];
+                  dfdgb_phi_m = gradsb[0]*bsg_values[j*3+0] +
+                                       gradsb[1]*bsg_values[j*3+1] +
+                                       gradsb[2]*bsg_values[j*3+2];
                   vbmu = dfdrb_phi_m + dfdgb_phi_m;
                 }
 
               int jtoff = (jt*(jt+1))>>1;
 
               for (int k=0; k <= j; k++) {
-                  int kt = contrib_bf_[k];
+                  int kt = contrib_bf[k];
                   int jtkt = jtoff + kt;
 
-                  double dfdga_phi_n = gradsa[0]*bsg_values_[k*3+0] +
-                                       gradsa[1]*bsg_values_[k*3+1] +
-                                       gradsa[2]*bsg_values_[k*3+2];
-                  alpha_vmat_[jtkt] += vamu * bs_values_[k] +
-                                     dfdga_phi_n * bs_values_[j];
+                  double dfdga_phi_n = gradsa[0]*bsg_values[k*3+0] +
+                                       gradsa[1]*bsg_values[k*3+1] +
+                                       gradsa[2]*bsg_values[k*3+2];
+                  alpha_vmat_[jtkt] += vamu * bs_values[k] +
+                                     dfdga_phi_n * bs_values[j];
                   if (spin_polarized_) {
-                      double dfdgb_phi_n = gradsb[0]*bsg_values_[k*3+0] +
-                                           gradsb[1]*bsg_values_[k*3+1] +
-                                           gradsb[2]*bsg_values_[k*3+2];
-                      beta_vmat_[jtkt] += vbmu * bs_values_[k] +
-                                          dfdgb_phi_n * bs_values_[j];
+                      double dfdgb_phi_n = gradsb[0]*bsg_values[k*3+0] +
+                                           gradsb[1]*bsg_values[k*3+1] +
+                                           gradsb[2]*bsg_values[k*3+2];
+                      beta_vmat_[jtkt] += vbmu * bs_values[k] +
+                                          dfdgb_phi_n * bs_values[j];
                     }
                 }
             }
@@ -739,16 +468,16 @@ DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
       else {
           double drhoa = w_mult*od.df_drho_a;
           double drhob = w_mult*od.df_drho_b;
-          for (int j=0; j<ncontrib_bf_; j++) {
-              int jt = contrib_bf_[j];
-              double bsj = bs_values_[j];
+          for (int j=0; j<ncontrib_bf; j++) {
+              int jt = contrib_bf[j];
+              double bsj = bs_values[j];
               double dfa_phi_m = drhoa * bsj;
               double dfb_phi_m = drhob * bsj;
               int jtoff = (jt*(jt+1))>>1;
               for (int k=0; k <= j; k++) {
-                  int kt = contrib_bf_[k];
+                  int kt = contrib_bf[k];
                   int jtkt = jtoff + kt;
-                  double bsk = bs_values_[k];
+                  double bsk = bs_values[k];
                   alpha_vmat_[jtkt] += dfa_phi_m * bsk;
                   if (spin_polarized_)
                       beta_vmat_[jtkt] += dfb_phi_m * bsk;
@@ -760,8 +489,12 @@ DenIntegratorThread::do_point(int acenter, const SCVector3 &r,
   if (nuclear_gradient != 0) {
       // the contribution from f dw/dx
       if (w_gradient) {
-          for (i=0; i<natom_*3; i++) {
-              nuclear_gradient[i] += w_gradient[i] * od.energy * multiplier;
+          for (int icenter = 0; icenter<n_integration_center_; icenter++) {
+              int iatom = basis_->molecule()->non_q_atom(icenter);
+              for (int ixyz=0; ixyz<3; ixyz++) {
+                  nuclear_gradient[iatom*3+ixyz]
+                      += w_gradient[icenter*3+ixyz] * od.energy * multiplier;
+                }
             }
         }
       // the contribution from (df/dx) w
@@ -935,6 +668,7 @@ BeckeIntegrationWeight::BeckeIntegrationWeight(StateIn& s):
   SavableState(s),
   IntegrationWeight(s)
 {
+  n_integration_centers = 0;
   atomic_radius = 0;
   a_mat = 0;
   oorab = 0;
@@ -943,6 +677,7 @@ BeckeIntegrationWeight::BeckeIntegrationWeight(StateIn& s):
 
 BeckeIntegrationWeight::BeckeIntegrationWeight()
 {
+  n_integration_centers = 0;
   centers = 0;
   atomic_radius = 0;
   a_mat = 0;
@@ -952,6 +687,7 @@ BeckeIntegrationWeight::BeckeIntegrationWeight()
 BeckeIntegrationWeight::BeckeIntegrationWeight(const Ref<KeyVal>& keyval):
   IntegrationWeight(keyval)
 {
+  n_integration_centers = 0;
   centers = 0;
   atomic_radius = 0;
   a_mat = 0;
@@ -975,36 +711,36 @@ BeckeIntegrationWeight::init(const Ref<Molecule> &mol, double tolerance)
   done();
   IntegrationWeight::init(mol, tolerance);
 
-  ncenters = mol->natom();
+  // We only want to include to include "atoms" that correspond to nuclei,
+  // not charges.
+  n_integration_centers = mol->n_non_q_atom();
 
-  double *atomic_radius = new double[ncenters];
-  int icenter;
-  for (icenter=0; icenter<ncenters; icenter++) {
-      // atomic_radius[icenter] = mol->atominfo()->bragg_radius(mol->Z(icenter));
-      atomic_radius[icenter] = mol->atominfo()->maxprob_radius(mol->Z(icenter));
-    }
-  
-  centers = new SCVector3[ncenters];
-  for (icenter=0; icenter<ncenters; icenter++) {
-      centers[icenter].x() = mol->r(icenter,0);
-      centers[icenter].y() = mol->r(icenter,1);
-      centers[icenter].z() = mol->r(icenter,2);
+  double *atomic_radius = new double[n_integration_centers];
+  centers = new SCVector3[n_integration_centers];
+
+  for (int icenter=0; icenter<n_integration_centers; icenter++) {
+      int iatom = mol->non_q_atom(icenter);
+
+      atomic_radius[icenter] = get_radius(mol, iatom);
+
+      centers[icenter].x() = mol->r(iatom,0);
+      centers[icenter].y() = mol->r(iatom,1);
+      centers[icenter].z() = mol->r(iatom,2);
     }
+      
+  a_mat = new double*[n_integration_centers];
+  a_mat[0] = new double[n_integration_centers*n_integration_centers];
+  oorab = new double*[n_integration_centers];
+  oorab[0] = new double[n_integration_centers*n_integration_centers];
 
-  a_mat = new double*[ncenters];
-  a_mat[0] = new double[ncenters*ncenters];
-  oorab = new double*[ncenters];
-  oorab[0] = new double[ncenters*ncenters];
-
-  for (icenter=0; icenter < ncenters; icenter++) {
+  for (int icenter=0; icenter<n_integration_centers; icenter++) {
       if (icenter) {
-          a_mat[icenter] = &a_mat[icenter-1][ncenters];
-          oorab[icenter] = &oorab[icenter-1][ncenters];
+          a_mat[icenter] = &a_mat[icenter-1][n_integration_centers];
+          oorab[icenter] = &oorab[icenter-1][n_integration_centers];
         }
 
       double atomic_radius_a = atomic_radius[icenter];
-      
-      for (int jcenter=0; jcenter < ncenters; jcenter++) {
+      for (int jcenter=0; jcenter < n_integration_centers; jcenter++) {
           double chi=atomic_radius_a/atomic_radius[jcenter];
           double uab=(chi-1.)/(chi+1.);
           a_mat[icenter][jcenter] = uab/(uab*uab-1.);
@@ -1040,6 +776,8 @@ BeckeIntegrationWeight::done()
       delete[] oorab;
       oorab = 0;
     }
+
+  n_integration_centers = 0;
 }
 
 double
@@ -1050,7 +788,7 @@ BeckeIntegrationWeight::compute_p(int icenter, SCVector3&point)
   double *aa = a_mat[icenter];
 
   double p = 1.0;
-  for (int jcenter=0; jcenter < ncenters; jcenter++) {
+  for (int jcenter=0; jcenter < n_integration_centers; jcenter++) {
       if (icenter != jcenter) {
           double mu = (ra-point.dist(centers[jcenter]))*ooraba[jcenter];
 
@@ -1138,7 +876,7 @@ BeckeIntegrationWeight::compute_grad_p(int grad_center, int bcenter,
 
   if (grad_center == bcenter) {
       grad = 0.0;
-      for (int dcenter=0; dcenter<ncenters; dcenter++) {
+      for (int dcenter=0; dcenter<n_integration_centers; dcenter++) {
           if (dcenter == bcenter) continue;
           SCVector3 grad_nu;
           compute_grad_nu(grad_center, dcenter, point, grad_nu);
@@ -1162,7 +900,7 @@ BeckeIntegrationWeight::w(int acenter, SCVector3 &point,
   int icenter;
   double p_sum=0.0, p_a=0.0;
     
-  for (icenter=0; icenter<ncenters; icenter++) {
+  for (icenter=0; icenter<n_integration_centers; icenter++) {
       double p_tmp = compute_p(icenter, point);
       if (icenter==acenter) p_a=p_tmp;
       p_sum += p_tmp;
@@ -1173,15 +911,15 @@ BeckeIntegrationWeight::w(int acenter, SCVector3 &point,
       // w_gradient is computed using the formulae from
       // Johnson et al., JCP v. 98, p. 5612 (1993) (Appendix B)
       int i,j;
-      for (i=0; i<ncenters*3; i++ ) w_gradient[i] = 0.0;
+      for (i=0; i<n_integration_centers*3; i++ ) w_gradient[i] = 0.0;
 //      fd_w(acenter, point, w_gradient);  // imbn commented out for debug
 //        ExEnv::outn() << point << " ";
-//        for (int i=0; i<ncenters*3; i++) {
+//        for (int i=0; i<n_integration_centers*3; i++) {
 //            ExEnv::outn() << scprintf(" %10.6f", w_gradient[i]);
 //          }
 //        ExEnv::outn() << endl;
 //      return w_a;  // imbn commented out for debug
-      for (int ccenter = 0; ccenter < ncenters; ccenter++) {
+      for (int ccenter = 0; ccenter < n_integration_centers; ccenter++) {
           // NB: for ccenter==acenter, use translational invariance
           // to get the corresponding component of the gradient
           if (ccenter != acenter) {
@@ -1189,7 +927,7 @@ BeckeIntegrationWeight::w(int acenter, SCVector3 &point,
               SCVector3 grad_c_p_a;
               compute_grad_p(ccenter, acenter, acenter, point, p_a, grad_c_p_a);
               for (i=0; i<3; i++) grad_c_w_a[i] = grad_c_p_a[i]/p_sum;
-              for (int bcenter=0; bcenter<ncenters; bcenter++) {
+              for (int bcenter=0; bcenter<n_integration_centers; bcenter++) {
                   SCVector3 grad_c_p_b;
                   double p_b = compute_p(bcenter,point);
                   compute_grad_p(ccenter, bcenter, acenter, point, p_b,
@@ -1201,7 +939,7 @@ BeckeIntegrationWeight::w(int acenter, SCVector3 &point,
         }
       // fill in w_gradient for ccenter==acenter
       for (j=0; j<3; j++) {
-          for (i=0; i<ncenters; i++) {
+          for (i=0; i<n_integration_centers; i++) {
               if (i != acenter) {
                   w_gradient[acenter*3+j] -= w_gradient[i*3+j];
                 }
@@ -1684,10 +1422,8 @@ class RadialAngularIntegratorThread: public DenIntegratorThread {
     RadialAngularIntegratorThread(int ithread, int nthread,
                                   RadialAngularIntegrator *integrator,
                                   DenFunctional *func,
-                                  double *alpha_dmat, double *beta_dmat,
-                                  double *dmat_bound,
+                                  const Ref<BatchElectronDensity> &den,
                                   int linear_scaling, int use_dmat_bound,
-                                  ShellExtent *extent,
                                   double accuracy,
                                   int compute_potential_integrals,
                                   int need_nuclear_gradient);
@@ -1701,19 +1437,16 @@ RadialAngularIntegratorThread
 ::RadialAngularIntegratorThread(int ithread, int nthread,
                                 RadialAngularIntegrator *integrator,
                                 DenFunctional *func,
-                                double *alpha_dmat, double *beta_dmat,
-                                double *dmat_bound,
+                                const Ref<BatchElectronDensity> &den,
                                 int linear_scaling, int use_dmat_bound,
-                                ShellExtent *extent,
                                 double accuracy,
                                 int compute_potential_integrals,
                                 int need_nuclear_gradient):
   DenIntegratorThread(ithread,nthread,
                       integrator, func,
-                      alpha_dmat, beta_dmat,
-                      dmat_bound,
+                      den,
                       linear_scaling, use_dmat_bound,
-                      extent, accuracy,
+                      accuracy,
                       compute_potential_integrals,
                       need_nuclear_gradient)
 {
@@ -1725,23 +1458,26 @@ RadialAngularIntegratorThread
 
   weight_ = ra_integrator_->weight().pointer();
 
-  nr_ = new int[natom_];
+  nr_ = new int[n_integration_center_];
   
-  for (icenter=0; icenter<natom_; icenter++)
+  for (icenter=0; icenter<n_integration_center_; icenter++) {
+      int iatom = mol_->non_q_atom(icenter);
       nr_[icenter]
-	= ra_integrator_->get_radial_grid(mol_->Z(icenter),deriv_order)->nr();
-
-  centers_ = new SCVector3[natom_];
-  for (icenter=0; icenter<natom_; icenter++) {
-      centers_[icenter].x() = mol_->r(icenter,0);
-      centers_[icenter].y() = mol_->r(icenter,1);
-      centers_[icenter].z() = mol_->r(icenter,2);
+	= ra_integrator_->get_radial_grid(mol_->Z(iatom),deriv_order)->nr();
     }
 
-  atomic_radius_ = new double[natom_];
-  for (icenter=0; icenter<natom_; icenter++) {
-      atomic_radius_[icenter]
-          = mol_->atominfo()->maxprob_radius(mol_->Z(icenter));
+  centers_ = new SCVector3[n_integration_center_];
+  for (icenter=0; icenter<n_integration_center_; icenter++) {
+      int iatom = mol_->non_q_atom(icenter);
+      centers_[icenter].x() = mol_->r(iatom,0);
+      centers_[icenter].y() = mol_->r(iatom,1);
+      centers_[icenter].z() = mol_->r(iatom,2);
+    }
+
+  atomic_radius_ = new double[n_integration_center_];
+  for (icenter=0; icenter<n_integration_center_; icenter++) {
+      int iatom = mol_->non_q_atom(icenter);
+      atomic_radius_[icenter] = get_radius(mol_, iatom);
     }
 
   point_count_total_ = 0;
@@ -1772,12 +1508,13 @@ RadialAngularIntegratorThread::run()
         
   int parallel_counter = 0;
 
-  for (icenter=0; icenter < natom_; icenter++) {
+  for (icenter=0; icenter < n_integration_center_; icenter++) {
+      int iatom = mol_->non_q_atom(icenter);
       point_count=0;
       center = centers_[icenter];
       // get current radial grid: depends on convergence threshold
       RadialIntegrator *radial
-          = ra_integrator_->get_radial_grid(mol_->Z(icenter), deriv_order);
+          = ra_integrator_->get_radial_grid(mol_->Z(iatom), deriv_order);
       nr = radial->nr();
       for (ir=0; ir < nr; ir++) {
           if (! (parallel_counter++%nthread_ == ithread_)) continue;
@@ -1786,7 +1523,7 @@ RadialAngularIntegratorThread::run()
           // get current angular grid: depends on radial point and threshold
           AngularIntegrator *angular
               = ra_integrator_->get_angular_grid(r, atomic_radius_[icenter],
-                                                 mol_->Z(icenter),
+                                                 mol_->Z(iatom),
 						 deriv_order);
           nangular = angular->num_angular_points(r/atomic_radius_[icenter],ir);
           for (iangular=0; iangular<nangular; iangular++) {
@@ -1799,7 +1536,7 @@ RadialAngularIntegratorThread::run()
               double multiplier = angular_multiplier * radial_multiplier;
               total_density_
                   += w * multiplier
-                  * do_point(icenter, integration_point,
+                  * do_point(iatom, integration_point,
                              w, multiplier,
                              nuclear_gradient_, f_gradient_, w_gradient_);
             }
@@ -2314,12 +2051,17 @@ RadialAngularIntegrator::integrate(const Ref<DenFunctional> &denfunc,
   RadialAngularIntegratorThread **threads =
       new RadialAngularIntegratorThread*[nthread];
   for (i=0; i<nthread; i++) {
+      Ref<BatchElectronDensity> bed = new BatchElectronDensity(den_, true);
+      if (nuclear_gradient != 0) {
+          bed->set_need_basis_gradient(true);
+          if (denfunc->need_density_gradient()) bed->set_need_basis_hessian(true);
+        }
       threads[i] = new RadialAngularIntegratorThread(
           i + ithread_overall, nthread_overall,
           this, denfunc.pointer(),
-          alpha_dmat_, beta_dmat_, dmat_bound_,
+          bed,
           linear_scaling_, use_dmat_bound_,
-          extent_.pointer(), accuracy_, compute_potential_integrals_,
+          accuracy_, compute_potential_integrals_,
           nuclear_gradient != 0);
       threadgrp_->add_thread(i, threads[i]);
     }
