@@ -40,6 +40,10 @@ namespace sc {
 
 // //////////////////////////////////////////////////////////////////////////
 
+/**
+   This provides a Kohn-Sham implementation for unrestricted-orbital
+   open-shell systems.
+ */
 class UKS: public UnrestrictedSCF {
   protected:
     Ref<DenIntegrator> integrator_;
@@ -49,6 +53,20 @@ class UKS: public UnrestrictedSCF {
 
   public:
     UKS(StateIn&);
+    /**
+       This KeyVal constructor reads the following keywords:
+        <dl>
+
+       <dt><tt>integrator</tt><dd>Specifies the DenIntegrator that will be
+       used to integrate the density functional.  The default is
+       RadialAngularIntegrator.
+
+       <dt><tt>functional</tt><dd>Specifies the DenFunctional that will be
+       used to compute the exchange/correlation contribution.  This is no
+       default.
+
+       </dl>
+    */
     UKS(const Ref<KeyVal>&);
     ~UKS();
 
