@@ -62,6 +62,14 @@ class IntegralKey {
   public:
     IntegralKey(int,int,int,int,int,int,int);
     IntegralKey(const IntegralKey&);
+    bool operator == (const IntegralKey &k) const {
+      return    (sh0_sh1_p12_p34 == k.sh0_sh1_p12_p34)
+             && (sh2_sh3_p13p24  == k.sh2_sh3_p13p24);
+    }
+    bool operator < (const IntegralKey &k) const {
+      return ((sh0_sh1_p12_p34 < k.sh0_sh1_p12_p34)?
+              true:(sh2_sh3_p13p24 < k.sh2_sh3_p13p24));
+    }
     int sh0() const { return (sh0_sh1_p12_p34>>SH0_SHIFT) & SH_MASK; }
     int sh1() const { return (sh0_sh1_p12_p34>>SH1_SHIFT) & SH_MASK; }
     int p12() const { return (sh0_sh1_p12_p34>>P12_SHIFT) & PE_MASK; }
