@@ -39,6 +39,8 @@
 #include <chemistry/qc/intv3/tformv3.h>
 #include <chemistry/qc/intv3/utils.h>
 
+using namespace sc;
+
 ////////////////////////////////////////////////////////////////////////////
 
 #define PRINT 0
@@ -648,14 +650,14 @@ Int2eV3::do_gencon_sparse_transform_2e(Integral*integ,
 #if PRINT
     {
       double *tmp = integrals;
-      ExEnv::out() << scprintf("Before transform of index %d (%dx%dx%dx%d)\n",
+      ExEnv::outn() << scprintf("Before transform of index %d (%dx%dx%dx%d)\n",
              index, nsource1, nsource2, nsource3, nsource4);
       for (i=0; i<nsource1; i++) {
           for (j=0; j<nsource2; j++) {
               for (k=0; k<nsource3; k++) {
                   for (l=0; l<nsource4; l++) {
                       if (fabs(*tmp)>1.e-15) {
-                          ExEnv::out() << scprintf("(%d %d|%d %d) = %15.11lf\n",i,j,k,l,*tmp);
+                          ExEnv::outn() << scprintf("(%d %d|%d %d) = %15.11lf\n",i,j,k,l,*tmp);
                         }
                       tmp++;
                     }
@@ -729,14 +731,14 @@ Int2eV3::do_gencon_sparse_transform_2e(Integral*integ,
 #if PRINT
     {
       double *tmp = integrals;
-      ExEnv::out() << scprintf("After transform of index %d (%dx%dx%dx%d)\n",
+      ExEnv::outn() << scprintf("After transform of index %d (%dx%dx%dx%d)\n",
              index, ntarget1, ntarget2, ntarget3, ntarget4);
       for (i=0; i<ntarget1; i++) {
           for (j=0; j<ntarget2; j++) {
               for (k=0; k<ntarget3; k++) {
                   for (l=0; l<ntarget4; l++) {
                       if (fabs(*tmp)>1.e-15) {
-                          ExEnv::out()
+                          ExEnv::outn()
                             << scprintf("(%d %d|%d %d) = %15.11lf\n",
                                         i,j,k,l,*tmp);
                         }
