@@ -566,7 +566,7 @@ MBPT2::compute_cs_grad()
       abort();
     }
 
-  mem->set_localsize(nijmax*nbasis*nbasis*sizeof(double));
+  mem->set_localsize(size_t(nijmax)*nbasis*nbasis*sizeof(double));
   ExEnv::out0() << indent
        << "Size of global distributed array:       "
        << mem->totalsize()
@@ -579,11 +579,13 @@ MBPT2::compute_cs_grad()
 
   Ref<ThreadLock> lock = thr_->new_lock();
   CSGradErep12Qtr** e12thread = new CSGradErep12Qtr*[thr_->nthread()];
+  DistShellPair::SharedData sp_e_data, sp_g_data;
   for (i=0; i<thr_->nthread(); i++) {
     e12thread[i] = new CSGradErep12Qtr(i, thr_->nthread(), me, nproc,
                                        mem, msg_, lock, basis(), tbints_[i],
                                        nocc, scf_vector, tol, debug_,
-                                       dynamic_, usep4);
+                                       dynamic_, print_percent_,
+                                       &sp_e_data, usep4);
     }
 
     CSGrad34Qbtr** qbt34thread;
@@ -593,7 +595,8 @@ MBPT2::compute_cs_grad()
         qbt34thread[i] = new CSGrad34Qbtr(i, thr_->nthread(), me, nproc,
                                           mem, msg_, lock, basis(), tbints_[i],
                                           tbintder_[i], nocc, nfzc, scf_vector,
-                                          tol, debug_, dynamic_, dograd, natom);
+                                          tol, debug_, dynamic_, print_percent_,
+                                          &sp_g_data, dograd, natom);
         }
       }
 
@@ -650,6 +653,7 @@ MBPT2::compute_cs_grad()
 
     // Do the two eletron integrals and the first two quarter transformations
     tim_enter("erep+1.qt+2.qt");
+    sp_e_data.init();
     for (i=0; i<thr_->nthread(); i++) {
       e12thread[i]->set_i_offset(i_offset);
       e12thread[i]->set_ni(ni);
@@ -1431,6 +1435,7 @@ MBPT2::compute_cs_grad()
     //////////////////////////////////////////////////////////
 
     tim_enter("3.qbt+4.qbt+non-sep contrib.");
+    sp_g_data.init();
     for (i=0; i<thr_->nthread(); i++) {
       qbt34thread[i]->set_i_offset(i_offset);
       qbt34thread[i]->set_ni(ni);
@@ -1731,7 +1736,7 @@ MBPT2::compute_cs_grad()
       int i0 = biggest_t1.indices(i)[0];
       int i1 = biggest_t1.indices(i)[1] + nocc;
       ExEnv::out0()
-           << indent << scprintf("  %2d %12.8f %2d %3s -> %2d %3s",
+           << indent << scprintf("  %2d %12.8f  %3d %3s -> %4d %3s",
                                  i+1, biggest_t1.val(i),
                                  symorb_num_[i0]+1,
                                  ct.gamma(symorb_irrep_[i0]).symbol(),
@@ -2208,10 +2213,7 @@ MBPT2::compute_cs_grad()
   ////////////////////////////////////////////////////////
 
   if (me == 0) {
-    zero_gradients(ginter, natom, 3);
-    for (i=0; i<natom; i++) {
-      molecule()->nuclear_repulsion_1der(i,ginter[i]);
-      }
+    nuclear_repulsion_energy_gradient(ginter);
     accum_gradients(gradient, ginter, natom, 3);
     accum_gradients(hf_gradient, ginter, natom, 3);
 
