@@ -35,8 +35,8 @@
 #include <util/misc/formio.h>
 #include <chemistry/qc/mbpt/bzerofast.h>
 #include <chemistry/qc/mbpt/csgrad34qb.h>
-#include <chemistry/qc/mbpt/distsh.h>
 #include <chemistry/qc/mbpt/util.h>
+#include <chemistry/qc/basis/distshpair.h>
 
 using namespace std;
 using namespace sc;
@@ -52,7 +52,10 @@ CSGrad34Qbtr::CSGrad34Qbtr(int mythread_a, int nthread_a,
                            int nocc_a, int nfzc_a,
                            double **scf_vector_a,
                            double tol_a, int debug_a,
-                           int dynamic_a, int dograd_a, int natom_a)
+                           int dynamic_a, double print_percent_a,
+                           DistShellPair::SharedData *shellpair_shared_data,
+                           int dograd_a, int natom_a):
+  shellpair_shared_data_(shellpair_shared_data)
 {
   msg = msg_a;
   mythread = mythread_a;
@@ -70,6 +73,7 @@ CSGrad34Qbtr::CSGrad34Qbtr(int mythread_a, int nthread_a,
   scf_vector = scf_vector_a;
   debug = debug_a;
   dynamic_ = dynamic_a;
+  print_percent_ = print_percent_a;
   dograd = dograd_a;
   natom = natom_a;
 
@@ -155,8 +159,9 @@ CSGrad34Qbtr::run()
   
   DerivCenters der_centers;
 
-  DistShellPair shellpairs(msg,nthread,mythread,lock,basis);
-  shellpairs.set_dynamic(dynamic_);
+  DistShellPair shellpairs(msg,nthread,mythread,lock,basis,basis,dynamic_,
+                           shellpair_shared_data_);
+  shellpairs.set_print_percent(print_percent_);
   shellpairs.set_debug(debug);
   if (debug) shellpairs.set_print_percent(1);
   S = 0;
