@@ -43,6 +43,7 @@ typedef int dmt_matrix;
 #include <chemistry/qc/mbpt/hsosv1e1.h>
 
 using namespace std;
+using namespace sc;
 
 static distsize_t
 compute_v1_memory(int ni,
@@ -131,12 +132,12 @@ MBPT2::compute_hsos_v1()
 
   me = msg_->me();
   
-  ExEnv::out() << node0 << indent << "Just entered OPT2 program (opt2_v1)" << endl;
+  ExEnv::out0() << indent << "Just entered OPT2 program (opt2_v1)" << endl;
 
   tol = (int) (-10.0/log10(2.0));  /* discard ereps smaller than 10^-10 */
 
   nproc = msg_->n();
-  ExEnv::out() << node0 << indent << "nproc = " << nproc << endl;
+  ExEnv::out0() << indent << "nproc = " << nproc << endl;
 
   ndocc = nsocc = 0;
   const double epsilon = 1.0e-4;
@@ -149,19 +150,19 @@ MBPT2::compute_hsos_v1()
    * can be done (and appears to be meaningful!)                     */
 
   if (ndocc == 0 && nsocc == 0) {
-    ExEnv::err() << node0 << "There are no occupied orbitals; program exiting" << endl;
+    ExEnv::err0() << "There are no occupied orbitals; program exiting" << endl;
     abort();
     }
 
   if (nfzc > ndocc) {
-    ExEnv::err() << node0
+    ExEnv::err0()
          << "The number of frozen core orbitals exceeds the number" << endl
          << "of doubly occupied orbitals; program exiting" << endl;
     abort();
     }
 
   if (nfzv > noso - ndocc - nsocc) {
-    ExEnv::err() << node0
+    ExEnv::err0()
          << "The number of frozen virtual orbitals exceeds the number" << endl
          << "of unoccupied orbitals; program exiting" << endl;
     abort();
@@ -181,7 +182,7 @@ MBPT2::compute_hsos_v1()
   if (me < a_rest) a_number++;
 
   if (me == 0 && a_number < nsocc) { 
-    ExEnv::err() << "not enough memory allocated" << endl;
+    ExEnv::err0() << "not enough memory allocated" << endl;
     /* must have all socc's on node 0 for computation of socc_sum*/
     abort();
     }
@@ -193,7 +194,7 @@ MBPT2::compute_hsos_v1()
 
   a_vector = (int*) malloc(nproc*sizeof(int));
   if (!a_vector) {
-    ExEnv::err() << "could not allocate storage for a_vector" << endl;
+    ExEnv::errn() << "could not allocate storage for a_vector" << endl;
     abort();
     }
   for (i=0; i<nproc; i++) {
@@ -208,7 +209,7 @@ MBPT2::compute_hsos_v1()
     restart_orbital_v1_ = 0;
     }
   else if (restart_orbital_v1_) {
-    ExEnv::out() << node0 << indent
+    ExEnv::out0() << indent
          << scprintf("Restarting at orbital %d with partial energy %18.14f",
                      restart_orbital_v1_, restart_ecorr_)
          << endl;
@@ -241,38 +242,38 @@ MBPT2::compute_hsos_v1()
   msg_->min(ni);
   msg_->bcast(ni);
 
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Memory available per node:      " << mem_alloc << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Total memory used per node:     " << memused << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Memory required for one pass:   "
        << compute_v1_memory(nocc-restart_orbital_v1_,
                             nfuncmax, nbasis, noso, a_number, nshell,
                             ndocc, nsocc, nvir, nfzc, nfzv, nproc)
        << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Minimum memory required:        "
        << compute_v1_memory(1,
                             nfuncmax, nbasis, noso, a_number, nshell,
                             ndocc, nsocc, nvir, nfzc, nfzv, nproc)
        << " Bytes"
        << endl;
-  ExEnv::out() << node0 << indent
+  ExEnv::out0() << indent
        << "Batch size:                     " << ni
        << endl;
 
   if (ni < nsocc) {
-    ExEnv::out() << node0 << indent << "Not enough memory allocated to handle"
+    ExEnv::out0() << indent << "Not enough memory allocated to handle"
          << " SOCC orbs in first pass" << endl;
     abort();
     }
 
   if (ni < 1) {
-    ExEnv::out() << node0 << indent << "Not enough memory allocated" << endl;
+    ExEnv::out0() << indent << "Not enough memory allocated" << endl;
     abort();
     }
 
@@ -281,9 +282,9 @@ MBPT2::compute_hsos_v1()
   if (rest == 0) npass--;
 
   if (me == 0) {
-    ExEnv::out() << indent << " npass  rest  nbasis  nshell  nfuncmax"
+    ExEnv::out0() << indent << " npass  rest  nbasis  nshell  nfuncmax"
          << "  ndocc  nsocc  nvir  nfzc  nfzv" << endl;
-    ExEnv::out() << indent << scprintf("   %-4i   %-3i   %-5i   %-4i     %-3i"
+    ExEnv::out0() << indent << scprintf("   %-4i   %-3i   %-5i   %-4i     %-3i"
                      "     %-3i     %-3i   %-3i    %-3i   %-3i",
                      npass,rest,nbasis,nshell,nfuncmax,ndocc,nsocc,nvir,nfzc,nfzv)
          << endl;
@@ -301,7 +302,7 @@ MBPT2::compute_hsos_v1()
 
   evals_open = (double*) malloc((noso+nsocc-nfzc-nfzv)*sizeof(double));
   if (!evals_open) {
-    ExEnv::err() << "could not allocate storage for evals_open" << endl;
+    ExEnv::errn() << "could not allocate storage for evals_open" << endl;
     abort();
     }
 
@@ -310,7 +311,7 @@ MBPT2::compute_hsos_v1()
   RefSCMatrix Scf_Vec;
   eigen(evals, Scf_Vec, occ);
 
-  if (debug_>0) ExEnv::out() << node0 << indent << "eigvenvectors computed" << endl;
+  if (debug_>0) ExEnv::out0() << indent << "eigvenvectors computed" << endl;
   if (debug_>1) evals.print("eigenvalues");
   if (debug_>2) Scf_Vec.print("eigenvectors");
 
@@ -343,7 +344,7 @@ MBPT2::compute_hsos_v1()
     }
 
   // need the transpose of the vector
-  if (debug_>0) ExEnv::out() << node0 << indent << "allocating scf_vector" << endl;
+  if (debug_>0) ExEnv::out0() << indent << "allocating scf_vector" << endl;
   double **scf_vector = new double*[nbasis];
   double *scf_vector_dat = new double[(nocc+nvir)*nbasis];
   for (i=0; i<nbasis; i++) {
@@ -356,19 +357,19 @@ MBPT2::compute_hsos_v1()
   delete[] scf_vectort_dat;
 
   if (debug_>2) {
-    ExEnv::out() << node0 << indent << "Final eigenvalues and vectors" << endl;
+    ExEnv::out0() << indent << "Final eigenvalues and vectors" << endl;
     for (i=0; i<nocc+nvir; i++) {
-      ExEnv::out() << node0 << indent << evals_open[i];
+      ExEnv::out0() << indent << evals_open[i];
       for (j=0; j<nbasis; j++) {
-        ExEnv::out() << node0 << " " << scf_vector[j][i];
+        ExEnv::out0() << " " << scf_vector[j][i];
         }
-      ExEnv::out() << node0<< endl;
+      ExEnv::out0()<< endl;
       }
-    ExEnv::out() << node0 << endl;
+    ExEnv::out0() << endl;
     }
 
   /* allocate storage for integral arrays */
-  if (debug_>0) ExEnv::out() << node0 << indent << "allocating intermediates" << endl;
+  if (debug_>0) ExEnv::out0() << indent << "allocating intermediates" << endl;
   dim_ij = nocc*ni - ni*(ni-1)/2;
 
   trans_int1 = (double*) malloc(nfuncmax*nfuncmax*nbasis*ni*sizeof(double));
@@ -379,7 +380,7 @@ MBPT2::compute_hsos_v1()
   if (!(trans_int1 && trans_int2
         && (!a_number || trans_int3)
         && (!a_number || trans_int4_node) && trans_int4)){
-    ExEnv::err() << "could not allocate storage for integral arrays" << endl;
+    ExEnv::errn() << "could not allocate storage for integral arrays" << endl;
     abort();
     }
   if (nsocc) socc_sum  = (double*) malloc(nsocc*sizeof(double));
@@ -391,7 +392,7 @@ MBPT2::compute_hsos_v1()
   if (nsocc) bzerofast(mo_int_do_so_vir,ndocc*nsocc*(nvir-nsocc));
 
   // create the integrals object
-  if (debug_>0) ExEnv::out() << node0 << indent << "allocating integrals" << endl;
+  if (debug_>0) ExEnv::out0() << indent << "allocating integrals" << endl;
   integral()->set_storage(mem_remaining);
   Ref<TwoBodyInt> *tbint = new Ref<TwoBodyInt>[thr_->nthread()];
   for (ithread=0; ithread<thr_->nthread(); ithread++) {
@@ -407,7 +408,7 @@ MBPT2::compute_hsos_v1()
                                              scf_vector, tol, debug_);
     }
   
-  if (debug_>0) ExEnv::out() << node0 << indent << "beginning passes" << endl;
+  if (debug_>0) ExEnv::out0() << indent << "beginning passes" << endl;
 
 /**************************************************************************
 *    begin opt2 loops                                                     *
@@ -420,7 +421,7 @@ MBPT2::compute_hsos_v1()
 
   for (pass=0; pass<npass; pass++) {
     if (debug_) {
-      ExEnv::out() << node0 << indent << "Beginning pass " << pass << endl;
+      ExEnv::out0() << indent << "Beginning pass " << pass << endl;
       }
 
     int print_index = 0;
@@ -441,7 +442,7 @@ MBPT2::compute_hsos_v1()
 
         if (debug_ && (print_index++)%print_interval == 0) {
           lock->lock();
-          ExEnv::out() << scprintf("%d: (PQ|%d %d) %d%%",
+          ExEnv::outn() << scprintf("%d: (PQ|%d %d) %d%%",
                            me,R,S,(100*print_index)/work)
                << endl;
           lock->unlock();
@@ -542,7 +543,7 @@ MBPT2::compute_hsos_v1()
      * the individual integrals are not saved here, only the sums are kept */
 
     if (debug_) {
-      ExEnv::out() << node0 << indent << "Beginning 4. quarter transform" << endl;
+      ExEnv::out0() << indent << "Beginning 4. quarter transform" << endl;
       }
 
     tim_enter("4. quart. tr.");
@@ -723,12 +724,12 @@ MBPT2::compute_hsos_v1()
     if (nsocc == 0 && npass > 1 && pass < npass - 1) {
       double passe = ecorr_opt2;
       msg_->sum(passe);
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << "Partial correlation energy for pass " << pass << ":" << endl;
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << scprintf("  restart_ecorr   = %18.14f", passe)
            << endl;
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << scprintf("  restart_orbital_v1 = %d", ((pass+1) * ni))
            << endl;
       }
@@ -804,25 +805,25 @@ MBPT2::compute_hsos_v1()
 
     /* print out various energies etc.*/
 
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << "Number of shell quartets for which AO integrals would" << endl
          << indent
          << "have been computed without bounds checking: "
          << npass*nshell*nshell*(nshell+1)*(nshell+1)/4 << endl;
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << "Number of shell quartets for which AO integrals" << endl
          << indent << "were computed: " << aoint_computed << endl;
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("ROHF energy [au]:                  %17.12lf\n", escf);
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("OPT1 energy [au]:                  %17.12lf\n", eopt1);
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("OPT2 second order correction [au]: %17.12lf\n", ecorr_opt2);
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("OPT2 energy [au]:                  %17.12lf\n", eopt2);
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("ZAPT2 correlation energy [au]:     %17.12lf\n", ecorr_zapt2);
-    ExEnv::out() << indent
+    ExEnv::out0() << indent
          << scprintf("ZAPT2 energy [au]:                 %17.12lf\n", ezapt2);
     }
   msg_->bcast(eopt1);
@@ -846,7 +847,7 @@ MBPT2::compute_hsos_v1()
     }
   else {
     if (!(!method_ || !strcmp(method_,"zapt"))) {
-      ExEnv::out() << node0 << indent
+      ExEnv::out0() << indent
            << "MBPT2: bad method: " << method_ << ", using zapt" << endl;
       }
     set_energy(ezapt2);
