@@ -33,6 +33,7 @@
 #include <sstream>
 #include <util/misc/string.h>
 
+#include <util/class/scexception.h>
 #include <util/misc/formio.h>
 #include <util/misc/exenv.h>
 #include <util/state/stateio.h>
@@ -50,7 +51,7 @@ using namespace sc;
  --------------------------------*/
 
 static ClassDesc MBPT2_R12_cd(
-  typeid(MBPT2_R12),"MBPT2_R12",1,"public MBPT2",
+  typeid(MBPT2_R12),"MBPT2_R12",4,"public MBPT2",
   0, create<MBPT2_R12>, create<MBPT2_R12>);
 
 MBPT2_R12::MBPT2_R12(StateIn& s):
@@ -61,10 +62,21 @@ MBPT2_R12::MBPT2_R12(StateIn& s):
   r12ap_energy_ << SavableState::restore_state(s);
   r12b_energy_ << SavableState::restore_state(s);
   aux_basis_ << SavableState::restore_state(s);
+  vir_basis_ << SavableState::restore_state(s);
+  if (s.version(::class_desc<MBPT2_R12>()) >= 3) {
+    int gbc; s.get(gbc); gbc_ = (bool)gbc;
+    int ebc; s.get(ebc); ebc_ = (bool)ebc;
+  }
+  if (s.version(::class_desc<MBPT2_R12>()) >= 2) {
+    int absmethod; s.get(absmethod); abs_method_ = (LinearR12::ABSMethod)absmethod;
+  }
   int stdapprox; s.get(stdapprox); stdapprox_ = (LinearR12::StandardApproximation) stdapprox;
   int spinadapted; s.get(spinadapted); spinadapted_ = (bool)spinadapted;
+  if (s.version(::class_desc<MBPT2_R12>()) >= 4) {
+    int include_mp1; s.get(include_mp1); include_mp1_ = static_cast<bool>(include_mp1);
+  }
   int r12ints_method; s.get(r12ints_method); r12ints_method_ = (R12IntEvalInfo::StoreMethod) r12ints_method;
-  s.getstring(r12ints_file_);
+  s.get(r12ints_file_);
   s.get(mp2_corr_energy_);
   s.get(r12_corr_energy_);
 }
@@ -89,10 +101,52 @@ MBPT2_R12::MBPT2_R12(const Ref<KeyVal>& keyval):
   if (aux_basis_.pointer() == NULL)
     aux_basis_ = basis();
 
-  // Default method is MBPT2-R12/A
-  char *sa_string = keyval->pcharvalue("stdapprox",KeyValValuepchar("A"));
-  if (sa_string == NULL)
-    sa_string = strdup("");
+  vir_basis_ = require_dynamic_cast<GaussianBasisSet*>(
+    keyval->describedclassvalue("vir_basis").pointer(),
+    "MBPT2_R12::MBPT2_R12\n"
+    );
+  if (vir_basis_.pointer() == NULL)
+    vir_basis_ = basis();
+
+  // Default is to assume GBC
+  gbc_ = keyval->booleanvalue("gbc",KeyValValueboolean((int)true));
+  // Default is to assume EBC
+  ebc_ = keyval->booleanvalue("ebc",KeyValValueboolean((int)true));
+  
+  // For now the default is to use the old ABS method, of Klopper and Samson
+  char* abs_method_str = keyval->pcharvalue("abs_method",KeyValValuepchar("ABS"));
+  if ( !strcmp(abs_method_str,"KS") ||
+       !strcmp(abs_method_str,"ks") ||
+       !strcmp(abs_method_str,"ABS") ||
+       !strcmp(abs_method_str,"abs") ) {
+    abs_method_ = LinearR12::ABS_ABS;
+  }
+  else if ( !strcmp(abs_method_str,"KS+") ||
+	    !strcmp(abs_method_str,"ks+") ||
+            !strcmp(abs_method_str,"ABS+") ||
+	    !strcmp(abs_method_str,"abs+") ) {
+    abs_method_ = LinearR12::ABS_ABSPlus;
+  }
+  else if ( !strcmp(abs_method_str,"EV") ||
+	    !strcmp(abs_method_str,"ev") ||
+            !strcmp(abs_method_str,"CABS") ||
+	    !strcmp(abs_method_str,"cabs") ) {
+    abs_method_ = LinearR12::ABS_CABS;
+  }
+  else if ( !strcmp(abs_method_str,"EV+") ||
+	    !strcmp(abs_method_str,"ev+") ||
+            !strcmp(abs_method_str,"CABS+") ||
+	    !strcmp(abs_method_str,"cabs+") ) {
+    abs_method_ = LinearR12::ABS_CABSPlus;
+  }
+  else {
+    delete[] abs_method_str;
+    throw std::runtime_error("MBPT2_R12::MBPT2_R12 -- unrecognized value for abs_method");
+  }
+  delete[] abs_method_str;
+
+  // Default method is MBPT2-R12/A'
+  char *sa_string = keyval->pcharvalue("stdapprox",KeyValValuepchar("A'"));
   if ( !strcmp(sa_string,"A") ||
        !strcmp(sa_string,"a") ) {
     stdapprox_ = LinearR12::StdApprox_A;
@@ -104,58 +158,82 @@ MBPT2_R12::MBPT2_R12(const Ref<KeyVal>& keyval):
     stdapprox_ = LinearR12::StdApprox_Ap;
   }
   else if ( !strcmp(sa_string,"B") ||
-	    !strcmp(sa_string,"b") )
-    throw std::runtime_error("MBPT2_R12: MP2-R12/B energy is not implemented yet");
-
-
-  // Default is to use spin-adapted algorithm
-  spinadapted_ = true;
-  spinadapted_ = keyval->booleanvalue("spinadapted");
-
-  // Determine how to store MO integrals
-  char* r12ints_str = 0;
-  r12ints_str = keyval->pcharvalue("r12ints");
-  if (!r12ints_str) {
-    r12ints_method_ = R12IntEvalInfo::mem_posix;
+	    !strcmp(sa_string,"b") ) {
+    delete[] sa_string;
+    throw std::runtime_error("MBPT2_R12::MBPT2_R12() -- MP2-R12/B energy is not implemented yet");
   }
   else {
-    if (!strcmp(r12ints_str,"mem")) {
-      r12ints_method_ = R12IntEvalInfo::mem_only;
-    }
-#if HAVE_MPIIO
-    else if (!strcmp(r12ints_str,"mem-mpi")) {
-      r12ints_method_ = R12IntEvalInfo::mem_mpi;
-    }
-    else if (!strcmp(r12ints_str,"mpi")) {
-      r12ints_method_ = R12IntEvalInfo::mpi;
-    }
-#else
-    else if ( !strcmp(r12ints_str,"mem-mpi") ||
-	      !strcmp(r12ints_str,"mpi") ) {
-      throw std::runtime_error("MBPT2_R12::MBPT2_R12 -- specified keyword r12ints is not valid in this environment (no MPI-I/O detected)");
-    }
-#endif
-    else if (!strcmp(r12ints_str,"mem-posix")) {
-      r12ints_method_ = R12IntEvalInfo::mem_posix;
-    }
-    else if (!strcmp(r12ints_str,"posix")) {
-      r12ints_method_ = R12IntEvalInfo::posix;
-    }
-    else
-      throw std::runtime_error("MBPT2_R12::MBPT2_R12 -- invalid value for keyword r12ints");
-    delete[] r12ints_str;
+    delete[] sa_string;
+    throw std::runtime_error("MBPT2_R12::MBPT2_R12() -- unrecognized value for stdapprox");
   }
 
-  // Get the filename to store the integrals
-  r12ints_file_ = 0;
-  r12ints_file_ = keyval->pcharvalue("r12ints_file");
-  if (!r12ints_file_) {
-    // Since SCFormIO::fileext_to_filename uses new char[] and KeyVal::pcharvalue uses malloc
-    // need to copy the obtained string using strdup first
-    char* filename = SCFormIO::fileext_to_filename(".r12ints.dat");
-    r12ints_file_ = strdup(filename);
-    delete[] filename;
+  // Default is to use spin-adapted algorithm
+  spinadapted_ = keyval->booleanvalue("spinadapted",KeyValValueboolean((int)true));
+
+  // Default is to not compute MP1 energy
+  include_mp1_ = keyval->booleanvalue("include_mp1",KeyValValueboolean((int)false));
+
+  // Klopper and Samson's ABS method is only implemented for certain "old" methods
+  // Make sure that the ABS method is available for the requested MP2-R12 energy
+  const bool must_use_cabs = (!gbc_ || !ebc_ || stdapprox_ == LinearR12::StdApprox_B ||
+                              !basis()->equiv(vir_basis_));
+  if (must_use_cabs &&
+      (abs_method_ == LinearR12::ABS_ABS || abs_method_ == LinearR12::ABS_ABSPlus))
+    throw std::runtime_error("MBPT2_R12::MBPT2_R12() -- abs_method must be set to cabs or cabs+ for this MP2-R12 method");
+    
+  // Standard approximation A is not valid when gbc_ = false or ebc_ = false
+  if ( (!gbc_ || !ebc_) && stdapprox_ == LinearR12::StdApprox_A )
+    throw std::runtime_error("MBPT2_R12::MBPT2_R12() -- stdapprox=A is not valid when gbc_ = false or ebc_ = false");
+    
+
+  // Determine how to store MO integrals
+  char *r12ints_str = keyval->pcharvalue("r12ints",KeyValValuepchar("mem-posix"));
+  if (!strcmp(r12ints_str,"mem")) {
+    r12ints_method_ = R12IntEvalInfo::mem_only;
   }
+#if HAVE_MPIIO
+  else if (!strcmp(r12ints_str,"mem-mpi")) {
+    r12ints_method_ = R12IntEvalInfo::mem_mpi;
+  }
+  else if (!strcmp(r12ints_str,"mpi")) {
+    r12ints_method_ = R12IntEvalInfo::mpi;
+  }
+#else
+  else if ( !strcmp(r12ints_str,"mem-mpi") ||
+	    !strcmp(r12ints_str,"mpi") ) {
+    throw std::runtime_error("MBPT2_R12::MBPT2_R12 -- the value for keyword r12ints is not valid in this environment (no MPI-I/O detected)");
+  }
+#endif
+  else if (!strcmp(r12ints_str,"mem-posix")) {
+    r12ints_method_ = R12IntEvalInfo::mem_posix;
+  }
+  else if (!strcmp(r12ints_str,"posix")) {
+    r12ints_method_ = R12IntEvalInfo::posix;
+  }
+  else {
+    delete[] r12ints_str;
+    throw std::runtime_error("MBPT2_R12::MBPT2_R12 -- invalid value for keyword r12ints");
+  }
+  delete[] r12ints_str;
+
+  // Make sure that integrals storage method is compatible with standard approximation
+  // If it's a MP2-R12/B calculation or EBC or GBC are not assumed then must use disk
+  const bool must_use_disk = (!gbc_ || !ebc_ || stdapprox_ == LinearR12::StdApprox_B);
+  if (must_use_disk && r12ints_method_ == R12IntEvalInfo::mem_only)
+    throw std::runtime_error("MBPT2_R12::MBPT2_R12 -- r12ints=mem is only possible for MP2-R12/A and MP2-R12/A' (GBC+EBC) methods");
+  if (must_use_disk) {
+    if (r12ints_method_ == R12IntEvalInfo::mem_posix)
+      r12ints_method_ = R12IntEvalInfo::posix;
+#if HAVE_MPIIO
+    if (r12ints_method_ == R12IntEvalInfo::mem_mpi)
+      r12ints_method_ = R12IntEvalInfo::mpi;
+#endif
+  }
+
+  // Get the prefix for the filename to store the integrals
+  std::ostringstream oss;
+  oss << SCFormIO::default_basename() << ".r12ints";
+  r12ints_file_ = keyval->stringvalue("r12ints_file",KeyValValuestring(oss.str()));
 
   r12eval_ = 0;
   r12a_energy_ = 0;
@@ -163,6 +241,11 @@ MBPT2_R12::MBPT2_R12(const Ref<KeyVal>& keyval):
   r12b_energy_ = 0;
   mp2_corr_energy_ = 0.0;
   r12_corr_energy_ = 0.0;
+
+  twopdm_grid_aa_ = require_dynamic_cast<TwoBodyGrid*>(keyval->describedclassvalue("twopdm_grid_aa").pointer(),
+                                               "MBPT2_R12::MBPT2_R12\n");
+  twopdm_grid_ab_ = require_dynamic_cast<TwoBodyGrid*>(keyval->describedclassvalue("twopdm_grid_ab").pointer(),
+                                               "MBPT2_R12::MBPT2_R12\n");
 }
 
 MBPT2_R12::~MBPT2_R12()
@@ -171,7 +254,6 @@ MBPT2_R12::~MBPT2_R12()
   r12a_energy_ = 0;
   r12ap_energy_ = 0;
   r12b_energy_ = 0;
-  free(r12ints_file_);
 }
 
 void
@@ -183,10 +265,15 @@ MBPT2_R12::save_data_state(StateOut& s)
   SavableState::save_state(r12ap_energy_.pointer(),s);
   SavableState::save_state(r12b_energy_.pointer(),s);
   SavableState::save_state(aux_basis_.pointer(),s);
+  SavableState::save_state(vir_basis_.pointer(),s);
+  s.put((int)gbc_);
+  s.put((int)ebc_);
+  s.put((int)abs_method_);
   s.put((int)stdapprox_);
   s.put((int)spinadapted_);
+  s.put((int)include_mp1_);
   s.put((int)r12ints_method_);
-  s.putstring(r12ints_file_);
+  s.put(r12ints_file_);
 
   s.put(mp2_corr_energy_);
   s.put(r12_corr_energy_);
@@ -197,6 +284,22 @@ MBPT2_R12::print(ostream&o) const
 {
   o << indent << "MBPT2_R12:" << endl;
   o << incindent;
+  o << indent << "GBC assumed: " << (gbc_ ? "true" : "false") << endl;
+  o << indent << "EBC assumed: " << (ebc_ ? "true" : "false") << endl;
+  switch(abs_method_) {
+  case LinearR12::ABS_ABS :
+    o << indent << "ABS method variant: ABS  (Klopper and Samson)" << endl;
+    break;
+  case LinearR12::ABS_ABSPlus :
+    o << indent << "ABS method variant: ABS+ (Klopper and Samson using the union of OBS and ABS for RI)" << endl;
+    break;
+  case LinearR12::ABS_CABS :
+    o << indent << "ABS method variant: CABS  (Valeev)" << endl;
+    break;
+  case LinearR12::ABS_CABSPlus :
+    o << indent << "ABS method variant: CABS+ (Valeev using the union of OBS and ABS for RI)" << endl;
+    break;
+  }
   switch (stdapprox_) {
     case LinearR12::StdApprox_A :
       o << indent << "Standard Approximation: A" << endl;
@@ -208,7 +311,11 @@ MBPT2_R12::print(ostream&o) const
       o << indent << "Standard Approximation: B" << endl;
     break;
   }
+
   o << indent << "Spin-adapted algorithm: " << (spinadapted_ ? "true" : "false") << endl;
+  if (!vir_basis_->equiv(basis()))
+    o << indent << "Compute MP1 energy: " << (include_mp1_ ? "true" : "false") << endl;
+
   char* r12ints_str;
   switch (r12ints_method_) {
   case R12IntEvalInfo::mem_only:
@@ -228,9 +335,11 @@ MBPT2_R12::print(ostream&o) const
   }
   o << indent << "How to Store Transformed Integrals: " << r12ints_str << endl << endl;
   free(r12ints_str);
-  o << indent << "Transformed Integrals file: " << r12ints_file_ << endl << endl;
-  o << indent << "Auxiliary Basis:" << endl;
+  o << indent << "Transformed Integrals file suffix: " << r12ints_file_ << endl << endl;
+  o << indent << "Auxiliary Basis Set (ABS):" << endl;
   o << incindent; aux_basis_->print(o); o << decindent << endl;
+  o << indent << " Virtuals Basis Set (VBS):" << endl;
+  o << incindent; vir_basis_->print(o); o << decindent << endl;
   MBPT2::print(o);
   o << decindent;
 }
@@ -248,6 +357,21 @@ MBPT2_R12::density()
 void
 MBPT2_R12::compute()
 {
+  if (std::string(reference_->integral()->class_name())
+      !=integral()->class_name()) {
+      FeatureNotImplemented ex(
+          "cannot use a reference with a different Integral specialization",
+          __FILE__, __LINE__, class_desc());
+      try {
+          ex.elaborate()
+              << "reference uses " << reference_->integral()->class_name()
+              << " but this object uses " << integral()->class_name()
+              << std::endl;
+        }
+      catch (...) {}
+      throw ex;
+    }
+
   init_variables_();
   reference_->set_desired_value_accuracy(desired_value_accuracy()
                                          / ref_to_mp2r12_acc_);
@@ -295,6 +419,38 @@ MBPT2_R12::aux_basis() const
 
 /////////////////////////////////////////////////////////////////////////////
 
+Ref<GaussianBasisSet>
+MBPT2_R12::vir_basis() const
+{
+  return vir_basis_;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+bool
+MBPT2_R12::gbc() const
+{
+  return gbc_;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+bool
+MBPT2_R12::ebc() const
+{
+  return ebc_;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+LinearR12::ABSMethod
+MBPT2_R12::abs_method() const
+{
+  return abs_method_;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 LinearR12::StandardApproximation
 MBPT2_R12::stdapprox() const
 {
@@ -319,10 +475,10 @@ MBPT2_R12::r12ints_method() const
 
 /////////////////////////////////////////////////////////////////////////////
 
-char*
+const std::string&
 MBPT2_R12::r12ints_file() const
 {
-  return strdup(r12ints_file_);
+  return r12ints_file_;
 }
 
 /////////////////////////////////////////////////////////////////////////////
