@@ -41,19 +41,62 @@ using namespace sc;
 
 ///////////////////////////////////////////////////////////////
 
-R12IntsAcc_MPIIOFile::R12IntsAcc_MPIIOFile(Ref<MemoryGrp>& mem, const char* filename, int nte_types, int nbasis1, int nbasis2,
-					   int nocc, int nfzc, bool restart) :
-    R12IntsAcc(nte_types, nbasis1, nbasis2, nocc, nfzc), datafile_(MPI_FILE_NULL)
+static ClassDesc R12IntsAcc_MPIIOFile_cd(
+  typeid(R12IntsAcc_MPIIOFile),"R12IntsAcc_MPIIOFile",1,"public R12IntsAcc",
+  0, 0, 0);
+
+R12IntsAcc_MPIIOFile::R12IntsAcc_MPIIOFile(Ref<MemoryGrp>& mem, const char* filename, int nte_types,
+                                           int ni, int nj, int nx, int ny) :
+    R12IntsAcc(nte_types, ni, nj, nx, ny), datafile_(MPI_FILE_NULL)
 {
   mem_ = mem;
+  filename_ = strdup(filename);
+
+  init(false);
+}
+
+R12IntsAcc_MPIIOFile::R12IntsAcc_MPIIOFile(StateIn& si) :
+  SavableState(si), R12IntsAcc(si)
+{
+  mem_ = MemoryGrp::get_default_memorygrp();
+  si.getstring(filename_);
+  
+  init(true);
+}
+
+R12IntsAcc_MPIIOFile::~R12IntsAcc_MPIIOFile()
+{
+  for(int i=0;i<ni_;i++)
+    for(int j=0;j<nj_;j++) {
+      int ij = ij_index(i,j);
+      for(int oper_type=0; oper_type<num_te_types(); oper_type++)
+	if (pairblk_[ij].ints_[oper_type] != NULL) {
+	  ExEnv::outn() << indent << mem_->me() << ": i = " << i << " j = " << j << " oper_type = " << oper_type << endl;
+	  throw std::runtime_error("Logic error: R12IntsAcc_MPIIOFile::~ : some nonlocal blocks have not been released!");
+	}
+    }
+  delete[] pairblk_;
+  free(filename_);
+}
+
+void
+R12IntsAcc_MPIIOFile::save_data_state(StateOut& so)
+{
+  R12IntsAcc::save_data_state(so);
+  so.putstring(filename_);
+}
+
+void
+R12IntsAcc_MPIIOFile::init(bool restart)
+{
   int errcod;
   errcod = MPI_Comm_size(MPI_COMM_WORLD, &nproc_);
-  nints_per_block_ = nbasis__2_*num_te_types();
+  nints_per_block_ = nxy_*num_te_types();
 
-  pairblk_ = new struct PairBlkInfo[nocc_act_*nocc_act_];
+  pairblk_ = new struct PairBlkInfo[ni_*nj_];
   int i, j, ij;
-  for(i=0,ij=0;i<nocc_act_;i++)
-    for(j=0;j<nocc_act_;j++,ij++) {
+  for(i=0,ij=0;i<ni_;i++)
+    for(j=0;j<nj_;j++,ij++) {
       pairblk_[ij].ints_[eri] = NULL;
       pairblk_[ij].ints_[r12] = NULL;
       pairblk_[ij].ints_[r12t1] = NULL;
@@ -65,13 +108,7 @@ R12IntsAcc_MPIIOFile::R12IntsAcc_MPIIOFile(Ref<MemoryGrp>& mem, const char* file
       pairblk_[ij].offset_ = (MPI_Offset)ij*blocksize_;
     }
 
-  // Create the file
-  icounter_ = 0;
-  filename_ = strdup(filename);
-
-  //
-  // Try opening the file
-  //
+  // Try opening/creating the file
   int amode;
   if (!restart)
     amode = MPI_MODE_CREATE | MPI_MODE_DELETE_ON_CLOSE | MPI_MODE_WRONLY;
@@ -85,22 +122,6 @@ R12IntsAcc_MPIIOFile::R12IntsAcc_MPIIOFile(Ref<MemoryGrp>& mem, const char* file
   check_error_code_(errcod);
 }
 
-R12IntsAcc_MPIIOFile::~R12IntsAcc_MPIIOFile()
-{
-  for(int i=0;i<nocc_act_;i++)
-    for(int j=0;j<nocc_act_;j++) {
-      int ij = ij_index(i,j);
-      for(int oper_type=0; oper_type<num_te_types(); oper_type++)
-	if (pairblk_[ij].ints_[oper_type] != NULL) {
-	  ExEnv::outn() << indent << mem_->me() << ": i = " << i << " j = " << j << " oper_type = " << oper_type << endl;
-	  throw std::runtime_error("Logic error: R12IntsAcc_MPIIOFile::~ : some nonlocal blocks have not been released!");
-	}
-    }
-  delete[] pairblk_;
-  free(filename_);
-}
-
-
 void
 R12IntsAcc_MPIIOFile::check_error_code_(int errcod) const
 {
@@ -138,6 +159,12 @@ R12IntsAcc_MPIIOFile::commit()
   mem_->sync();
   mem_->deactivate();
   R12IntsAcc::commit();
+}
+
+void
+R12IntsAcc_MPIIOFile::activate()
+{
+  R12IntsAcc::activate();
   int errcod = MPI_File_open(MPI_COMM_WORLD, filename_, MPI_MODE_RDONLY | MPI_MODE_DELETE_ON_CLOSE, MPI_INFO_NULL, &datafile_);
   check_error_code_(errcod);
 }
@@ -148,6 +175,7 @@ R12IntsAcc_MPIIOFile::deactivate()
   mem_->activate();
   int errcod = MPI_File_close(&datafile_);
   check_error_code_(errcod);
+  R12IntsAcc::deactivate();
 }
 
 void
@@ -168,9 +196,18 @@ R12IntsAcc_MPIIOFile::release_pair_block(int i, int j, tbint_type oper_type)
 
 ///////////////////////////////////////////////////////////////
 
-R12IntsAcc_MPIIOFile_Ind::R12IntsAcc_MPIIOFile_Ind(Ref<MemoryGrp>& mem, const char* filename, int num_te_types, int nbasis1, int nbasis2,
-						   int nocc, int nfzc, bool restart) :
-  R12IntsAcc_MPIIOFile(mem,filename,num_te_types,nbasis1,nbasis2,nocc,nfzc,restart)
+static ClassDesc R12IntsAcc_MPIIOFile_Ind_cd(
+  typeid(R12IntsAcc_MPIIOFile_Ind),"R12IntsAcc_MPIIOFile_Ind",1,"public R12IntsAcc",
+  0, 0, create<R12IntsAcc_MPIIOFile_Ind>);
+
+R12IntsAcc_MPIIOFile_Ind::R12IntsAcc_MPIIOFile_Ind(StateIn& si) :
+  SavableState(si), R12IntsAcc_MPIIOFile(si)
+{
+}
+
+R12IntsAcc_MPIIOFile_Ind::R12IntsAcc_MPIIOFile_Ind(Ref<MemoryGrp>& mem, const char* filename, int num_te_types,
+                                                   int ni, int nj, int nx, int ny) :
+  R12IntsAcc_MPIIOFile(mem,filename,num_te_types,ni,nj,nx,ny)
 {
 }
 
@@ -179,7 +216,13 @@ R12IntsAcc_MPIIOFile_Ind::~R12IntsAcc_MPIIOFile_Ind()
 }
 
 void
-R12IntsAcc_MPIIOFile_Ind::store_memorygrp(Ref<MemoryGrp>& mem, int ni)
+R12IntsAcc_MPIIOFile_Ind::save_data_state(StateOut&so)
+{
+  R12IntsAcc_MPIIOFile::save_data_state(so);
+}
+
+void
+R12IntsAcc_MPIIOFile_Ind::store_memorygrp(Ref<MemoryGrp>& mem, int ni, const size_t blksize)
 {
   if (committed_) {
     ExEnv::out0() << "R12IntsAcc_MPIIOFile_Ind::store_memorygrp(mem,ni) called after all data has been committed" << endl;
@@ -191,17 +234,21 @@ R12IntsAcc_MPIIOFile_Ind::store_memorygrp(Ref<MemoryGrp>& mem, int ni)
       "mem != R12IntsAcc_MemoryGrp::mem_" << endl;
     abort();
   }
-  else if (ni > nocc_act_) {
+  else if (ni > ni_) {
     ExEnv::out0() << "R12IntsAcc_MPIIOFile_Ind::store_memorygrp(mem,ni) called with invalid argument:" << endl <<
-      "ni > R12IntsAcc_MPIIOFile_Ind::nocc_act_" << endl;
+      "ni > R12IntsAcc_MPIIOFile_Ind::ni_" << endl;
     abort();
   }
-  else if (icounter_ + ni > nocc_act_) {
+  else if (next_orbital() + ni > ni_) {
     ExEnv::out0() << "R12IntsAcc_MPIIOFile_Ind::store_memorygrp(mem,ni) called with invalid argument:" << endl <<
-      "ni+icounter_ > R12IntsAcc_MPIIOFile_Ind::nocc_act_" << endl;
+      "ni+next_orbital() > R12IntsAcc_MPIIOFile_Ind::ni_" << endl;
     abort();
   }
   else {
+    size_t blksize_memgrp = blksize;
+    if (blksize_memgrp == 0)
+      blksize_memgrp = blksize_;
+
     // Now do some extra work to figure layout of data in MemoryGrp
     // Compute global offsets to each processor's data
     int i,j,ij;
@@ -213,25 +260,28 @@ R12IntsAcc_MPIIOFile_Ind::store_memorygrp(Ref<MemoryGrp>& mem, int ni)
     check_error_code_(errcod);
     
     for (int i=0; i<ni; i++)
-      for (int j=0; j<nocc_act_; j++) {
+      for (int j=0; j<nj_; j++) {
 	int ij = ij_index(i,j);
 	int proc = ij%nproc;
         if (proc != me) continue;
 	int local_ij_index = ij/nproc;
-        double *data = (double *) mem->localdata() + nbasis__2_*num_te_types()*local_ij_index;
-        
-        int IJ = ij_index(i+icounter_,j);
-        int errcod = MPI_File_seek(datafile_, pairblk_[IJ].offset_, MPI_SEEK_SET);
-        check_error_code_(errcod);
-        MPI_Status status;
-        errcod = MPI_File_write(datafile_, (void *)data, nints_per_block_, MPI_DOUBLE, &status);
-        check_error_code_(errcod);
+        double *data = (double *) ((size_t)mem->localdata() + blksize_memgrp*num_te_types()*local_ij_index);
+        for(int te_type=0; te_type < num_te_types(); te_type++) {
+          int IJ = ij_index(i+next_orbital(),j);
+          int errcod = MPI_File_seek(datafile_, pairblk_[IJ].offset_+(MPI_Offset)te_type*blksize_, MPI_SEEK_SET);
+          check_error_code_(errcod);
+          MPI_Status status;
+          errcod = MPI_File_write(datafile_, (void *)data, nxy_, MPI_DOUBLE, &status);
+          check_error_code_(errcod);
+          data = (double*) ((size_t) data + blksize_memgrp);
+        }
       }
     // Close the file and update the i counter
     errcod = MPI_File_close(&datafile_);
     check_error_code_(errcod);
-    icounter_ += ni;
   }
+  
+  inc_next_orbital(ni);
 }
 
 double *
@@ -244,9 +294,9 @@ R12IntsAcc_MPIIOFile_Ind::retrieve_pair_block(int i, int j, tbint_type oper_type
     MPI_Offset offset = pb->offset_ + (MPI_Offset)oper_type*blksize_;
     int errcod = MPI_File_seek(datafile_, offset, MPI_SEEK_SET);
     check_error_code_(errcod);
-    double *buffer = new double[nbasis__2_];
+    double *buffer = new double[nxy_];
     MPI_Status status;
-    errcod = MPI_File_read(datafile_, (void *)buffer, nbasis__2_, MPI_DOUBLE, &status);
+    errcod = MPI_File_read(datafile_, (void *)buffer, nxy_, MPI_DOUBLE, &status);
     check_error_code_(errcod);
     pb->ints_[oper_type] = buffer;
   }
