@@ -55,7 +55,6 @@ class R12IntsAcc_MPIIOFile: public R12IntsAcc {
     Ref<MemoryGrp> mem_; // The MemoryGrp associated with this accumulator
     int nproc_;
     size_t nints_per_block_;  // number of integrals per block = num_te_types*nbasis__2_
-    int icounter_;      // the number of i's for which blocks have been written to 
     char *filename_;
     MPI_File datafile_;
 
@@ -67,17 +66,28 @@ class R12IntsAcc_MPIIOFile: public R12IntsAcc {
 
     /// Utility function to check MPI I/O error codes.
     void check_error_code_(int errcod) const;
+    // Initialization tasks common to all constructors
+    void init(bool restart);
+    
+    /// total number of tasks
+    int ntasks() const { return mem_->n(); }
+    /// ID of this task
+    int taskid() const { return mem_->me(); }
     
   public:
-    R12IntsAcc_MPIIOFile(Ref<MemoryGrp>& mem, const char *filename, int num_te_types, int nbasis1, int nbasis2,
-			 int nocc, int nfzc, bool restart);
+    R12IntsAcc_MPIIOFile(Ref<MemoryGrp>& mem, const char *filename, int num_te_types,
+                         int ni, int nj, int nx, int ny);
+    R12IntsAcc_MPIIOFile(StateIn&);
     ~R12IntsAcc_MPIIOFile();
+    void save_data_state(StateOut&);
 
     /// Stores an ij pair block of integrals to the file
     void store_pair_block(int i, int j, double *ints);
-    /// Commit the content of the accumulator for reading - deactivate the associated MemoryGrp
-    /// This is a collective operation
+    /** Commit the content of the accumulator for reading - deactivate the associated MemoryGrp
+        and activate the accumulator. This is a collective operation. */
     void commit();
+    /// Call when ready to read content
+    void activate();
     /// Done reading content - activate the associated MemoryGrp
     /// This is a collective operation
     void deactivate();
@@ -93,7 +103,7 @@ class R12IntsAcc_MPIIOFile: public R12IntsAcc {
     bool can_restart() const { return true; };
 
     // Utility functions
-    int ij_index(int i, int j) const { return i*nocc_act_ + j; };
+    int ij_index(int i, int j) const { return i*nj_ + j; };
 };
 
 //////////////////////////////////////////////////////////////////////////////
@@ -107,16 +117,21 @@ class R12IntsAcc_MPIIOFile: public R12IntsAcc {
 class R12IntsAcc_MPIIOFile_Ind: public R12IntsAcc_MPIIOFile {
 
   public:
-    R12IntsAcc_MPIIOFile_Ind(Ref<MemoryGrp>& mem, const char *filename, int num_te_types, int nbasis1, int nbasis2,
-			     int nocc, int nfzc, bool restart);
+    R12IntsAcc_MPIIOFile_Ind(Ref<MemoryGrp>& mem, const char *filename, int num_te_types,
+                             int ni, int nj, int nx, int ny);
+    R12IntsAcc_MPIIOFile_Ind(StateIn&);
     ~R12IntsAcc_MPIIOFile_Ind();
+    void save_data_state(StateOut&);
 
-    /// Stores all pair block of integrals held in mem.
-    /// By default blocks are appended to the end of the same file, i.e.
-    /// they are assumed to have come from consecutive passes of
-    /// the same transformation
-    /// This is a collective operation
-    void store_memorygrp(Ref<MemoryGrp>& mem, int ni);
+    /** Stores all pair block of integrals held in mem.
+        By default blocks are appended to the end of the same file, i.e.
+        they are assumed to have come from consecutive passes of
+        the same transformation.
+        This is a collective operation.
+        See documentation for R12IntsAcc::store_memorygrp()
+        for more info.
+      */
+    void store_memorygrp(Ref<MemoryGrp>& mem, int ni, const size_t blksize = 0);
     /// Retrieves an ij pair block of integrals from the file
     double* retrieve_pair_block(int i, int j, tbint_type oper_type);
 };
