@@ -30,6 +30,7 @@
 #endif
 
 #include <stdexcept>
+#include <util/class/scexception.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -40,21 +41,73 @@
 #include <util/misc/exenv.h>
 #include <chemistry/qc/mbptr12/r12ia_node0file.h>
 
+#define CREATE_FILE_ON_NODE0_ONLY 1
+
 using namespace std;
 using namespace sc;
 
 ///////////////////////////////////////////////////////////////
 
+static ClassDesc R12IntsAcc_Node0File_cd(
+  typeid(R12IntsAcc_Node0File),"R12IntsAcc_Node0File",1,"public R12IntsAcc",
+  0, 0, create<R12IntsAcc_Node0File>);
+
 R12IntsAcc_Node0File::R12IntsAcc_Node0File(Ref<MemoryGrp>& mem, const char* filename, int num_te_types,
-					   int nbasis1, int nbasis2, int nocc, int nfzc, bool restart) :
-  R12IntsAcc(num_te_types, nbasis1, nbasis2, nocc, nfzc)
+					   int ni, int nj, int nx, int ny) :
+  R12IntsAcc(num_te_types, ni, nj, nx, ny)
 {
   mem_ = mem;
+  filename_ = strdup(filename);
+  
+  init(false);
+}
 
-  pairblk_ = new struct PairBlkInfo[nocc_act_*nocc_act_];
+R12IntsAcc_Node0File::R12IntsAcc_Node0File(StateIn& si) :
+  R12IntsAcc(si)
+{
+  mem_ = MemoryGrp::get_default_memorygrp();
+  si.getstring(filename_);
+  
+  init(true);
+}
+
+R12IntsAcc_Node0File::~R12IntsAcc_Node0File()
+{
+  for(int i=0;i<ni_;i++)
+    for(int j=0;j<nj_;j++) {
+      if (!is_avail(i,j)) {
+	int ij = ij_index(i,j);
+	for(int oper_type=0; oper_type<num_te_types(); oper_type++)
+	  if (pairblk_[ij].ints_[oper_type] != NULL) {
+	    ExEnv::outn() << indent << taskid() << ": i = " << i << " j = " << j << " oper_type = " << oper_type << endl;
+	    throw std::runtime_error("Logic error: R12IntsAcc_Node0File::~ : some nonlocal blocks have not been released!");
+	  }
+      }
+    }
+  delete[] pairblk_;
+   
+  // Destroy the file
+#if  CREATE_FILE_ON_NODE0_ONLY
+  if (taskid() == 0)
+#endif
+    unlink(filename_);
+  free(filename_);
+}
+
+void
+R12IntsAcc_Node0File::save_data_state(StateOut& so)
+{
+  R12IntsAcc::save_data_state(so);
+  so.putstring(filename_);
+}
+
+void
+R12IntsAcc_Node0File::init(bool restart)
+{
+  pairblk_ = new struct PairBlkInfo[ni_*nj_];
   int i, j, ij;
-  for(i=0,ij=0;i<nocc_act_;i++)
-    for(j=0;j<nocc_act_;j++,ij++) {
+  for(i=0,ij=0;i<ni_;i++)
+    for(j=0;j<nj_;j++,ij++) {
       pairblk_[ij].ints_[eri] = NULL;
       pairblk_[ij].ints_[r12] = NULL;
       pairblk_[ij].ints_[r12t1] = NULL;
@@ -66,50 +119,48 @@ R12IntsAcc_Node0File::R12IntsAcc_Node0File(Ref<MemoryGrp>& mem, const char* file
       pairblk_[ij].offset_ = (off_t)ij*blocksize_;
     }
 
-  // Create the file
-  icounter_ = 0;
-  filename_ = strdup(filename);
-  if (!restart) {
-    datafile_ = creat(filename_,0644);
-    // If the file was not opened correctly - throw an exception
-    if (datafile_ == -1) {
-      switch (errno) {
-	case EACCES:
-	throw std::runtime_error("R12IntsAcc_Node0File::R12IntsAcc_Node0File -- access to the requested file is not allowed");
-	case ENOSPC:
-	throw std::runtime_error("R12IntsAcc_Node0File::R12IntsAcc_Node0File -- no space left in the filesystem");
+  // node 0 will have the file
+#if CREATE_FILE_ON_NODE0_ONLY
+  if (taskid() != 0)
+    return;
+#endif
 
-	default:
-        throw std::runtime_error("R12IntsAcc_Node0File::R12IntsAcc_Node0File -- failed to open POSIX file on node 0");
-      }
-    }
-    // If everything is fine close it and proceed
-    close(datafile_);
+  // See if can open/create the file
+  if (restart) {
+    datafile_ = open(filename_,O_WRONLY|O_APPEND,0644);
   }
-}
-
-R12IntsAcc_Node0File::~R12IntsAcc_Node0File()
-{
-  for(int i=0;i<nocc_act_;i++)
-    for(int j=0;j<nocc_act_;j++) {
-      if (!is_avail(i,j)) {
-	int ij = ij_index(i,j);
-	for(int oper_type=0; oper_type<num_te_types(); oper_type++)
-	  if (pairblk_[ij].ints_[oper_type] != NULL) {
-	    ExEnv::outn() << indent << mem_->me() << ": i = " << i << " j = " << j << " oper_type = " << oper_type << endl;
-	    throw std::runtime_error("Logic error: R12IntsAcc_Node0File::~ : some nonlocal blocks have not been released!");
-	  }
-      }
-    }
-  delete[] pairblk_;
-      
-  // Destroy the file
-  unlink(filename_);
-  free(filename_);
+  else {
+    datafile_ = creat(filename_,0644);
+  }
+  // Check if the file was opened correctly
+  check_filedescr_();
+  // If everything is fine close it and proceed
+  close(datafile_);
 }
 
 void
-R12IntsAcc_Node0File::store_memorygrp(Ref<MemoryGrp>& mem, int ni)
+R12IntsAcc_Node0File::check_filedescr_()
+{
+  // If the file was not opened correctly - throw an exception
+  if (datafile_ == -1) {
+    switch (errno) {
+      case EACCES:
+      throw std::runtime_error("R12IntsAcc_Node0File::R12IntsAcc_Node0File -- access to the requested file is not allowed");
+      case ENOSPC:
+      throw std::runtime_error("R12IntsAcc_Node0File::R12IntsAcc_Node0File -- no space left in the filesystem");
+      case ENOENT:
+      throw std::runtime_error("R12IntsAcc_Node0File::R12IntsAcc_Node0File -- file does not exist");
+      case ENOTDIR:
+      throw std::runtime_error("R12IntsAcc_Node0File::R12IntsAcc_Node0File -- not a directory");
+      default:
+      perror(0);
+      throw std::runtime_error("R12IntsAcc_Node0File::R12IntsAcc_Node0File -- failed to open POSIX file on node 0");
+    }
+  }
+}
+
+void
+R12IntsAcc_Node0File::store_memorygrp(Ref<MemoryGrp>& mem, int ni, const size_t blksize)
 {
   if (committed_) {
     ExEnv::out0() << "R12IntsAcc_Node0File::store_memorygrp(mem,ni) called after all data has been committed" << endl;
@@ -122,48 +173,71 @@ R12IntsAcc_Node0File::store_memorygrp(Ref<MemoryGrp>& mem, int ni)
     abort();
   }
   // Will store integrals on node 0
-  else if (mem->me() != 0)
+  else if (taskid() != 0)
     return;
-  else if (ni > nocc_act_) {
+  else if (ni > ni_) {
     ExEnv::out0() << "R12IntsAcc_Node0File::store_memorygrp(mem,ni) called with invalid argument:" << endl <<
-      "ni > R12IntsAcc_Node0File::nocc_act_" << endl;
+      "ni > R12IntsAcc_Node0File::ni_" << endl;
     abort();
   }
-  else if (icounter_ + ni > nocc_act_) {
+  else if (next_orbital() + ni > ni_) {
     ExEnv::out0() << "R12IntsAcc_Node0File::store_memorygrp(mem,ni) called with invalid argument:" << endl <<
-      "ni+icounter_ > R12IntsAcc_Node0File::nocc_act_" << endl;
+      "ni+next_orbital() > R12IntsAcc_Node0File::ni_" << endl;
     abort();
   }
   else {
+    size_t blksize_memgrp = blksize;
+    if (blksize_memgrp == 0)
+      blksize_memgrp = blksize_;
+
     // Now do some extra work to figure layout of data in MemoryGrp
     // Compute global offsets to each processor's data
     int i,j,ij;
-    int me = mem->me();
+    int me = taskid();
     int nproc = mem->n();
 
     // Append the data to the file
     datafile_ = open(filename_,O_WRONLY|O_APPEND,0644);
     for (int i=0; i<ni; i++)
-      for (int j=0; j<nocc_act_; j++) {
+      for (int j=0; j<nj_; j++) {
 	double *data;
 	int ij = ij_index(i,j);
 	int proc = ij%nproc;
 	int local_ij_index = ij/nproc;
 	if (proc != me) {
-	  distsize_t moffset = (distsize_t)local_ij_index*blocksize_ + mem->offset(proc);
-	  data = (double *) mem->obtain_readonly(moffset, blocksize_);
-	  write(datafile_, data, blocksize_);
-	  mem->release_readonly(data, moffset, blocksize_);
+	  distsize_t moffset = (distsize_t)local_ij_index*blksize_memgrp*num_te_types() + mem->offset(proc);
+          for(int te_type=0; te_type < num_te_types(); te_type++) {
+	    data = (double *) mem->obtain_readonly(moffset, blksize_);
+	    ssize_t wrote_this_much = write(datafile_, data, blksize_);
+            if (wrote_this_much != blksize_)
+              throw FileOperationFailed("R12IntsAcc_Node0File::store_memorygrp() failed",
+                                        __FILE__,
+                                        __LINE__,
+                                        filename_,
+                                        FileOperationFailed::Write);
+	    mem->release_readonly(data, moffset, blksize_);
+            moffset += blksize_memgrp;
+          }
 	}
 	else {
-	  data = (double *) mem->localdata() + nbasis__2_*num_te_types()*local_ij_index;
-	  write(datafile_, data, blocksize_);
+          data = (double *) ((size_t)mem->localdata() + blksize_memgrp*num_te_types()*local_ij_index);
+          for(int te_type=0; te_type < num_te_types(); te_type++) {
+            ssize_t wrote_this_much = write(datafile_, data, blksize_);
+            if (wrote_this_much != blksize_)
+              throw FileOperationFailed("R12IntsAcc_Node0File::store_memorygrp() failed",
+                                        __FILE__,
+                                        __LINE__,
+                                        filename_,
+                                        FileOperationFailed::Write);
+            data = (double*) ((size_t) data + blksize_memgrp);
+          }
 	}
       }
     // Close the file and update the i counter
     close(datafile_);
-    icounter_ += ni;
   }
+
+  inc_next_orbital(ni);
 }
 
 void
@@ -180,14 +254,27 @@ R12IntsAcc_Node0File::commit()
   mem_->sync();
   mem_->deactivate();
   R12IntsAcc::commit();
-  datafile_ = open(filename_, O_RDONLY);
+}
+
+void
+R12IntsAcc_Node0File::activate()
+{
+  R12IntsAcc::activate();
+#if CREATE_FILE_ON_NODE0_ONLY
+  if (taskid() == 0)
+#endif
+    datafile_ = open(filename_, O_RDONLY);
 }
 
 void
 R12IntsAcc_Node0File::deactivate()
 {
   mem_->activate();
-  close(datafile_);
+#if CREATE_FILE_ON_NODE0_ONLY
+  if (taskid() == 0)
+#endif
+    close(datafile_);
+  R12IntsAcc::deactivate();
 }
 
 double *
@@ -200,9 +287,21 @@ R12IntsAcc_Node0File::retrieve_pair_block(int i, int j, tbint_type oper_type)
     // Always first check if it's already in memory
     if (pb->ints_[oper_type] == 0) {
       off_t offset = pb->offset_ + (off_t)oper_type*blksize_;
-      lseek(datafile_,offset,SEEK_SET);
-      pb->ints_[oper_type] = new double[nbasis__2_];
-      read(datafile_,pb->ints_[oper_type],blksize_);
+      off_t result_offset = lseek(datafile_,offset,SEEK_SET);
+      if (offset == (off_t)-1 || result_offset != offset)
+        throw FileOperationFailed("R12IntsAcc_Node0File::retrieve_pair_block() failed",
+                                  __FILE__,
+                                  __LINE__,
+                                  filename_,
+                                  FileOperationFailed::Other);
+      pb->ints_[oper_type] = new double[nxy_];
+      ssize_t read_this_much = read(datafile_,pb->ints_[oper_type],blksize_);
+      if (read_this_much != blksize_)
+        throw FileOperationFailed("R12IntsAcc_Node0File::retrieve_pair_block() failed",
+                                  __FILE__,
+                                  __LINE__,
+                                  filename_,
+                                  FileOperationFailed::Read);
     }
     pb->refcount_[oper_type] += 1;
     return pb->ints_[oper_type];
@@ -220,7 +319,7 @@ R12IntsAcc_Node0File::release_pair_block(int i, int j, tbint_type oper_type)
     int ij = ij_index(i,j);
     struct PairBlkInfo *pb = &pairblk_[ij];
     if (pb->refcount_[oper_type] <= 0) {
-      ExEnv::outn() << indent << mem_->me() << ":refcount=0: i = " << i << " j = " << j << " tbint_type = " << oper_type << endl;
+      ExEnv::outn() << indent << taskid() << ":refcount=0: i = " << i << " j = " << j << " tbint_type = " << oper_type << endl;
       throw std::runtime_error("Logic error: R12IntsAcc_Node0File::release_pair_block: refcount is already zero!");
     }
     if (pb->ints_[oper_type] != NULL && pb->refcount_[oper_type] == 1) {
