@@ -9,6 +9,7 @@
 #include <chemistry/qc/oint3/build.h>
 
 using namespace std;
+using namespace sc;
 
 BuildIntV3::BuildIntV3()
 {
@@ -21,7 +22,7 @@ BuildIntV3::~BuildIntV3()
 int
 BuildIntV3::impossible_integral()
 {
-  ExEnv::err()
+  ExEnv::errn()
       << "oint3/build.cc: tried to build a impossible integral" << endl;
   abort();
   return(0);
