@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i0303(){
+int sc::BuildIntV3::i0303(){
 /* the cost is 3407 */
 double t1;
 double t2;
@@ -312,12 +312,12 @@ double t308;
 double t309;
 double t310;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_W0-int_v_p340;
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t4=t3*int_v_list004[0];
 t5=int_v_p340-int_v_r30;
 t6=t5*int_v_list003[0];
@@ -326,7 +326,7 @@ t4=int_v_W0-int_v_p120;
 t6=t4*t7;
 t8=t6+t2;
 t6=t3*int_v_list003[0];
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t9=t5*int_v_list002[0];
 t10=t9+t6;
 t6=int_v_p120-int_v_r10;
@@ -351,7 +351,7 @@ t14=(-1)*t15;
 t15=t14*t17;
 t18=t15+t12;
 t12=t13*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t19=int_v_oo2zeta34*int_v_list001[0];
 t20=t19+t12;
 t12=t3*t10;
@@ -367,7 +367,7 @@ t18=t9*t7;
 t23=t13*int_v_list004[0];
 t24=int_v_oo2zeta34*int_v_list003[0];
 t25=t24+t23;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t23=t3*int_v_list005[0];
 t24=t5*int_v_list004[0];
 t26=t24+t23;
@@ -424,11 +424,11 @@ t18=t4*t35;
 t36=t18+t8;
 t8=t30*t22;
 t18=t3*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t37=t5*int_v_list000[0];
 t38=t37+t18;
-double**int_v_list01=int_v_list0[1];
-double*int_v_list010=int_v_list01[0];
+double**restrictxx int_v_list01=int_v_list0[1];
+double*restrictxx int_v_list010=int_v_list01[0];
 int_v_list010[2]=t38;
 t18=t32*t38;
 t37=t18+t8;
@@ -441,19 +441,19 @@ t8=t3*t22;
 t37=t8+t39;
 t8=t5*t38;
 t40=t8+t37;
-double**int_v_list02=int_v_list0[2];
-double*int_v_list020=int_v_list02[0];
+double**restrictxx int_v_list02=int_v_list0[2];
+double*restrictxx int_v_list020=int_v_list02[0];
 int_v_list020[5]=t40;
 t8=t5*t40;
 t37=t8+t18;
-double**int_v_list03=int_v_list0[3];
-double*int_v_list030=int_v_list03[0];
+double**restrictxx int_v_list03=int_v_list0[3];
+double*restrictxx int_v_list030=int_v_list03[0];
 int_v_list030[9]=t37;
 t8=t6*t37;
 t18=t8+t36;
-double***int_v_list1=int_v_list(1);
-double**int_v_list13=int_v_list1[3];
-double*int_v_list130=int_v_list13[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list13=int_v_list1[3];
+double*restrictxx int_v_list130=int_v_list13[0];
 int_v_list130[29]=t18;
 t8=int_v_oo2zeta12*2;
 t36=t8*t18;
@@ -470,7 +470,7 @@ t46=t45+t44;
 t44=t13*int_v_list005[0];
 t45=int_v_oo2zeta34*int_v_list004[0];
 t47=t45+t44;
-double*int_v_list006=int_v_list00[6];
+double*restrictxx int_v_list006=int_v_list00[6];
 t44=t3*int_v_list006[0];
 t45=t5*int_v_list005[0];
 t48=t45+t44;
@@ -501,15 +501,15 @@ t50=t4*t31;
 t52=t50+t51;
 t50=t6*t18;
 t51=t50+t52;
-double***int_v_list2=int_v_list(2);
-double**int_v_list23=int_v_list2[3];
-double*int_v_list230=int_v_list23[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list23=int_v_list2[3];
+double*restrictxx int_v_list230=int_v_list23[0];
 int_v_list230[59]=t51;
 t50=t6*t51;
 t52=t50+t45;
-double***int_v_list3=int_v_list(3);
-double**int_v_list33=int_v_list3[3];
-double*int_v_list330=int_v_list33[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list33=int_v_list3[3];
+double*restrictxx int_v_list330=int_v_list33[0];
 int_v_list330[99]=t52;
 t45=int_v_W2-int_v_p342;
 t50=t45*int_v_list004[0];
@@ -565,8 +565,8 @@ t73=t4*t21;
 t74=t73+t72;
 t72=t6*t40;
 t73=t72+t74;
-double**int_v_list12=int_v_list1[2];
-double*int_v_list120=int_v_list12[0];
+double**restrictxx int_v_list12=int_v_list1[2];
+double*restrictxx int_v_list120=int_v_list12[0];
 int_v_list120[17]=t73;
 t72=t53*t73;
 t74=t72+t64;
@@ -608,8 +608,8 @@ t85=t4*t19;
 t87=t85+t86;
 t85=t6*t73;
 t86=t85+t87;
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t86;
 t85=t53*t86;
 t87=t85+t72;
@@ -851,8 +851,8 @@ t166=t4*t22;
 t167=t166+t165;
 t166=t6*t38;
 t168=t166+t167;
-double**int_v_list11=int_v_list1[1];
-double*int_v_list110=int_v_list11[0];
+double**restrictxx int_v_list11=int_v_list1[1];
+double*restrictxx int_v_list110=int_v_list11[0];
 int_v_list110[8]=t168;
 t166=t88*t168;
 t167=t166+t158;
@@ -925,18 +925,18 @@ t181=t180+t186;
 t180=t4*int_v_list001[0];
 t187=t6*int_v_list000[0];
 t188=t187+t180;
-double**int_v_list10=int_v_list1[0];
-double*int_v_list100=int_v_list10[0];
+double**restrictxx int_v_list10=int_v_list1[0];
+double*restrictxx int_v_list100=int_v_list10[0];
 int_v_list100[2]=t188;
 t180=t6*t188;
 t187=t180+t181;
-double**int_v_list20=int_v_list2[0];
-double*int_v_list200=int_v_list20[0];
+double**restrictxx int_v_list20=int_v_list2[0];
+double*restrictxx int_v_list200=int_v_list20[0];
 int_v_list200[5]=t187;
 t180=t5*t187;
 t181=t180+t183;
-double**int_v_list21=int_v_list2[1];
-double*int_v_list210=int_v_list21[0];
+double**restrictxx int_v_list21=int_v_list2[1];
+double*restrictxx int_v_list210=int_v_list21[0];
 int_v_list210[17]=t181;
 t180=t88*t181;
 t183=t180+t177;
@@ -1944,8 +1944,8 @@ t138=t78+t84;
 int_v_list220[17]=t138;
 t78=t272*t138;
 t84=t78+t15;
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[23]=t84;
 t15=t53*t84;
 t78=t15+t41;
@@ -3761,8 +3761,8 @@ t16=t4*t179;
 t65=t16+t70;
 t16=t6*t181;
 t70=t16+t65;
-double**int_v_list31=int_v_list3[1];
-double*int_v_list310=int_v_list31[0];
+double**restrictxx int_v_list31=int_v_list3[1];
+double*restrictxx int_v_list310=int_v_list31[0];
 int_v_list310[29]=t70;
 t16=t29*t77;
 t65=t4*t120;
@@ -4045,8 +4045,8 @@ t2=t4*t185;
 t4=t2+t59;
 t2=t6*t187;
 t6=t2+t4;
-double**int_v_list30=int_v_list3[0];
-double*int_v_list300=int_v_list30[0];
+double**restrictxx int_v_list30=int_v_list3[0];
+double*restrictxx int_v_list300=int_v_list30[0];
 int_v_list300[9]=t6;
 t2=t159*t185;
 t4=t272*t187;
