@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i0303eAB(){
+int sc::BuildIntV3::i0303eAB(){
 /* the cost is 2283 */
 double t1;
 double t2;
@@ -341,12 +341,12 @@ double t337;
 double t338;
 double t339;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_W0-int_v_p340;
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t4=t3*int_v_list004[0];
 t5=int_v_p340-int_v_r30;
 t6=t5*int_v_list003[0];
@@ -361,7 +361,7 @@ t11=int_v_zeta12*int_v_ooze;
 t12=int_v_oo2zeta34*t11;
 t11=(-1)*t12;
 t12=t11*int_v_list003[0];
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t13=int_v_oo2zeta34*int_v_list002[0];
 t14=t13+t12;
 t12=t3*t7;
@@ -377,7 +377,7 @@ t12=(-1)*t13;
 t13=t12*t15;
 t17=t13+t10;
 t10=t11*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t18=int_v_oo2zeta34*int_v_list001[0];
 t19=t18+t10;
 t10=t3*t16;
@@ -393,7 +393,7 @@ t17=t9*t7;
 t22=t11*int_v_list004[0];
 t23=int_v_oo2zeta34*int_v_list003[0];
 t24=t23+t22;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t22=t3*int_v_list005[0];
 t23=t5*int_v_list004[0];
 t25=t23+t22;
@@ -437,9 +437,9 @@ t17=t5*t20;
 t34=t17+t33;
 t17=t4*t34;
 t33=t17+t6;
-double***int_v_list1=int_v_list(1);
-double**int_v_list13=int_v_list1[3];
-double*int_v_list130=int_v_list13[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list13=int_v_list1[3];
+double*restrictxx int_v_list130=int_v_list13[0];
 int_v_list130[29]=t33;
 t6=int_v_oo2zeta12*2;
 t17=t6*t33;
@@ -456,7 +456,7 @@ t40=t39+t38;
 t38=t11*int_v_list005[0];
 t39=int_v_oo2zeta34*int_v_list004[0];
 t41=t39+t38;
-double*int_v_list006=int_v_list00[6];
+double*restrictxx int_v_list006=int_v_list00[6];
 t38=t3*int_v_list006[0];
 t39=t5*int_v_list005[0];
 t42=t39+t38;
@@ -474,9 +474,9 @@ t36=t4*t39;
 t38=t36+t37;
 t36=t4*t38;
 t37=t36+t35;
-double***int_v_list3=int_v_list(3);
-double**int_v_list33=int_v_list3[3];
-double*int_v_list330=int_v_list33[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list33=int_v_list3[3];
+double*restrictxx int_v_list330=int_v_list33[0];
 int_v_list330[99]=t37;
 t35=int_v_W2-int_v_p342;
 t36=t35*int_v_list004[0];
@@ -1312,15 +1312,15 @@ t25=t35*t162;
 t162=t25+t53;
 t25=t27*t57;
 t53=t191*t80;
-double**int_v_list12=int_v_list1[2];
-double*int_v_list120=int_v_list12[0];
+double**restrictxx int_v_list12=int_v_list1[2];
+double*restrictxx int_v_list120=int_v_list12[0];
 int_v_list120[9]=t53;
 t201=t6*t53;
 t53=t201+t25;
 t25=t191*t186;
 t201=t25+t53;
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[21]=t201;
 t25=t44*t201;
 t53=t25+t162;
@@ -2228,15 +2228,15 @@ t272=t255+t49;
 t255=t1*int_v_list001[0];
 t273=t4*t21;
 t281=t273+t255;
-double**int_v_list11=int_v_list1[1];
-double*int_v_list110=int_v_list11[0];
+double**restrictxx int_v_list11=int_v_list1[1];
+double*restrictxx int_v_list110=int_v_list11[0];
 int_v_list110[8]=t281;
 t273=t6*t281;
 t282=t273+t272;
 t272=t4*t122;
 t273=t272+t282;
-double**int_v_list31=int_v_list3[1];
-double*int_v_list310=int_v_list31[0];
+double**restrictxx int_v_list31=int_v_list3[1];
+double*restrictxx int_v_list310=int_v_list31[0];
 int_v_list310[29]=t273;
 t272=t4*t100;
 t282=t27*t272;
@@ -2409,15 +2409,15 @@ int_v_list310[0]=t292;
 t100=t4*int_v_list002[0];
 t241=t27*t100;
 t298=t4*int_v_list001[0];
-double**int_v_list10=int_v_list1[0];
-double*int_v_list100=int_v_list10[0];
+double**restrictxx int_v_list10=int_v_list1[0];
+double*restrictxx int_v_list100=int_v_list10[0];
 int_v_list100[2]=t298;
 t299=t6*t298;
 t300=t299+t241;
 t241=t4*t99;
 t299=t241+t300;
-double**int_v_list30=int_v_list3[0];
-double*int_v_list300=int_v_list30[0];
+double**restrictxx int_v_list30=int_v_list3[0];
+double*restrictxx int_v_list300=int_v_list30[0];
 int_v_list300[9]=t299;
 t241=t191*t99;
 int_v_list300[8]=t241;
@@ -2465,11 +2465,11 @@ t27=t12*t34;
 t34=t27+t6;
 t6=t28*t21;
 t303=t3*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t304=t5*int_v_list000[0];
 t305=t304+t303;
-double**int_v_list01=int_v_list0[1];
-double*int_v_list010=int_v_list01[0];
+double**restrictxx int_v_list01=int_v_list0[1];
+double*restrictxx int_v_list010=int_v_list01[0];
 int_v_list010[2]=t305;
 t303=t30*t305;
 t304=t303+t6;
@@ -2482,21 +2482,21 @@ t6=t3*t21;
 t3=t6+t306;
 t6=t5*t305;
 t304=t6+t3;
-double**int_v_list02=int_v_list0[2];
-double*int_v_list020=int_v_list02[0];
+double**restrictxx int_v_list02=int_v_list0[2];
+double*restrictxx int_v_list020=int_v_list02[0];
 int_v_list020[5]=t304;
 t3=t5*t304;
 t5=t3+t303;
-double**int_v_list03=int_v_list0[3];
-double*int_v_list030=int_v_list03[0];
+double**restrictxx int_v_list03=int_v_list0[3];
+double*restrictxx int_v_list030=int_v_list03[0];
 int_v_list030[9]=t5;
 t3=int_v_oo2zeta12*t5;
 t5=t3+t34;
 t6=t4*t31;
 t34=t6+t5;
-double***int_v_list2=int_v_list(2);
-double**int_v_list23=int_v_list2[3];
-double*int_v_list230=int_v_list23[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list23=int_v_list2[3];
+double*restrictxx int_v_list230=int_v_list23[0];
 int_v_list230[59]=t34;
 t5=t35*t22;
 t6=t9*t270;
@@ -2506,8 +2506,8 @@ t6=int_v_oo2zeta12*t304;
 t308=t6+t307;
 t307=t4*t136;
 t309=t307+t308;
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t309;
 t307=t44*t309;
 t308=t307+t5;
@@ -2545,8 +2545,8 @@ t316=int_v_oo2zeta12*t305;
 t317=t316+t315;
 t315=t4*t270;
 t318=t315+t317;
-double**int_v_list21=int_v_list2[1];
-double*int_v_list210=int_v_list21[0];
+double**restrictxx int_v_list21=int_v_list2[1];
+double*restrictxx int_v_list210=int_v_list21[0];
 int_v_list210[17]=t318;
 t315=t72*t318;
 t317=t315+t84;
@@ -3041,8 +3041,8 @@ t12=int_v_oo2zeta12*int_v_list000[0];
 t131=t12+t129;
 t12=t4*t100;
 t4=t12+t131;
-double**int_v_list20=int_v_list2[0];
-double*int_v_list200=int_v_list20[0];
+double**restrictxx int_v_list20=int_v_list2[0];
+double*restrictxx int_v_list200=int_v_list20[0];
 int_v_list200[5]=t4;
 t12=t191*t100;
 int_v_list200[4]=t12;
