@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i0313eAB(){
+int sc::BuildIntV3::i0313eAB(){
 /* the cost is 2237 */
 double t1;
 double t2;
@@ -328,12 +328,12 @@ double t324;
 double t325;
 double t326;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_W0-int_v_p340;
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t4=t3*int_v_list004[0];
 t5=int_v_p340-int_v_r30;
 t6=t5*int_v_list003[0];
@@ -348,7 +348,7 @@ t11=int_v_zeta12*int_v_ooze;
 t12=int_v_oo2zeta34*t11;
 t11=(-1)*t12;
 t12=t11*int_v_list003[0];
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t13=int_v_oo2zeta34*int_v_list002[0];
 t14=t13+t12;
 t12=t3*t7;
@@ -364,7 +364,7 @@ t12=(-1)*t13;
 t13=t12*t15;
 t17=t13+t10;
 t10=t11*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t18=int_v_oo2zeta34*int_v_list001[0];
 t19=t18+t10;
 t10=t3*t16;
@@ -380,7 +380,7 @@ t17=t9*t7;
 t22=t11*int_v_list004[0];
 t23=int_v_oo2zeta34*int_v_list003[0];
 t24=t23+t22;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t22=t3*int_v_list005[0];
 t23=t5*int_v_list004[0];
 t25=t23+t22;
@@ -424,9 +424,9 @@ t17=t5*t20;
 t34=t17+t33;
 t17=t4*t34;
 t33=t17+t6;
-double***int_v_list1=int_v_list(1);
-double**int_v_list13=int_v_list1[3];
-double*int_v_list130=int_v_list13[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list13=int_v_list1[3];
+double*restrictxx int_v_list130=int_v_list13[0];
 int_v_list130[29]=t33;
 t6=int_v_oo2zeta12*2;
 t17=t6*t33;
@@ -443,7 +443,7 @@ t40=t39+t38;
 t38=t11*int_v_list005[0];
 t39=int_v_oo2zeta34*int_v_list004[0];
 t41=t39+t38;
-double*int_v_list006=int_v_list00[6];
+double*restrictxx int_v_list006=int_v_list00[6];
 t38=t3*int_v_list006[0];
 t39=t5*int_v_list005[0];
 t42=t39+t38;
@@ -461,9 +461,9 @@ t36=t4*t39;
 t38=t36+t37;
 t36=t4*t38;
 t37=t36+t35;
-double***int_v_list3=int_v_list(3);
-double**int_v_list33=int_v_list3[3];
-double*int_v_list330=int_v_list33[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list33=int_v_list3[3];
+double*restrictxx int_v_list330=int_v_list33[0];
 int_v_list330[99]=t37;
 t35=int_v_W2-int_v_p342;
 t36=t35*int_v_list004[0];
@@ -1299,15 +1299,15 @@ t25=t35*t162;
 t162=t25+t53;
 t25=t27*t57;
 t53=t191*t80;
-double**int_v_list12=int_v_list1[2];
-double*int_v_list120=int_v_list12[0];
+double**restrictxx int_v_list12=int_v_list1[2];
+double*restrictxx int_v_list120=int_v_list12[0];
 int_v_list120[9]=t53;
 t201=t6*t53;
 t53=t201+t25;
 t25=t191*t186;
 t201=t25+t53;
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[21]=t201;
 t25=t44*t201;
 t53=t25+t162;
@@ -2215,15 +2215,15 @@ t270=t253+t49;
 t253=t1*int_v_list001[0];
 t272=t4*t21;
 t273=t272+t253;
-double**int_v_list11=int_v_list1[1];
-double*int_v_list110=int_v_list11[0];
+double**restrictxx int_v_list11=int_v_list1[1];
+double*restrictxx int_v_list110=int_v_list11[0];
 int_v_list110[8]=t273;
 t272=t6*t273;
 t281=t272+t270;
 t270=t4*t122;
 t272=t270+t281;
-double**int_v_list31=int_v_list3[1];
-double*int_v_list310=int_v_list31[0];
+double**restrictxx int_v_list31=int_v_list3[1];
+double*restrictxx int_v_list310=int_v_list31[0];
 int_v_list310[29]=t272;
 t270=t4*t100;
 t281=t27*t270;
@@ -2398,11 +2398,11 @@ t27=t12*t34;
 t34=t27+t6;
 t6=t28*t21;
 t241=t3*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t277=t5*int_v_list000[0];
 t282=t277+t241;
-double**int_v_list01=int_v_list0[1];
-double*int_v_list010=int_v_list01[0];
+double**restrictxx int_v_list01=int_v_list0[1];
+double*restrictxx int_v_list010=int_v_list01[0];
 int_v_list010[2]=t282;
 t241=t30*t282;
 t277=t241+t6;
@@ -2415,21 +2415,21 @@ t6=t3*t21;
 t3=t6+t291;
 t6=t5*t282;
 t277=t6+t3;
-double**int_v_list02=int_v_list0[2];
-double*int_v_list020=int_v_list02[0];
+double**restrictxx int_v_list02=int_v_list0[2];
+double*restrictxx int_v_list020=int_v_list02[0];
 int_v_list020[5]=t277;
 t3=t5*t277;
 t5=t3+t241;
-double**int_v_list03=int_v_list0[3];
-double*int_v_list030=int_v_list03[0];
+double**restrictxx int_v_list03=int_v_list0[3];
+double*restrictxx int_v_list030=int_v_list03[0];
 int_v_list030[9]=t5;
 t3=int_v_oo2zeta12*t5;
 t5=t3+t34;
 t6=t4*t31;
 t34=t6+t5;
-double***int_v_list2=int_v_list(2);
-double**int_v_list23=int_v_list2[3];
-double*int_v_list230=int_v_list23[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list23=int_v_list2[3];
+double*restrictxx int_v_list230=int_v_list23[0];
 int_v_list230[59]=t34;
 t5=t35*t22;
 t6=t9*t255;
@@ -2439,8 +2439,8 @@ t6=int_v_oo2zeta12*t277;
 t295=t6+t294;
 t294=t4*t136;
 t296=t294+t295;
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t296;
 t294=t44*t296;
 t295=t294+t5;
@@ -2479,8 +2479,8 @@ t303=int_v_oo2zeta12*t282;
 t304=t303+t302;
 t302=t4*t255;
 t305=t302+t304;
-double**int_v_list21=int_v_list2[1];
-double*int_v_list210=int_v_list21[0];
+double**restrictxx int_v_list21=int_v_list2[1];
+double*restrictxx int_v_list210=int_v_list21[0];
 int_v_list210[17]=t305;
 t302=t72*t305;
 t304=t302+t84;
