@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i0333eAB(){
+int sc::BuildIntV3::i0333eAB(){
 /* the cost is 1609 */
 double t1;
 double t2;
@@ -226,12 +226,12 @@ double t222;
 double t223;
 double t224;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_W0-int_v_p340;
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t4=t3*int_v_list004[0];
 t5=int_v_p340-int_v_r30;
 t6=t5*int_v_list003[0];
@@ -246,7 +246,7 @@ t11=int_v_zeta12*int_v_ooze;
 t12=int_v_oo2zeta34*t11;
 t11=(-1)*t12;
 t12=t11*int_v_list003[0];
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t13=int_v_oo2zeta34*int_v_list002[0];
 t14=t13+t12;
 t12=t3*t7;
@@ -262,7 +262,7 @@ t12=(-1)*t13;
 t13=t12*t15;
 t17=t13+t10;
 t10=t11*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t18=int_v_oo2zeta34*int_v_list001[0];
 t19=t18+t10;
 t10=t3*t16;
@@ -278,7 +278,7 @@ t17=t9*t7;
 t22=t11*int_v_list004[0];
 t23=int_v_oo2zeta34*int_v_list003[0];
 t24=t23+t22;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t22=t3*int_v_list005[0];
 t23=t5*int_v_list004[0];
 t25=t23+t22;
@@ -322,9 +322,9 @@ t17=t5*t20;
 t34=t17+t33;
 t17=t4*t34;
 t33=t17+t6;
-double***int_v_list1=int_v_list(1);
-double**int_v_list13=int_v_list1[3];
-double*int_v_list130=int_v_list13[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list13=int_v_list1[3];
+double*restrictxx int_v_list130=int_v_list13[0];
 int_v_list130[29]=t33;
 t6=int_v_oo2zeta12*2;
 t17=t6*t33;
@@ -341,7 +341,7 @@ t40=t39+t38;
 t38=t11*int_v_list005[0];
 t39=int_v_oo2zeta34*int_v_list004[0];
 t41=t39+t38;
-double*int_v_list006=int_v_list00[6];
+double*restrictxx int_v_list006=int_v_list00[6];
 t38=t3*int_v_list006[0];
 t39=t5*int_v_list005[0];
 t42=t39+t38;
@@ -359,9 +359,9 @@ t36=t4*t39;
 t38=t36+t37;
 t36=t4*t38;
 t37=t36+t35;
-double***int_v_list3=int_v_list(3);
-double**int_v_list33=int_v_list3[3];
-double*int_v_list330=int_v_list33[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list33=int_v_list3[3];
+double*restrictxx int_v_list330=int_v_list33[0];
 int_v_list330[99]=t37;
 t35=int_v_W2-int_v_p342;
 t36=t35*int_v_list004[0];
@@ -1668,7 +1668,7 @@ t14=t12*t34;
 t34=t14+t6;
 t6=t28*t21;
 t75=t3*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t78=t5*int_v_list000[0];
 t83=t78+t75;
 t75=t30*t83;
@@ -1684,16 +1684,16 @@ t6=t5*t83;
 t78=t6+t3;
 t3=t5*t78;
 t5=t3+t75;
-double**int_v_list03=int_v_list0[3];
-double*int_v_list030=int_v_list03[0];
+double**restrictxx int_v_list03=int_v_list0[3];
+double*restrictxx int_v_list030=int_v_list03[0];
 int_v_list030[9]=t5;
 t3=int_v_oo2zeta12*t5;
 t5=t3+t34;
 t6=t4*t31;
 t34=t6+t5;
-double***int_v_list2=int_v_list(2);
-double**int_v_list23=int_v_list2[3];
-double*int_v_list230=int_v_list23[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list23=int_v_list2[3];
+double*restrictxx int_v_list230=int_v_list23[0];
 int_v_list230[59]=t34;
 t5=t1*t100;
 t6=t4*t49;
