@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i1111eAB(){
+int sc::BuildIntV3::i1111eAB(){
 /* the cost is 32 */
 double t1;
 double t2;
@@ -14,12 +14,12 @@ double t10;
 double t11;
 double t12;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list001=int_v_list00[1];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list001=int_v_list00[1];
 t2=t1*int_v_list001[0];
 t1=int_v_W0-int_v_p340;
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t3=t1*int_v_list002[0];
 t1=int_v_p340-int_v_r30;
 t4=t1*int_v_list001[0];
@@ -27,9 +27,9 @@ t1=t4+t3;
 t3=int_v_W0-int_v_p120;
 t4=t3*t1;
 t5=t4+t2;
-double***int_v_list1=int_v_list(1);
-double**int_v_list11=int_v_list1[1];
-double*int_v_list110=int_v_list11[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list11=int_v_list1[1];
+double*restrictxx int_v_list110=int_v_list11[0];
 int_v_list110[8]=t5;
 t4=int_v_W2-int_v_p342;
 t6=t4*int_v_list002[0];
