@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i1200eAB(){
+int sc::BuildIntV3::i1200eAB(){
 /* the cost is 24 */
 double t1;
 double t2;
@@ -15,21 +15,21 @@ double t11;
 t1=int_v_zeta34*int_v_ooze;
 t2=int_v_oo2zeta12*t1;
 t1=(-1)*t2;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list001=int_v_list00[1];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list001=int_v_list00[1];
 t2=int_v_list001[0]*t1;
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t1=int_v_list000[0]*int_v_oo2zeta12;
 t3=t1+t2;
 t1=int_v_W0-int_v_p120;
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t2=int_v_list002[0]*t1;
 t4=t1*t2;
 t5=t4+t3;
-double***int_v_list2=int_v_list(2);
-double**int_v_list20=int_v_list2[0];
-double*int_v_list200=int_v_list20[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list20=int_v_list2[0];
+double*restrictxx int_v_list200=int_v_list20[0];
 int_v_list200[5]=t5;
 t4=int_v_W2-int_v_p122;
 t6=t4*t2;
@@ -48,9 +48,9 @@ t11=t7*t9;
 t9=t3+t11;
 int_v_list200[0]=t9;
 t3=int_v_list001[0]*t1;
-double***int_v_list1=int_v_list(1);
-double**int_v_list10=int_v_list1[0];
-double*int_v_list100=int_v_list10[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list10=int_v_list1[0];
+double*restrictxx int_v_list100=int_v_list10[0];
 int_v_list100[2]=t3;
 t1=int_v_list001[0]*t4;
 int_v_list100[1]=t1;
