@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i1302(){
+int sc::BuildIntV3::i1302(){
 /* the cost is 1593 */
 double t1;
 double t2;
@@ -172,12 +172,12 @@ double t168;
 double t169;
 double t170;
 t1=int_v_W0-int_v_p120;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_p120-int_v_r10;
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t4=t3*int_v_list002[0];
 t5=t4+t2;
 t2=0.5*int_v_ooze;
@@ -193,13 +193,13 @@ t7=(-1)*t9;
 t9=t7*t10;
 t11=t9+t4;
 t12=t6*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t13=t8*int_v_list001[0];
 t14=t13+t12;
 t12=int_v_oo2zeta12*t14;
 t13=t12+t11;
 t11=t2*int_v_list003[0];
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t15=t6*int_v_list004[0];
 t16=t8*int_v_list003[0];
 t17=t16+t15;
@@ -250,7 +250,7 @@ t15=t16*t14;
 t21=t1*t29;
 t30=t21+t15;
 t15=t23*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t21=int_v_oo2zeta34*int_v_list000[0];
 t31=t21+t15;
 t15=t6*t14;
@@ -262,9 +262,9 @@ t15=t8*t33;
 t32=t15+t21;
 t15=t3*t32;
 t21=t15+t30;
-double***int_v_list1=int_v_list(1);
-double**int_v_list12=int_v_list1[2];
-double*int_v_list120=int_v_list12[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list12=int_v_list1[2];
+double*restrictxx int_v_list120=int_v_list12[0];
 int_v_list120[17]=t21;
 t15=int_v_oo2zeta12*2;
 t30=t15*t21;
@@ -278,7 +278,7 @@ t35=t16*t17;
 t37=t23*int_v_list004[0];
 t23=int_v_oo2zeta34*int_v_list003[0];
 t38=t23+t37;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t23=t6*int_v_list005[0];
 t37=t8*int_v_list004[0];
 t39=t37+t23;
@@ -305,15 +305,15 @@ t41=t1*t24;
 t43=t41+t42;
 t41=t3*t21;
 t42=t41+t43;
-double***int_v_list2=int_v_list(2);
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t42;
 t41=t3*t42;
 t43=t41+t37;
-double***int_v_list3=int_v_list(3);
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[59]=t43;
 t37=int_v_W2-int_v_p342;
 t41=t37*int_v_list003[0];
@@ -351,8 +351,8 @@ t58=t1*t14;
 t59=t58+t57;
 t58=t3*t33;
 t60=t58+t59;
-double**int_v_list11=int_v_list1[1];
-double*int_v_list110=int_v_list11[0];
+double**restrictxx int_v_list11=int_v_list1[1];
+double*restrictxx int_v_list110=int_v_list11[0];
 int_v_list110[8]=t60;
 t58=t44*t60;
 t59=t58+t50;
@@ -406,18 +406,18 @@ t70=t64+t75;
 t64=t1*int_v_list001[0];
 t76=t3*int_v_list000[0];
 t77=t76+t64;
-double**int_v_list10=int_v_list1[0];
-double*int_v_list100=int_v_list10[0];
+double**restrictxx int_v_list10=int_v_list1[0];
+double*restrictxx int_v_list100=int_v_list10[0];
 int_v_list100[2]=t77;
 t64=t3*t77;
 t76=t64+t70;
-double**int_v_list20=int_v_list2[0];
-double*int_v_list200=int_v_list20[0];
+double**restrictxx int_v_list20=int_v_list2[0];
+double*restrictxx int_v_list200=int_v_list20[0];
 int_v_list200[5]=t76;
 t64=t8*t76;
 t70=t64+t72;
-double**int_v_list21=int_v_list2[1];
-double*int_v_list210=int_v_list21[0];
+double**restrictxx int_v_list21=int_v_list2[1];
+double*restrictxx int_v_list210=int_v_list21[0];
 int_v_list210[17]=t70;
 t64=t44*t70;
 t72=t64+t58;
@@ -1061,8 +1061,8 @@ t131=t106+t9;
 int_v_list210[8]=t131;
 t9=t146*t131;
 t106=t9+t30;
-double**int_v_list31=int_v_list3[1];
-double*int_v_list310=int_v_list31[0];
+double**restrictxx int_v_list31=int_v_list3[1];
+double*restrictxx int_v_list310=int_v_list31[0];
 int_v_list310[11]=t106;
 t9=t44*t106;
 t30=t9+t39;
@@ -1884,8 +1884,8 @@ t4=t1*t74;
 t1=t4+t35;
 t4=t3*t76;
 t3=t4+t1;
-double**int_v_list30=int_v_list3[0];
-double*int_v_list300=int_v_list30[0];
+double**restrictxx int_v_list30=int_v_list3[0];
+double*restrictxx int_v_list300=int_v_list30[0];
 int_v_list300[9]=t3;
 t1=t139*t74;
 t4=t146*t76;
