@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i1312eAB(){
+int sc::BuildIntV3::i1312eAB(){
 /* the cost is 994 */
 double t1;
 double t2;
@@ -166,16 +166,16 @@ double t162;
 double t163;
 double t164;
 t1=int_v_W0-int_v_p120;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=0.5*int_v_ooze;
 t4=t3*t2;
 t5=int_v_W0-int_v_p340;
 t6=t5*int_v_list003[0];
 t7=int_v_p340-int_v_r30;
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t8=t7*int_v_list002[0];
 t9=t8+t6;
 t6=int_v_zeta34*int_v_ooze;
@@ -184,13 +184,13 @@ t6=(-1)*t8;
 t8=t6*t9;
 t10=t8+t4;
 t11=t5*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t12=t7*int_v_list001[0];
 t13=t12+t11;
 t11=int_v_oo2zeta12*t13;
 t12=t11+t10;
 t10=t3*int_v_list003[0];
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t14=t5*int_v_list004[0];
 t15=t7*int_v_list003[0];
 t16=t15+t14;
@@ -229,9 +229,9 @@ t18=t7*t13;
 t27=t18+t25;
 t18=t1*t27;
 t25=t18+t12;
-double***int_v_list1=int_v_list(1);
-double**int_v_list12=int_v_list1[2];
-double*int_v_list120=int_v_list12[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list12=int_v_list1[2];
+double*restrictxx int_v_list120=int_v_list12[0];
 int_v_list120[17]=t25;
 t12=int_v_oo2zeta12*2;
 t18=t12*t25;
@@ -245,7 +245,7 @@ t29=t14*t16;
 t31=t20*int_v_list004[0];
 t32=int_v_oo2zeta34*int_v_list003[0];
 t33=t32+t31;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t31=t5*int_v_list005[0];
 t32=t7*int_v_list004[0];
 t34=t32+t31;
@@ -259,9 +259,9 @@ t29=t1*t32;
 t31=t29+t30;
 t29=t1*t31;
 t30=t29+t28;
-double***int_v_list3=int_v_list(3);
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[59]=t30;
 t28=int_v_W2-int_v_p342;
 t29=t28*int_v_list003[0];
@@ -922,15 +922,15 @@ t92=t75+t43;
 t75=t3*int_v_list001[0];
 t98=t1*t13;
 t101=t98+t75;
-double**int_v_list11=int_v_list1[1];
-double*int_v_list110=int_v_list11[0];
+double**restrictxx int_v_list11=int_v_list1[1];
+double*restrictxx int_v_list110=int_v_list11[0];
 int_v_list110[8]=t101;
 t98=t12*t101;
 t105=t98+t92;
 t92=t1*t17;
 t98=t92+t105;
-double**int_v_list31=int_v_list3[1];
-double*int_v_list310=int_v_list31[0];
+double**restrictxx int_v_list31=int_v_list3[1];
+double*restrictxx int_v_list310=int_v_list31[0];
 int_v_list310[29]=t98;
 t92=t1*t38;
 t105=t19*t92;
@@ -1104,7 +1104,7 @@ t12=t14*t85;
 t19=t6*t27;
 t27=t19+t12;
 t12=t20*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t20=int_v_oo2zeta34*int_v_list000[0];
 t71=t20+t12;
 t12=t5*t13;
@@ -1118,9 +1118,9 @@ t5=int_v_oo2zeta12*t7;
 t7=t5+t27;
 t12=t1*t22;
 t20=t12+t7;
-double***int_v_list2=int_v_list(2);
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t20;
 t7=t28*t17;
 t12=t1*int_v_list002[0];
@@ -1131,8 +1131,8 @@ t145=int_v_oo2zeta12*t122;
 t148=t145+t128;
 t128=t1*t85;
 t149=t128+t148;
-double**int_v_list21=int_v_list2[1];
-double*int_v_list210=int_v_list21[0];
+double**restrictxx int_v_list21=int_v_list2[1];
+double*restrictxx int_v_list210=int_v_list21[0];
 int_v_list210[17]=t149;
 t128=t36*t149;
 t148=t128+t7;
