@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i1313(){
+int sc::BuildIntV3::i1313(){
 /* the cost is 3339 */
 double t1;
 double t2;
@@ -302,12 +302,12 @@ double t298;
 double t299;
 double t300;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_W0-int_v_p340;
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t4=t3*int_v_list004[0];
 t5=int_v_p340-int_v_r30;
 t6=t5*int_v_list003[0];
@@ -316,7 +316,7 @@ t4=int_v_W0-int_v_p120;
 t6=t4*t7;
 t8=t6+t2;
 t6=t3*int_v_list003[0];
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t9=t5*int_v_list002[0];
 t10=t9+t6;
 t6=int_v_p120-int_v_r10;
@@ -341,7 +341,7 @@ t14=(-1)*t15;
 t15=t14*t17;
 t18=t15+t12;
 t12=t13*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t19=int_v_oo2zeta34*int_v_list001[0];
 t20=t19+t12;
 t12=t3*t10;
@@ -357,7 +357,7 @@ t18=t9*t7;
 t23=t13*int_v_list004[0];
 t24=int_v_oo2zeta34*int_v_list003[0];
 t25=t24+t23;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t23=t3*int_v_list005[0];
 t24=t5*int_v_list004[0];
 t26=t24+t23;
@@ -414,7 +414,7 @@ t18=t4*t35;
 t36=t18+t8;
 t8=t30*t22;
 t18=t3*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t37=t5*int_v_list000[0];
 t38=t37+t18;
 t18=t32*t38;
@@ -432,9 +432,9 @@ t8=t5*t40;
 t37=t8+t18;
 t8=t6*t37;
 t18=t8+t36;
-double***int_v_list1=int_v_list(1);
-double**int_v_list13=int_v_list1[3];
-double*int_v_list130=int_v_list13[0];
+double***restrictxx int_v_list1=int_v_list(1);
+double**restrictxx int_v_list13=int_v_list1[3];
+double*restrictxx int_v_list130=int_v_list13[0];
 int_v_list130[29]=t18;
 t8=int_v_oo2zeta12*2;
 t36=t8*t18;
@@ -451,7 +451,7 @@ t46=t45+t44;
 t44=t13*int_v_list005[0];
 t45=int_v_oo2zeta34*int_v_list004[0];
 t47=t45+t44;
-double*int_v_list006=int_v_list00[6];
+double*restrictxx int_v_list006=int_v_list00[6];
 t44=t3*int_v_list006[0];
 t45=t5*int_v_list005[0];
 t48=t45+t44;
@@ -482,15 +482,15 @@ t45=t4*t31;
 t50=t45+t46;
 t45=t6*t18;
 t46=t45+t50;
-double***int_v_list2=int_v_list(2);
-double**int_v_list23=int_v_list2[3];
-double*int_v_list230=int_v_list23[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list23=int_v_list2[3];
+double*restrictxx int_v_list230=int_v_list23[0];
 int_v_list230[59]=t46;
 t45=t6*t46;
 t50=t45+t44;
-double***int_v_list3=int_v_list(3);
-double**int_v_list33=int_v_list3[3];
-double*int_v_list330=int_v_list33[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list33=int_v_list3[3];
+double*restrictxx int_v_list330=int_v_list33[0];
 int_v_list330[99]=t50;
 t44=int_v_W2-int_v_p342;
 t45=t44*int_v_list004[0];
@@ -546,8 +546,8 @@ t71=t4*t21;
 t72=t71+t70;
 t70=t6*t40;
 t71=t70+t72;
-double**int_v_list12=int_v_list1[2];
-double*int_v_list120=int_v_list12[0];
+double**restrictxx int_v_list12=int_v_list1[2];
+double*restrictxx int_v_list120=int_v_list12[0];
 int_v_list120[17]=t71;
 t70=t51*t71;
 t72=t70+t62;
@@ -589,8 +589,8 @@ t83=t4*t19;
 t85=t83+t84;
 t83=t6*t71;
 t84=t83+t85;
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t84;
 t83=t51*t84;
 t85=t83+t70;
@@ -830,8 +830,8 @@ t164=t4*t22;
 t165=t164+t163;
 t164=t6*t38;
 t166=t164+t165;
-double**int_v_list11=int_v_list1[1];
-double*int_v_list110=int_v_list11[0];
+double**restrictxx int_v_list11=int_v_list1[1];
+double*restrictxx int_v_list110=int_v_list11[0];
 int_v_list110[8]=t166;
 t164=t86*t166;
 t165=t164+t156;
@@ -895,8 +895,8 @@ t180=t4*t67;
 t183=t180+t182;
 t180=t6*t166;
 t182=t180+t183;
-double**int_v_list21=int_v_list2[1];
-double*int_v_list210=int_v_list21[0];
+double**restrictxx int_v_list21=int_v_list2[1];
+double*restrictxx int_v_list210=int_v_list21[0];
 int_v_list210[17]=t182;
 t180=t86*t182;
 t183=t180+t174;
@@ -1893,8 +1893,8 @@ t136=t76+t82;
 int_v_list220[17]=t136;
 t76=t267*t136;
 t82=t76+t15;
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[23]=t82;
 t15=t51*t82;
 t76=t15+t36;
@@ -3707,8 +3707,8 @@ t16=t4*t176;
 t74=t16+t91;
 t16=t6*t182;
 t91=t16+t74;
-double**int_v_list31=int_v_list3[1];
-double*int_v_list310=int_v_list31[0];
+double**restrictxx int_v_list31=int_v_list3[1];
+double*restrictxx int_v_list310=int_v_list31[0];
 int_v_list310[29]=t91;
 t16=t29*t80;
 t74=t4*t118;
