@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i2322(){
+int sc::BuildIntV3::i2322(){
 /* the cost is 1260 */
 double t1;
 double t2;
@@ -155,12 +155,12 @@ double t151;
 double t152;
 double t153;
 t1=int_v_W0-int_v_p120;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_p120-int_v_r10;
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t4=t3*int_v_list002[0];
 t5=t4+t2;
 t2=0.5*int_v_ooze;
@@ -176,13 +176,13 @@ t6=(-1)*t8;
 t8=t6*t9;
 t10=t8+t4;
 t11=t5*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t12=t7*int_v_list001[0];
 t13=t12+t11;
 t11=int_v_oo2zeta12*t13;
 t12=t11+t10;
 t10=t2*int_v_list003[0];
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t14=t5*int_v_list004[0];
 t15=t7*int_v_list003[0];
 t16=t15+t14;
@@ -233,7 +233,7 @@ t14=t15*t13;
 t20=t1*t28;
 t29=t20+t14;
 t14=t22*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t20=int_v_oo2zeta34*int_v_list000[0];
 t30=t20+t14;
 t14=t5*t13;
@@ -257,7 +257,7 @@ t34=t15*t16;
 t36=t22*int_v_list004[0];
 t22=int_v_oo2zeta34*int_v_list003[0];
 t37=t22+t36;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t22=t5*int_v_list005[0];
 t36=t7*int_v_list004[0];
 t38=t36+t22;
@@ -284,15 +284,15 @@ t36=t1*t23;
 t40=t36+t39;
 t36=t3*t20;
 t39=t36+t40;
-double***int_v_list2=int_v_list(2);
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t39;
 t36=t3*t39;
 t40=t36+t22;
-double***int_v_list3=int_v_list(3);
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[59]=t40;
 t22=int_v_W2-int_v_p342;
 t36=t22*int_v_list003[0];
