@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i2323eAB(){
+int sc::BuildIntV3::i2323eAB(){
 /* the cost is 2048 */
 double t1;
 double t2;
@@ -285,12 +285,12 @@ double t281;
 double t282;
 double t283;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_W0-int_v_p340;
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t4=t3*int_v_list004[0];
 t5=int_v_p340-int_v_r30;
 t6=t5*int_v_list003[0];
@@ -305,7 +305,7 @@ t11=int_v_zeta12*int_v_ooze;
 t12=int_v_oo2zeta34*t11;
 t11=(-1)*t12;
 t12=t11*int_v_list003[0];
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t13=int_v_oo2zeta34*int_v_list002[0];
 t14=t13+t12;
 t12=t3*t7;
@@ -321,7 +321,7 @@ t12=(-1)*t13;
 t13=t12*t15;
 t17=t13+t10;
 t10=t11*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t18=int_v_oo2zeta34*int_v_list001[0];
 t19=t18+t10;
 t10=t3*t16;
@@ -337,7 +337,7 @@ t17=t9*t7;
 t22=t11*int_v_list004[0];
 t23=int_v_oo2zeta34*int_v_list003[0];
 t24=t23+t22;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t22=t3*int_v_list005[0];
 t23=t5*int_v_list004[0];
 t25=t23+t22;
@@ -396,7 +396,7 @@ t40=t39+t38;
 t38=t11*int_v_list005[0];
 t39=int_v_oo2zeta34*int_v_list004[0];
 t41=t39+t38;
-double*int_v_list006=int_v_list00[6];
+double*restrictxx int_v_list006=int_v_list00[6];
 t38=t3*int_v_list006[0];
 t39=t5*int_v_list005[0];
 t42=t39+t38;
@@ -414,9 +414,9 @@ t36=t4*t39;
 t38=t36+t37;
 t36=t4*t38;
 t37=t36+t35;
-double***int_v_list3=int_v_list(3);
-double**int_v_list33=int_v_list3[3];
-double*int_v_list330=int_v_list33[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list33=int_v_list3[3];
+double*restrictxx int_v_list330=int_v_list33[0];
 int_v_list330[99]=t37;
 t35=int_v_W2-int_v_p342;
 t36=t35*int_v_list004[0];
@@ -1243,8 +1243,8 @@ t201=t6*t53;
 t53=t201+t25;
 t25=t191*t186;
 t201=t25+t53;
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[21]=t201;
 t25=t44*t201;
 t53=t25+t162;
@@ -2111,7 +2111,7 @@ t27=t12*t34;
 t34=t27+t6;
 t6=t28*t21;
 t49=t3*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t119=t5*int_v_list000[0];
 t164=t119+t49;
 t49=t30*t164;
@@ -2131,9 +2131,9 @@ t3=int_v_oo2zeta12*t5;
 t5=t3+t34;
 t6=t4*t31;
 t34=t6+t5;
-double***int_v_list2=int_v_list(2);
-double**int_v_list23=int_v_list2[3];
-double*int_v_list230=int_v_list23[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list23=int_v_list2[3];
+double*restrictxx int_v_list230=int_v_list23[0];
 int_v_list230[59]=t34;
 t5=t35*t22;
 t6=t1*int_v_list002[0];
@@ -2146,8 +2146,8 @@ t49=int_v_oo2zeta12*t119;
 t201=t49+t200;
 t200=t4*t130;
 t206=t200+t201;
-double**int_v_list22=int_v_list2[2];
-double*int_v_list220=int_v_list22[0];
+double**restrictxx int_v_list22=int_v_list2[2];
+double*restrictxx int_v_list220=int_v_list22[0];
 int_v_list220[35]=t206;
 t200=t44*t206;
 t201=t200+t5;
