@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i2333(){
+int sc::BuildIntV3::i2333(){
 /* the cost is 2387 */
 double t1;
 double t2;
@@ -266,12 +266,12 @@ double t262;
 double t263;
 double t264;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_W0-int_v_p340;
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t4=t3*int_v_list004[0];
 t5=int_v_p340-int_v_r30;
 t6=t5*int_v_list003[0];
@@ -280,7 +280,7 @@ t4=int_v_W0-int_v_p120;
 t6=t4*t7;
 t8=t6+t2;
 t6=t3*int_v_list003[0];
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t9=t5*int_v_list002[0];
 t10=t9+t6;
 t6=int_v_p120-int_v_r10;
@@ -305,7 +305,7 @@ t14=(-1)*t15;
 t15=t14*t17;
 t18=t15+t12;
 t12=t13*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t19=int_v_oo2zeta34*int_v_list001[0];
 t20=t19+t12;
 t12=t3*t10;
@@ -321,7 +321,7 @@ t18=t9*t7;
 t23=t13*int_v_list004[0];
 t24=int_v_oo2zeta34*int_v_list003[0];
 t25=t24+t23;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t23=t3*int_v_list005[0];
 t24=t5*int_v_list004[0];
 t26=t24+t23;
@@ -378,7 +378,7 @@ t18=t4*t35;
 t36=t18+t8;
 t8=t30*t22;
 t18=t3*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t37=t5*int_v_list000[0];
 t38=t37+t18;
 t18=t32*t38;
@@ -411,7 +411,7 @@ t46=t45+t44;
 t44=t13*int_v_list005[0];
 t45=int_v_oo2zeta34*int_v_list004[0];
 t47=t45+t44;
-double*int_v_list006=int_v_list00[6];
+double*restrictxx int_v_list006=int_v_list00[6];
 t44=t3*int_v_list006[0];
 t45=t5*int_v_list005[0];
 t48=t45+t44;
@@ -442,15 +442,15 @@ t45=t4*t31;
 t50=t45+t46;
 t45=t6*t18;
 t46=t45+t50;
-double***int_v_list2=int_v_list(2);
-double**int_v_list23=int_v_list2[3];
-double*int_v_list230=int_v_list23[0];
+double***restrictxx int_v_list2=int_v_list(2);
+double**restrictxx int_v_list23=int_v_list2[3];
+double*restrictxx int_v_list230=int_v_list23[0];
 int_v_list230[59]=t46;
 t45=t6*t46;
 t50=t45+t44;
-double***int_v_list3=int_v_list(3);
-double**int_v_list33=int_v_list3[3];
-double*int_v_list330=int_v_list33[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list33=int_v_list3[3];
+double*restrictxx int_v_list330=int_v_list33[0];
 int_v_list330[99]=t50;
 t44=int_v_W2-int_v_p342;
 t45=t44*int_v_list004[0];
