@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i3302(){
+int sc::BuildIntV3::i3302(){
 /* the cost is 1559 */
 double t1;
 double t2;
@@ -169,12 +169,12 @@ double t165;
 double t166;
 double t167;
 t1=int_v_W0-int_v_p120;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_p120-int_v_r10;
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t4=t3*int_v_list002[0];
 t5=t4+t2;
 t2=0.5*int_v_ooze;
@@ -190,13 +190,13 @@ t7=(-1)*t9;
 t9=t7*t10;
 t11=t9+t4;
 t12=t6*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t13=t8*int_v_list001[0];
 t14=t13+t12;
 t12=int_v_oo2zeta12*t14;
 t13=t12+t11;
 t11=t2*int_v_list003[0];
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t15=t6*int_v_list004[0];
 t16=t8*int_v_list003[0];
 t17=t16+t15;
@@ -247,7 +247,7 @@ t15=t16*t14;
 t21=t1*t29;
 t30=t21+t15;
 t15=t23*int_v_list001[0];
-double*int_v_list000=int_v_list00[0];
+double*restrictxx int_v_list000=int_v_list00[0];
 t21=int_v_oo2zeta34*int_v_list000[0];
 t31=t21+t15;
 t15=t6*t14;
@@ -271,7 +271,7 @@ t35=t16*t17;
 t37=t23*int_v_list004[0];
 t23=int_v_oo2zeta34*int_v_list003[0];
 t38=t23+t37;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t23=t6*int_v_list005[0];
 t37=t8*int_v_list004[0];
 t39=t37+t23;
@@ -300,9 +300,9 @@ t41=t3*t21;
 t42=t41+t43;
 t41=t3*t42;
 t43=t41+t37;
-double***int_v_list3=int_v_list(3);
-double**int_v_list32=int_v_list3[2];
-double*int_v_list320=int_v_list32[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list32=int_v_list3[2];
+double*restrictxx int_v_list320=int_v_list32[0];
 int_v_list320[59]=t43;
 t37=int_v_W2-int_v_p342;
 t41=t37*int_v_list003[0];
@@ -1004,8 +1004,8 @@ t86=t8*t126;
 t118=t86+t9;
 t9=t145*t118;
 t86=t9+t30;
-double**int_v_list31=int_v_list3[1];
-double*int_v_list310=int_v_list31[0];
+double**restrictxx int_v_list31=int_v_list3[1];
+double*restrictxx int_v_list310=int_v_list31[0];
 int_v_list310[11]=t86;
 t9=t44*t86;
 t30=t9+t39;
@@ -1777,8 +1777,8 @@ t2=t1*t74;
 t1=t2+t35;
 t2=t3*t76;
 t3=t2+t1;
-double**int_v_list30=int_v_list3[0];
-double*int_v_list300=int_v_list30[0];
+double**restrictxx int_v_list30=int_v_list3[0];
+double*restrictxx int_v_list300=int_v_list30[0];
 int_v_list300[9]=t3;
 t1=t138*t74;
 t2=t145*t76;
