@@ -1,5 +1,5 @@
 #include <chemistry/qc/oint3/build.h>
-int BuildIntV3::i3333eAB(){
+int sc::BuildIntV3::i3333eAB(){
 /* the cost is 1291 */
 double t1;
 double t2;
@@ -200,12 +200,12 @@ double t196;
 double t197;
 double t198;
 t1=0.5*int_v_ooze;
-double***int_v_list0=int_v_list(0);
-double**int_v_list00=int_v_list0[0];
-double*int_v_list003=int_v_list00[3];
+double***restrictxx int_v_list0=int_v_list(0);
+double**restrictxx int_v_list00=int_v_list0[0];
+double*restrictxx int_v_list003=int_v_list00[3];
 t2=t1*int_v_list003[0];
 t3=int_v_W0-int_v_p340;
-double*int_v_list004=int_v_list00[4];
+double*restrictxx int_v_list004=int_v_list00[4];
 t4=t3*int_v_list004[0];
 t5=int_v_p340-int_v_r30;
 t6=t5*int_v_list003[0];
@@ -220,7 +220,7 @@ t11=int_v_zeta12*int_v_ooze;
 t12=int_v_oo2zeta34*t11;
 t11=(-1)*t12;
 t12=t11*int_v_list003[0];
-double*int_v_list002=int_v_list00[2];
+double*restrictxx int_v_list002=int_v_list00[2];
 t13=int_v_oo2zeta34*int_v_list002[0];
 t14=t13+t12;
 t12=t3*t7;
@@ -236,7 +236,7 @@ t12=(-1)*t13;
 t13=t12*t15;
 t17=t13+t10;
 t10=t11*int_v_list002[0];
-double*int_v_list001=int_v_list00[1];
+double*restrictxx int_v_list001=int_v_list00[1];
 t18=int_v_oo2zeta34*int_v_list001[0];
 t19=t18+t10;
 t10=t3*t16;
@@ -252,7 +252,7 @@ t17=t9*t7;
 t22=t11*int_v_list004[0];
 t23=int_v_oo2zeta34*int_v_list003[0];
 t24=t23+t22;
-double*int_v_list005=int_v_list00[5];
+double*restrictxx int_v_list005=int_v_list00[5];
 t22=t3*int_v_list005[0];
 t23=t5*int_v_list004[0];
 t25=t23+t22;
@@ -311,7 +311,7 @@ t40=t39+t38;
 t38=t11*int_v_list005[0];
 t39=int_v_oo2zeta34*int_v_list004[0];
 t41=t39+t38;
-double*int_v_list006=int_v_list00[6];
+double*restrictxx int_v_list006=int_v_list00[6];
 t38=t3*int_v_list006[0];
 t39=t5*int_v_list005[0];
 t42=t39+t38;
@@ -329,9 +329,9 @@ t3=t4*t38;
 t36=t3+t37;
 t3=t4*t36;
 t37=t3+t35;
-double***int_v_list3=int_v_list(3);
-double**int_v_list33=int_v_list3[3];
-double*int_v_list330=int_v_list33[0];
+double***restrictxx int_v_list3=int_v_list(3);
+double**restrictxx int_v_list33=int_v_list3[3];
+double*restrictxx int_v_list330=int_v_list33[0];
 int_v_list330[99]=t37;
 t3=int_v_W2-int_v_p342;
 t35=t3*int_v_list004[0];
