@@ -56,7 +56,8 @@ class CLSCF: public SCF {
     /** The KeyVal constructor:
         <dl>
 
-        <dt><tt>total_charge</tt><dd> This integer gives the total charge
+        <dt><tt>total_charge</tt><dd> This floating point number
+        gives the total charge
         of the molecule.  The default is 0.
 
         <dt><tt>docc</tt><dd> This vector of integers gives the total
@@ -76,7 +77,12 @@ class CLSCF: public SCF {
     double occupation(int irrep, int vectornum);
 
     int n_fock_matrices() const;
-    RefSymmSCMatrix fock(int);
+    /** Returns closed-shell Fock matrix in AO basis (excluding XC contribution in KS DFT).
+	Use effective_fock() if you want the full KS Fock matrix.
+	Argument i must be 0.
+    */
+    RefSymmSCMatrix fock(int i);
+    /** Returns closed-shell Fock matrix in MO basis (including XC contribution for KS DFT). */
     RefSymmSCMatrix effective_fock();
 
     RefSymmSCMatrix density();
