@@ -49,6 +49,7 @@
 #include <chemistry/qc/scf/ossscf.h>
 
 using namespace std;
+using namespace sc;
 
 ///////////////////////////////////////////////////////////////////////////
 // OSSSCF
@@ -118,7 +119,7 @@ OSSSCF::OSSSCF(const Ref<KeyVal>& keyval) :
   } else {
     tndocc_ = (nelectrons-2)/2;
     if ((nelectrons-2)%2) {
-      ExEnv::err() << node0 << endl << indent
+      ExEnv::err0() << endl << indent
            << "OSSSCF::init: Warning, there's a leftover electron.\n"
            << incindent
            << indent << "total_charge = " << charge << endl
@@ -127,13 +128,13 @@ OSSSCF::OSSSCF(const Ref<KeyVal>& keyval) :
     }
   }
 
-  ExEnv::out() << node0 << endl << indent << "OSSSCF::init: total charge = "
+  ExEnv::out0() << endl << indent << "OSSSCF::init: total charge = "
        << Znuc-2*tndocc_-2 << endl << endl;
 
   nirrep_ = molecule()->point_group()->char_table().ncomp();
 
   if (nirrep_==1) {
-    ExEnv::err() << node0 << indent << "OSSSCF::init: cannot do C1 symmetry\n";
+    ExEnv::err0() << indent << "OSSSCF::init: cannot do C1 symmetry\n";
     abort();
   }
 
@@ -151,14 +152,14 @@ OSSSCF::OSSSCF(const Ref<KeyVal>& keyval) :
       else if (nsi && osb_<0)
         osb_=i;
       else if (nsi) {
-        ExEnv::err() << node0 << indent << "OSSSCF::init: too many open shells\n";
+        ExEnv::err0() << indent << "OSSSCF::init: too many open shells\n";
         abort();
       }
     }
     delete[] nsocc;
   }
   else if (ndocc_ && !nsocc || !ndocc_ && nsocc) {
-    ExEnv::out() << "ERROR: OSSSCF: only one of docc and socc specified: "
+    ExEnv::outn() << "ERROR: OSSSCF: only one of docc and socc specified: "
                  << "give both or none" << endl;
     abort();
   }
@@ -169,15 +170,15 @@ OSSSCF::OSSSCF(const Ref<KeyVal>& keyval) :
   }
 
   int i;
-  ExEnv::out() << node0 << indent << "docc = [";
+  ExEnv::out0() << indent << "docc = [";
   for (i=0; i < nirrep_; i++)
-    ExEnv::out() << node0 << " " << ndocc_[i];
-  ExEnv::out() << node0 << " ]\n";
+    ExEnv::out0() << " " << ndocc_[i];
+  ExEnv::out0() << " ]\n";
 
-  ExEnv::out() << node0 << indent << "socc = [";
+  ExEnv::out0() << indent << "socc = [";
   for (i=0; i < nirrep_; i++)
-    ExEnv::out() << node0 << " " << (i==osa_ || i==osb_) ? 1 : 0;
-  ExEnv::out() << node0 << " ]\n";
+    ExEnv::out0() << " " << (i==osa_ || i==osb_) ? 1 : 0;
+  ExEnv::out0() << " ]\n";
 
   // check to see if this was done in SCF(keyval)
   if (!keyval->exists("maxiter"))
@@ -256,7 +257,7 @@ RefSymmSCMatrix
 OSSSCF::fock(int n)
 {
   if (n > 2) {
-    ExEnv::err() << node0 << indent
+    ExEnv::err0() << indent
          << "OSSSCF::fock: there are only three fock matrices, "
          << scprintf("but fock(%d) was requested\n", n);
     abort();
@@ -282,17 +283,17 @@ OSSSCF::print(ostream&o) const
   int i;
   
   SCF::print(o);
-  o << node0 << indent << "OSSSCF Parameters:\n" << incindent
+  o << indent << "OSSSCF Parameters:\n" << incindent
     << indent << "ndocc = " << tndocc_ << endl
     << indent << "docc = [";
   for (i=0; i < nirrep_; i++)
-    o << node0 << " " << ndocc_[i];
-  o << node0 << " ]" << endl;
+    o << " " << ndocc_[i];
+  o << " ]" << endl;
 
-  o << node0 << indent << "socc = [";
+  o << indent << "socc = [";
   for (i=0; i < nirrep_; i++)
-    o << node0 << " " << (i==osa_ || i==osb_) ? 1 : 0;
-  o << node0 << " ]" << endl << decindent << endl;
+    o << " " << (i==osa_ || i==osb_) ? 1 : 0;
+  o << " ]" << endl << decindent << endl;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -401,7 +402,7 @@ OSSSCF::set_occupations(const RefDiagSCMatrix& ev)
     // test to see if newocc is different from ndocc_
     for (i=0; i < nirrep_; i++) {
       if (ndocc_[i] != newdocc[i]) {
-        ExEnv::err() << node0 << indent << "OSSSCF::set_occupations:  WARNING!!!!\n"
+        ExEnv::err0() << indent << "OSSSCF::set_occupations:  WARNING!!!!\n"
              << incindent << indent
              << scprintf("occupations for irrep %d have changed\n", i+1)
              << indent
@@ -409,7 +410,7 @@ OSSSCF::set_occupations(const RefDiagSCMatrix& ev)
              << endl << decindent;
       }
       if ((osa != osa_ && osa != osb_) || (osb != osb_ && osb != osa_)) {
-        ExEnv::err() << node0 << indent << "OSSSCF::set_occupations:  WARNING!!!!\n"
+        ExEnv::err0() << indent << "OSSSCF::set_occupations:  WARNING!!!!\n"
              << incindent << indent
              << "open shell occupations have changed"
              << endl << decindent;
