@@ -941,7 +941,7 @@ UnrestrictedSCF::extrap_error()
 ///////////////////////////////////////////////////////////////////////////
 
 double
-UnrestrictedSCF::compute_vector(double& eelec)
+UnrestrictedSCF::compute_vector(double& eelec, double nucrep)
 {
   tim_enter("vector");
   int i;
@@ -963,12 +963,6 @@ UnrestrictedSCF::compute_vector(double& eelec)
 
   // set up subclass for vector calculation
   init_vector();
-  
-  // calculate the nuclear repulsion energy
-  double nucrep = molecule()->nuclear_repulsion_energy();
-  ExEnv::out0() << indent
-       << scprintf("nuclear repulsion energy = %15.10f", nucrep)
-       << endl << endl;
 
   RefDiagSCMatrix evalsa(oso_dimension(), basis_matrixkit());
   RefDiagSCMatrix evalsb(oso_dimension(), basis_matrixkit());
@@ -976,6 +970,9 @@ UnrestrictedSCF::compute_vector(double& eelec)
   double delta = 1.0;
   int iter;
   
+  ExEnv::out0() << indent
+                << "Beginning iterations.  Basis is "
+                << basis()->label() << '.' << std::endl;
   for (iter=0; iter < maxiter_; iter++) {
     // form the density from the current vector 
     tim_enter("density");
@@ -1294,6 +1291,15 @@ UnrestrictedSCF::two_body_deriv_hf(double * tbgrad, double exchange_fraction)
   }
 }
 
+void
+UnrestrictedSCF::set_desired_value_accuracy(double eps)
+{
+  OneBodyWavefunction::set_desired_value_accuracy(eps);
+  oso_eigenvectors_beta_.set_desired_accuracy(eps);
+  eigenvalues_beta_.set_desired_accuracy(eps);
+}
+
+
 //////////////////////////////////////////////////////////////////////////////
 
 }
