@@ -59,7 +59,7 @@ class UnrestrictedSCF: public SCF {
   protected:
     Ref<SCExtrapError> extrap_error();
     // calculate the scf vector, returning the accuracy
-    double compute_vector(double&);
+    double compute_vector(double&, double enuclear);
     void initial_vector(int needv=1);
     
   public:
@@ -96,9 +96,19 @@ class UnrestrictedSCF: public SCF {
     void print(std::ostream&o=ExEnv::out0()) const;
 
     int n_fock_matrices() const;
-    RefSymmSCMatrix fock(int);
+    /** Returns alpha (i==0) or beta (i==1) Fock matrix in AO basis (including XC contribution in KS DFT --
+	compare this to CLSCF and HSOSSCF!). Argument i must be 0.
+    */
+    RefSymmSCMatrix fock(int i);
+    /** Spin-unrestricted SCF methods do not define effective Fock matrix,
+	thus this function should never be called. */
     RefSymmSCMatrix effective_fock();
     
+    /** Overload of Function::set_desired_value_accuracy(). Must update
+        accuracy of the eigenvalues and eigenvectors.
+    */
+    void set_desired_value_accuracy(double eps);
+    
   protected:
     // these are temporary data, so they should not be checkpointed
     Ref<TwoBodyInt> tbi_;
