@@ -35,12 +35,16 @@
 #define INLINE
 #endif
 
+namespace sc {
+
 INLINE double&
 Volume::interpolation_accuracy()
 {
   return _interp_acc;
 };
 
+}
+
 // Local Variables:
 // mode: c++
 // c-file-style: "CLJ"
