@@ -47,6 +47,7 @@ namespace sc {
 
 /** The QNewtonOpt implements a quasi-Newton optimization scheme. */
 class QNewtonOpt: public Optimize {
+
   protected:
     double maxabs_gradient;
     double accuracy_;
@@ -60,6 +61,12 @@ class QNewtonOpt: public Optimize {
     int print_hessian_;
     int print_x_;
     int print_gradient_;
+    int linear_;
+    int restrict_;
+    int dynamic_grad_acc_;
+    int force_search_;
+    int restart_;
+
   public:
     /** The KeyVal constructor.
         The KeyVal constructor reads the following keywords:
@@ -93,6 +100,9 @@ class QNewtonOpt: public Optimize {
         <dt><tt>print_hessian</tt><dd> If true, print the approximate
         hessian each iteration. The default is false.
 
+        <dt><tt>restrict</tt><dd> Use step size restriction when not
+        using a line search.  The default is true.
+
         </dl> */
     QNewtonOpt(const Ref<KeyVal>&);
     QNewtonOpt(StateIn&);
