@@ -449,6 +449,10 @@ SymmSCMatrix::SymmSCMatrix(const RefSCDimension&a, SCMatrixKit *kit):
 {
 }
 
+SymmSCMatrix::~SymmSCMatrix()
+{
+}
+
 void
 SymmSCMatrix::save(StateOut&s)
 {
@@ -801,6 +805,10 @@ DiagSCMatrix::DiagSCMatrix(const RefSCDimension&a, SCMatrixKit *kit):
 {
 }
 
+DiagSCMatrix::~DiagSCMatrix()
+{
+}
+
 void
 DiagSCMatrix::save(StateOut&s)
 {
