@@ -28,8 +28,6 @@
 #ifndef _math_scmat_linkage_h
 #define _math_scmat_linkage_h
 
-#ifndef __PIC__
-
 #include <math/scmat/repl.h>
 #include <math/scmat/dist.h>
 
@@ -42,6 +40,4 @@ static ForceLink<DistSCMatrixKit> math_scmat_force_link_b_;
 
 }
 
-#endif /* __PIC__ */
-
 #endif
