@@ -37,6 +37,7 @@
 #include <math/scmat/mops.h>
 
 using namespace std;
+using namespace sc;
 
 /////////////////////////////////////////////////////////////////////////////
 // LocalSymmSCMatrix member functions
@@ -70,7 +71,7 @@ int
 LocalSymmSCMatrix::compute_offset(int i,int j) const
 {
   if (i<0 || j<0 || i>=d->n() || j>=d->n()) {
-      ExEnv::err() << indent << "LocalSymmSCMatrix: index out of bounds\n";
+      ExEnv::errn() << indent << "LocalSymmSCMatrix: index out of bounds\n";
       abort();
     }
   return ij_offset(i,j);
@@ -120,7 +121,7 @@ LocalSymmSCMatrix::get_subblock(int br, int er, int bc, int ec)
   int nscol = ec-bc+1;
 
   if (nsrow > n() || nscol > n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::get_subblock: trying to get too big a "
          << "subblock (" << nsrow << "," << nscol
          << ") from (" << n() << "," << n() << ")\n";
@@ -149,7 +150,7 @@ LocalSymmSCMatrix::get_subblock(int br, int er)
   int nsrow = er-br+1;
 
   if (nsrow > n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::get_subblock: trying to get too big a "
          << "subblock (" << nsrow << "," << nsrow
          << ") from (" << n() << "," << n() << ")\n";
@@ -181,7 +182,7 @@ LocalSymmSCMatrix::assign_subblock(SCMatrix*sb, int br, int er, int bc, int ec)
   int nscol = ec-bc+1;
 
   if (nsrow > n() || nscol > n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::assign_subblock: trying to assign too big a "
          << "subblock (" << nsrow << "," << nscol
          << ") from (" << n() << "," << n() << ")\n";
@@ -202,7 +203,7 @@ LocalSymmSCMatrix::assign_subblock(SymmSCMatrix*sb, int br, int er)
   int nsrow = er-br+1;
 
   if (nsrow > n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::assign_subblock: trying to assign too big a "
          << "subblock (" << nsrow << "," << nsrow
          << ") from (" << n() << "," << n() << ")\n";
@@ -224,7 +225,7 @@ LocalSymmSCMatrix::accumulate_subblock(SCMatrix*sb, int br, int er, int bc, int
   int nscol = ec-bc+1;
 
   if (nsrow > n() || nscol > n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::accumulate_subblock: trying to "
          << "accumulate too big a "
          << "subblock (" << nsrow << "," << nscol
@@ -246,7 +247,7 @@ LocalSymmSCMatrix::accumulate_subblock(SymmSCMatrix*sb, int br, int er)
   int nsrow = er-br+1;
 
   if (nsrow > n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::accumulate_subblock: trying to "
          << "accumulate too big a "
          << "subblock (" << nsrow << "," << nsrow
@@ -263,7 +264,7 @@ SCVector *
 LocalSymmSCMatrix::get_row(int i)
 {
   if (i >= n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::get_row: trying to get invalid row "
          << i << " max " << n() << endl;
     abort();
@@ -284,14 +285,14 @@ void
 LocalSymmSCMatrix::assign_row(SCVector *v, int i)
 {
   if (i >= n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::assign_row: trying to assign invalid row "
          << i << " max " << n() << endl;
     abort();
   }
   
   if (v->n() != n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::assign_row: vector is wrong size "
          << "is " << v->n() << ", should be " << n() << endl;
     abort();
@@ -308,7 +309,7 @@ void
 LocalSymmSCMatrix::accumulate_row(SCVector *v, int i)
 {
   if (i >= n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::accumulate_row: trying to "
          << "accumulate invalid row "
          << i << " max " << n() << endl;
@@ -316,7 +317,7 @@ LocalSymmSCMatrix::accumulate_row(SCVector *v, int i)
   }
   
   if (v->n() != n()) {
-    ExEnv::err() << indent
+    ExEnv::errn() << indent
          << "LocalSymmSCMatrix::accumulate_row: vector is wrong size"
          << "is " << v->n() << ", should be " << n() << endl;
     abort();
@@ -338,7 +339,7 @@ LocalSymmSCMatrix::accumulate(const SymmSCMatrix*a)
 
   // make sure that the dimensions match
   if (!dim()->equiv(la->dim())) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSymmSCMatrix::accumulate(SCMatrix*a): "
            << "dimensions don't match\n";
       abort();
@@ -376,7 +377,7 @@ LocalSymmSCMatrix::solve_this(SCVector*v)
   
   // make sure that the dimensions match
   if (!dim()->equiv(lv->dim())) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSymmSCMatrix::solve_this(SCVector*v): "
            << "dimensions don't match\n";
       abort();
@@ -420,7 +421,7 @@ LocalSymmSCMatrix::diagonalize(DiagSCMatrix*a,SCMatrix*b)
 
   if (!dim()->equiv(la->dim()) ||
       !dim()->equiv(lb->coldim()) || !dim()->equiv(lb->rowdim())) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSymmSCMatrix::"
            << "diagonalize(DiagSCMatrix*a,SCMatrix*b): bad dims";
       abort();
@@ -458,7 +459,7 @@ LocalSymmSCMatrix::accumulate_symmetric_product(SCMatrix*a)
                                           "accumulate_symmetric_product");
 
   if (!dim()->equiv(la->rowdim())) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSymmSCMatrix::"
            << "accumulate_symmetric_product(SCMatrix*a): bad dim";
       abort();
@@ -477,7 +478,7 @@ LocalSymmSCMatrix::accumulate_symmetric_sum(SCMatrix*a)
                                           "accumulate_symmetric_sum");
 
   if (!dim()->equiv(la->rowdim()) || !dim()->equiv(la->coldim())) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSymmSCMatrix::"
            << "accumulate_symmetric_sum(SCMatrix*a): bad dim";
       abort();
@@ -502,7 +503,7 @@ LocalSymmSCMatrix::accumulate_symmetric_outer_product(SCVector*a)
                                       "accumulate_symmetric_outer_product");
 
   if (!dim()->equiv(la->dim())) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSymmSCMatrix::"
            << "accumulate_symmetric_outer_product(SCMatrix*a): bad dim";
       abort();
@@ -537,7 +538,7 @@ LocalSymmSCMatrix::accumulate_transform(SCMatrix*a,SymmSCMatrix*b,
   // check the dimensions
   if (t == SCMatrix::NormalTransform) {
     if (!dim()->equiv(la->rowdim()) || !lb->dim()->equiv(la->coldim())) {
-      ExEnv::err() << indent << "LocalSymmSCMatrix::accumulate_transform: bad dim\n";
+      ExEnv::errn() << indent << "LocalSymmSCMatrix::accumulate_transform: bad dim\n";
       abort();
     }
 
@@ -545,7 +546,7 @@ LocalSymmSCMatrix::accumulate_transform(SCMatrix*a,SymmSCMatrix*b,
     nr = la->nrow();
   } else {
     if (!dim()->equiv(la->coldim()) || !lb->dim()->equiv(la->rowdim())) {
-      ExEnv::err() << indent << "LocalSymmSCMatrix::accumulate_transform: bad dim\n";
+      ExEnv::errn() << indent << "LocalSymmSCMatrix::accumulate_transform: bad dim\n";
       abort();
     }
 
@@ -647,7 +648,7 @@ LocalSymmSCMatrix::accumulate_transform(SCMatrix*a,DiagSCMatrix*b,
 
   // check the dimensions
   if (!dim()->equiv(la->rowdim()) || !lb->dim()->equiv(la->coldim())) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSymmSCMatrix::accumulate_transform: bad dim\n";
       abort();
     }
@@ -670,7 +671,7 @@ LocalSymmSCMatrix::scalar_product(SCVector*a)
 
   // make sure that the dimensions match
   if (!dim()->equiv(la->dim())) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSCVector::scalar_product(SCVector*a): "
            << "dimensions don't match\n";
       abort();
@@ -702,7 +703,7 @@ LocalSymmSCMatrix::element_op(const Ref<SCElementOp2>& op,
       = require_dynamic_cast<LocalSymmSCMatrix*>(m,"LocalSymSCMatrix::element_op");
 
   if (!dim()->equiv(lm->dim())) {
-      ExEnv::err() << indent << "LocalSymmSCMatrix: bad element_op\n";
+      ExEnv::errn() << indent << "LocalSymmSCMatrix: bad element_op\n";
       abort();
     }
   op->process_spec_ltri(block.pointer(), lm->block.pointer());
@@ -718,7 +719,7 @@ LocalSymmSCMatrix::element_op(const Ref<SCElementOp3>& op,
       = require_dynamic_cast<LocalSymmSCMatrix*>(n,"LocalSymSCMatrix::element_op");
 
   if (!dim()->equiv(lm->dim()) || !dim()->equiv(ln->dim())) {
-      ExEnv::err() << indent << "LocalSymmSCMatrix: bad element_op\n";
+      ExEnv::errn() << indent << "LocalSymmSCMatrix: bad element_op\n";
       abort();
     }
   op->process_spec_ltri(block.pointer(),
@@ -741,12 +742,12 @@ LocalSymmSCMatrix::vprint(const char *title, ostream& os, int prec) const
   width = 75/(lwidth+SCFormIO::getindent(os));
 
   if (title)
-    os << node0 << endl << indent << title << endl;
+    os << endl << indent << title << endl;
   else
-    os << node0 << endl;
+    os << endl;
 
   if (n()==0) {
-    os << node0 << indent << "empty matrix\n";
+    os << indent << "empty matrix\n";
     return;
   }
 
@@ -756,19 +757,19 @@ LocalSymmSCMatrix::vprint(const char *title, ostream& os, int prec) const
     nn = (n() > kk) ? kk : n();
 
     // print column indices
-    os << node0 << indent;
+    os << indent;
     for (i=ii; i <= nn; i++)
-      os << node0 << scprintf("%*d",lwidth,i);
-    os << node0 << endl;
+      os << scprintf("%*d",lwidth,i);
+    os << endl;
 
     // print the rows
     for (i=ii-1; i < n() ; i++) {
-      os << node0 << indent << scprintf("%5d",i+1);
+      os << indent << scprintf("%5d",i+1);
       for (j=ii-1; j<nn && j<=i; j++)
-        os << node0 << scprintf("%*.*f",lwidth,prec,rows[i][j]);
-      os << node0 << endl;
+        os << scprintf("%*.*f",lwidth,prec,rows[i][j]);
+      os << endl;
     }
-    os << node0 << endl;
+    os << endl;
 
     if (n() <= kk) {
       os.flush();
@@ -782,7 +783,7 @@ Ref<SCMatrixSubblockIter>
 LocalSymmSCMatrix::local_blocks(SCMatrixSubblockIter::Access access)
 {
   if (messagegrp()->n() > 1) {
-      ExEnv::err() << indent
+      ExEnv::errn() << indent
            << "LocalSymmSCMatrix::local_blocks: not valid for local matrices"
            << endl;
       abort();
@@ -796,7 +797,7 @@ Ref<SCMatrixSubblockIter>
 LocalSymmSCMatrix::all_blocks(SCMatrixSubblockIter::Access access)
 {
   if (access == SCMatrixSubblockIter::Write) {
-      ExEnv::err() << indent << "LocalSymmSCMatrix::all_blocks: "
+      ExEnv::errn() << indent << "LocalSymmSCMatrix::all_blocks: "
            << "Write access permitted for local blocks only"
            << endl;
       abort();
