@@ -33,9 +33,12 @@
 #include <math/scmat/block.h>
 #include <math/scmat/blkiter.h>
 #include <math/scmat/matrix.h>
+#include <math/scmat/blocked.h>
 
 using namespace std;
 
+namespace sc {
+
 /////////////////////////////////////////////////////////////////////////////
 // SCDimension reference member functions
 
@@ -590,7 +593,7 @@ RefSCMatrix::restore(StateIn&s)
       pointer()->restore(s);
     }
   else if (have_matrix) {
-      ExEnv::err() << "RefSCMatrix::restore: matrix not properly initialized" << endl;
+      ExEnv::errn() << "RefSCMatrix::restore: matrix not properly initialized" << endl;
       abort();
     }
   else {
@@ -598,6 +601,22 @@ RefSCMatrix::restore(StateIn&s)
     }
 }
 
+int
+RefSCMatrix::nblock() const
+{
+  BlockedSCMatrix *b = dynamic_cast<BlockedSCMatrix*>(pointer());
+  if (b) return b->nblocks();
+  return 1;
+}
+
+RefSCMatrix
+RefSCMatrix::block(int i) const
+{
+  BlockedSCMatrix *b = dynamic_cast<BlockedSCMatrix*>(pointer());
+  if (b) return b->block(i);
+  return *this;
+}
+
 ///////////////////////////////////////////////////////////////////
 // RefSymmSCMatrix members
 
@@ -1113,7 +1132,7 @@ RefSymmSCMatrix::restore(StateIn&s)
       pointer()->restore(s);
     }
   else if (have_matrix) {
-      ExEnv::err() << "RefSymmSCMatrix::restore: "
+      ExEnv::errn() << "RefSymmSCMatrix::restore: "
            << "matrix not properly initialized" << endl;
       abort();
     }
@@ -1122,6 +1141,23 @@ RefSymmSCMatrix::restore(StateIn&s)
     }
 }
 
+int
+RefSymmSCMatrix::nblock() const
+{
+  BlockedSymmSCMatrix *b = dynamic_cast<BlockedSymmSCMatrix*>(pointer());
+  if (b) return b->nblocks();
+  return 1;
+}
+
+RefSymmSCMatrix
+RefSymmSCMatrix::block(int i) const
+{
+  BlockedSymmSCMatrix *b = dynamic_cast<BlockedSymmSCMatrix*>(pointer());
+  if (b) return b->block(i);
+  return *this;
+}
+
+
 ///////////////////////////////////////////////////////////////////
 // RefDiagSCMatrix members
 
@@ -1426,7 +1462,7 @@ RefDiagSCMatrix::restore(StateIn&s)
       pointer()->restore(s);
     }
   else if (have_matrix) {
-      ExEnv::err() << "RefDiagSCMatrix::restore: "
+      ExEnv::errn() << "RefDiagSCMatrix::restore: "
            << "matrix not properly initialized" << endl;
       abort();
     }
@@ -1435,6 +1471,22 @@ RefDiagSCMatrix::restore(StateIn&s)
     }
 }
 
+int
+RefDiagSCMatrix::nblock() const
+{
+  BlockedDiagSCMatrix *b = dynamic_cast<BlockedDiagSCMatrix*>(pointer());
+  if (b) return b->nblocks();
+  return 1;
+}
+
+RefDiagSCMatrix
+RefDiagSCMatrix::block(int i) const
+{
+  BlockedDiagSCMatrix *b = dynamic_cast<BlockedDiagSCMatrix*>(pointer());
+  if (b) return b->block(i);
+  return *this;
+}
+
 ///////////////////////////////////////////////////////////////////
 // RefSCVector members
 
@@ -1758,7 +1810,7 @@ RefSCVector::restore(StateIn&s)
       pointer()->restore(s);
     }
   else if (have_matrix) {
-      ExEnv::err() << "RefSCVector::restore: vector not properly initialized" << endl;
+      ExEnv::errn() << "RefSCVector::restore: vector not properly initialized" << endl;
       abort();
     }
   else {
@@ -1768,6 +1820,8 @@ RefSCVector::restore(StateIn&s)
 
 /////////////////////////////////////////////////////////////////////////////
 
+}
+
 // Local Variables:
 // mode: c++
 // c-file-style: "CLJ"
