@@ -60,6 +60,8 @@
 #include <util/keyval/keyval.h>
 #include <math/scmat/vector3.h>
 
+namespace sc {
+
 // //////////////////////////////////////////////////////////////////
 
 /** The SymmetryOperation class provides a 3 by 3 matrix
@@ -130,7 +132,7 @@ class SymmetryOperation {
     void transpose();
 
     /// print the matrix 
-    void print(std::ostream& =ExEnv::out()) const;
+    void print(std::ostream& =ExEnv::out0()) const;
 };
 
 // //////////////////////////////////////////////////////////////////
@@ -210,7 +212,7 @@ class SymRep {
     void c2_y();
 
     /// print the matrix 
-    void print(std::ostream& =ExEnv::out()) const;
+    void print(std::ostream& =ExEnv::out0()) const;
 };
 
 inline double
@@ -244,6 +246,7 @@ class IrreducibleRepresentation {
     int ntrans_;   // the number of translations in this irrep
     int complex_;  // true if this irrep has a complex representation
     char *symb;    // mulliken symbol for this irrep
+    char *csymb;    // mulliken symbol for this irrep w/o special characters
 
     SymRep *rep;   // representation matrices for the symops
 
@@ -253,14 +256,14 @@ class IrreducibleRepresentation {
     /** This constructor takes as arguments the order of the point group,
      the degeneracy of the irrep, and the Mulliken symbol of the irrep.
      The Mulliken symbol is copied internally. */
-    IrreducibleRepresentation(int,int,const char*);
+    IrreducibleRepresentation(int,int,const char*,const char* =0);
 
     ~IrreducibleRepresentation();
 
     IrreducibleRepresentation& operator=(const IrreducibleRepresentation&);
 
     /// Initialize the order, degeneracy, and Mulliken symbol of the irrep.
-    void init(int =0, int =0, const char* =0);
+    void init(int =0, int =0, const char* =0, const char* =0);
     
     /// Returns the order of the group.
     int order() const { return g; }
@@ -283,6 +286,11 @@ class IrreducibleRepresentation {
     /// Returns the Mulliken symbol for the irrep.
     const char * symbol() const { return symb; }
 
+    /** Returns the Mulliken symbol for the irrep without special
+        characters.
+    */
+    const char * symbol_ns() const { return (csymb?csymb:symb); }
+
     /** Returns the character for the i'th symmetry operation of the point
      group. */
     double character(int i) const {
@@ -302,7 +310,7 @@ class IrreducibleRepresentation {
     /** This prints the irrep to the given file, or stdout if none is
      given.  The second argument is an optional string of spaces to offset
      by. */
-    void print(std::ostream& =ExEnv::out()) const;
+    void print(std::ostream& =ExEnv::out0()) const;
 };
 
 // ///////////////////////////////////////////////////////////
@@ -413,7 +421,7 @@ class CharacterTable {
     }
     
     /// This prints the irrep to the given file, or stdout if none is given.
-    void print(std::ostream& =ExEnv::out()) const;
+    void print(std::ostream& =ExEnv::out0()) const;
 };
 
 // ///////////////////////////////////////////////////////////
@@ -505,9 +513,10 @@ class PointGroup: public SavableState {
 
     void save_data_state(StateOut& so);
 
-    void print(std::ostream&o=ExEnv::out()) const;
+    void print(std::ostream&o=ExEnv::out0()) const;
 };
 
+}
 
 #endif
 
