@@ -25,15 +25,11 @@
 // The U.S. Government is granted a limited license as per AL 91-7.
 //
 
-#include <math.h>
+#include <util/misc/math.h>
 
 #include <math/symmetry/pointgrp.h>
 #include <util/misc/formio.h>
 
-#ifndef M_PI
-#define M_PI 3.14159265358979323846
-#endif
-
 using namespace std;
 using namespace sc;
 
