@@ -44,6 +44,7 @@
 #include <util/misc/formio.h>
 
 #include <util/class/class.h>
+#include <util/class/proxy.h>
 
 using namespace std;
 using namespace sc;
@@ -55,6 +56,11 @@ std::set<std::string>* ClassDesc::unresolved_parents_ = 0;
 
 /////////////////////////////////////////////////////////////////
 
+static sc::ClassDesc DescribedClassProxy_cd(
+    typeid(sc::DescribedClassProxy), "DescribedClassProxy",1,"public DescribedClass");
+
+/////////////////////////////////////////////////////////////////
+
 ParentClass::ParentClass(ClassDesc*classdesc,Access access,int is_virtual):
   _access(access),
   _is_virtual(is_virtual),
@@ -232,7 +238,12 @@ ClassDesc::ClassDesc(const type_info &ti,
       abort();
     }
   else {
-      (*type_info_all_)[key] = this;
+      if (type_info_all_->find(key) == type_info_all_->end()) {
+          (*type_info_all_)[key] = this;
+        }
+      else {
+          // this should never happen
+        }
     }
 
   // test the version number to see if it is valid
@@ -241,7 +252,7 @@ ClassDesc::ClassDesc(const type_info &ti,
       exit(1);
     }
 
-  init(name,version,parents,ctor,keyvalctor,stateinctor);
+  init(name,version,parents,&ti,ctor,keyvalctor,stateinctor);
 }
 
 ClassDesc::ClassDesc(const char* name)
@@ -252,6 +263,7 @@ ClassDesc::ClassDesc(const char* name)
 void
 ClassDesc::init(const char* name, int version,
                 const char* parents,
+                const type_info *ti,
                 DescribedClass* (*ctor)(),
                 DescribedClass* (*keyvalctor)(const Ref<KeyVal>&),
                 DescribedClass* (*stateinctor)(StateIn&))
@@ -262,6 +274,7 @@ ClassDesc::init(const char* name, int version,
   ctor_ = ctor;
   keyvalctor_ = keyvalctor;
   stateinctor_ = stateinctor;
+  ti_ = ti;
 
   // make sure that the static members have been initialized
   if (!all_) {
@@ -362,6 +375,7 @@ ClassDesc::~ClassDesc()
   // delete this ClassDesc from the list of all ClassDesc's
   std::string key(classname_);
   all_->erase(key);
+
   // if the list of all ClassDesc's is empty, delete it
   if (all_->size() == 0) {
       delete all_;
@@ -370,6 +384,16 @@ ClassDesc::~ClassDesc()
       classlib_search_path_ = 0;
     }
 
+  // delete this ClassDesc entry from the type_info map
+  if (ti_ != 0) {
+      type_info_key key(ti_);
+      type_info_all_->erase(key);
+      if (type_info_all_->size() == 0) {
+          delete type_info_all_;
+          type_info_all_ = 0;
+        }
+    }
+
   // delete local data
   delete[] classname_;
   if (children_) delete children_;
@@ -603,9 +627,16 @@ DescribedClass::~DescribedClass()
 }
 
 ClassDesc*
-DescribedClass::class_desc() const
+DescribedClass::class_desc() const throw()
 {
-  return ClassDesc::class_desc(typeid(*this));
+  ClassDesc *cd;
+  try {
+      cd = ClassDesc::class_desc(typeid(*this));
+    }
+  catch (...) {
+      cd = 0;
+    }
+  return cd;
 }
 
 const char* DescribedClass::class_name() const
