@@ -44,6 +44,8 @@
 #  define eavl_typename typename
 #endif
 
+namespace sc {
+
 template <class K, class T>
 class EAVLMMapNode {
   public:
@@ -64,14 +66,6 @@ class EAVLMMap {
     T *start_;
     EAVLMMapNode<K,T> T::* node_;
   public:
-#if defined(__GNUC__) && defined(__alpha__)
-    T*& rlink(const T* n) const { T*& r = (n->*node_).rt; return r; }
-    T*& llink(const T* n) const { T*& r = (n->*node_).lt; return r; }
-    T*& uplink(const T* n) const { T*& r = (n->*node_).up; return r; }
-    int& balance(const T* n) const { int& r = (n->*node_).balance; return r; }
-    K& key(T* n) const { K& r = (n->*node_).key; return r; }
-    const K& key(const T* n) const { K& r = (n->*node_).key; return r; }
-#else    
     T*& rlink(T* n) const { return (n->*node_).rt; }
     T* rlink(const T* n) const { return (n->*node_).rt; }
     T*& llink(T* n) const { return (n->*node_).lt; }
@@ -82,9 +76,8 @@ class EAVLMMap {
     int balance(const T* n) const { return (n->*node_).balance; }
     K& key(T* n) const { return (n->*node_).key; }
     const K& key(const T* n) const { return (n->*node_).key; }
-#endif
-    int compare(T*n,T*m) const { return ::compare(key(n), key(m)); }
-    int compare(T*n,const K&m) const { return ::compare(key(n), m); }
+    int compare(T*n,T*m) const { return sc::compare(key(n), key(m)); }
+    int compare(T*n,const K&m) const { return sc::compare(key(n), m); }
   private:
     void adjust_balance_insert(T* A, T* child);
     void adjust_balance_remove(T* A, T* child);
@@ -197,7 +190,7 @@ EAVLMMap<K,T>::remove(T* node)
       next(r);
 
       if (r == 0 || llink(r) != 0) {
-          ExEnv::err() << "EAVLMMap::remove: inconsistency" << std::endl;
+          ExEnv::errn() << "EAVLMMap::remove: inconsistency" << std::endl;
           abort();
         }
 
@@ -252,11 +245,11 @@ EAVLMMap<K,T>::print()
 {
   for (T*n=start(); n; next(n)) {
       int d = depth(n) + 1;
-      for (int i=0; i<d; i++) ExEnv::out() << "     ";
-      if (balance(n) == 1) ExEnv::out() << " (+)" << std::endl;
-      else if (balance(n) == -1) ExEnv::out() << " (-)" << std::endl;
-      else if (balance(n) == 0) ExEnv::out() << " (.)" << std::endl;
-      else ExEnv::out() << " (" << balance(n) << ")" << std::endl;
+      for (int i=0; i<d; i++) ExEnv::out0() << "     ";
+      if (balance(n) == 1) ExEnv::out0() << " (+)" << std::endl;
+      else if (balance(n) == -1) ExEnv::out0() << " (-)" << std::endl;
+      else if (balance(n) == 0) ExEnv::out0() << " (.)" << std::endl;
+      else ExEnv::out0() << " (" << balance(n) << ")" << std::endl;
     }
 }
 
@@ -316,7 +309,7 @@ EAVLMMap<K,T>::check()
   for (node = start(); node; next(node)) {
       check_node(node);
       if (prev && compare(prev,node) > 0) {
-          ExEnv::err() << "nodes out of order" << std::endl;
+          ExEnv::errn() << "nodes out of order" << std::endl;
           abort();
         }
       prev = node;
@@ -324,16 +317,16 @@ EAVLMMap<K,T>::check()
     }
   for (node = start(); node; next(node)) {
       if (balance(node) != height(rlink(node)) - height(llink(node))) {
-          ExEnv::err() << "balance inconsistency" << std::endl;
+          ExEnv::errn() << "balance inconsistency" << std::endl;
           abort();
         }
       if (balance(node) < -1 || balance(node) > 1) {
-          ExEnv::err() << "balance out of range" << std::endl;
+          ExEnv::errn() << "balance out of range" << std::endl;
           abort();
         }
     }
   if (length_ != computed_length) {
-      ExEnv::err() << "length error" << std::endl;
+      ExEnv::errn() << "length error" << std::endl;
       abort();
     }
 }
@@ -719,6 +712,8 @@ EAVLMMap<K,T>::initialize(EAVLMMapNode<K,T> T::* node)
   length_ = 0;
 }
 
+}
+
 #endif
 
 // ///////////////////////////////////////////////////////////////////////////
