@@ -28,8 +28,6 @@
 #ifndef _util_group_linkage_h
 #define _util_group_linkage_h
 
-#ifndef __PIC__
-
 #ifdef HAVE_CONFIG_H
 #include <scconfig.h>
 #endif
@@ -69,7 +67,4 @@ namespace sc {
 }
 #endif
 
-#endif /* __PIC__ */
-
-
 #endif
