@@ -64,6 +64,85 @@ ParallelRegionTimer::~ParallelRegionTimer()
 {
 }
 
+static void
+send_string(const Ref<MessageGrp>& msg, int node, const char *s)
+{
+  int l = strlen(s);
+  msg->send(node, l);
+  msg->send(node, s, l);
+}
+
+static char *
+recv_string(const Ref<MessageGrp>& msg, int node)
+{
+  int l;
+  msg->recv(node, l);
+  char *s = new char[l+1];
+  s[l] = '\0';
+  msg->recv(node, s, l);
+  return s;
+}
+
+void
+ParallelRegionTimer::send_subregions(int node, const TimedRegion *r) const
+{
+  TimedRegion *subr = r->subregions();
+
+  // rewind to the beginning
+  if (subr) { while (subr->prev()) subr = subr->prev(); }
+
+  while (subr) {
+      msg_->send(node, 1);
+      send_string(msg_, node, subr->name());
+      send_subregions(node, subr);
+      subr = subr->next();
+    };
+
+  msg_->send(node, 0);
+}
+
+void
+ParallelRegionTimer::recv_subregions(int node, TimedRegion *r) const
+{
+  int has_subregions;
+  msg_->recv(node, has_subregions);
+  while (has_subregions) {
+      char *name = recv_string(msg_, node);
+      TimedRegion *region = r->findinsubregion(name);
+      delete[] name;
+      recv_subregions(node, region);
+      msg_->recv(node, has_subregions);
+    }
+}
+
+void
+ParallelRegionTimer::all_reduce_regions() const
+{
+  Ref<MachineTopology> topology = msg_->topology();
+
+  // accumulate all the regions onto node zero
+  Ref<GlobalMsgIter> i_reduce(topology->global_msg_iter(msg_, 0));
+  for (i_reduce->backwards(); !i_reduce->done(); i_reduce->next()) {
+      if (i_reduce->send()) {
+          send_subregions(i_reduce->sendto(), top_);
+        }
+      if (i_reduce->recv()) {
+          recv_subregions(i_reduce->recvfrom(), top_);
+        }
+    }
+
+  // broadcast the regions to all the nodes
+  Ref<GlobalMsgIter> i_bcast(topology->global_msg_iter(msg_, 0));
+  for (i_bcast->forwards(); !i_bcast->done(); i_bcast->next()) {
+      if (i_bcast->send()) {
+          send_subregions(i_bcast->sendto(), top_);
+        }
+      if (i_bcast->recv()) {
+          recv_subregions(i_bcast->recvfrom(), top_);
+        }
+    }
+}
+
 void
 ParallelRegionTimer::print(ostream &o) const
 {
@@ -76,20 +155,11 @@ ParallelRegionTimer::print(ostream &o) const
 
   update_top();
 
+  // make sure all the nodes have the same regions
+  all_reduce_regions();
+
   int n = nregion();
 
-  int minn = n;
-  int maxn = n;
-  msg_->max(maxn);
-  msg_->min(minn);
-
-  if (maxn != minn) {
-      ExEnv::err0()
-           << "ParallelRegionTimer::print: differing number of regions"
-           << endl;
-      abort();
-    }
-
   double *cpu_time = 0;
   double *wall_time = 0;
   double *flops = 0;
