@@ -41,6 +41,11 @@ namespace sc {
 class ParallelRegionTimer: public RegionTimer {
   protected:
     Ref<MessageGrp> msg_;
+
+    void send_subregions(int node, const TimedRegion *r) const;
+    void recv_subregions(int node, TimedRegion *r) const;
+    void all_reduce_regions() const;
+
   public:
     ParallelRegionTimer(const Ref<MessageGrp>&,
                         const char *topname = "total",
