@@ -301,7 +301,12 @@ KeyValValuepchar::stringvalue(std::string&val) const
 void
 KeyValValuepchar::print(ostream&o) const
 {
-  o << _val;
+  if (_val == 0) {
+      o << "(null)";
+    }
+  else {
+      o << _val;
+    }
 }
 
 /////////////////////////////////////////////////////////////////////////
@@ -473,11 +478,11 @@ KeyValValueString::sizevalue(size_t&val) const
   int gotdigit = 0;
   int gotdecimal = 0;
   int denom = 1;
-  val = 0;
+  double dval = 0;
   for (int i=0; i<n; i++) {
       if (isdigit(_val[i]) && !gotdigitspace) {
           char tmp[2]; tmp[0] = _val[i]; tmp[1] = '\0';
-          val = val * 10 + atoi(tmp);
+          dval = dval * 10 + atoi(tmp);
           gotdigit = 1;
           if (gotdecimal) denom *= 10;
         }
@@ -487,28 +492,31 @@ KeyValValueString::sizevalue(size_t&val) const
       else if (_val[i] == ' ') {
           if (gotdigit) gotdigitspace = 1;
         }
-      else if (strcmp(&_val[i],"KIB") == 0) {
-          val *= 1024;
+      else if (strcmp(&_val[i],"KIB") == 0
+               || strcmp(&_val[i],"KiB") == 0) {
+          dval *= 1024;
           i+=2;
         }
-      else if (strcmp(&_val[i],"MIB") == 0) {
-          val *= 1048576;
+      else if (strcmp(&_val[i],"MIB") == 0
+               || strcmp(&_val[i],"MiB") == 0) {
+          dval *= 1048576;
           i+=2;
         }
-      else if (strcmp(&_val[i],"GIB") == 0) {
-          val *= 1073741824;
+      else if (strcmp(&_val[i],"GIB") == 0
+               ||strcmp(&_val[i],"GiB") == 0) {
+          dval *= 1073741824;
           i+=2;
         }
       else if (strcmp(&_val[i],"KB") == 0) {
-          val *= 1000;
+          dval *= 1000;
           i++;
         }
       else if (strcmp(&_val[i],"MB") == 0) {
-          val *= 1000000;
+          dval *= 1000000;
           i++;
         }
       else if (strcmp(&_val[i],"GB") == 0) {
-          val *= 1000000000;
+          dval *= 1000000000;
           i++;
         }
       else {
@@ -516,7 +524,8 @@ KeyValValueString::sizevalue(size_t&val) const
           return KeyValValue::WrongType;
         }
     }
-  val /= denom;
+  dval /= denom;
+  val = size_t(dval);
   return KeyValValue::OK;
 }
 KeyValValue::KeyValValueError
