@@ -28,14 +28,10 @@
 #ifndef _util_misc_ieee_h
 #define _util_misc_ieee_h
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace sc {
 
 void ieee_trap_errors();
 
-#ifdef __cplusplus
-};
-#endif
+}
 
 #endif
