@@ -33,6 +33,8 @@
 #  include <scconfig.h>
 #endif
 
+#include <stdexcept>
+
 #include <math.h>
 #include <iostream>
 #include <iomanip>
@@ -85,52 +87,13 @@ int getrusage (
 #include <util/keyval/keyval.h>
 #include <util/misc/regtime.h>
 #include <util/misc/timer.h>
+#include <util/class/scexception.h>
 
 using namespace std;
 using namespace sc;
 
 namespace sc {
 
-class TimedRegion {
-  private:
-    char *name_;
-    TimedRegion *up_;
-    TimedRegion *subregions_;
-    TimedRegion *next_;
-    TimedRegion *prev_;
-    double cpu_time_;
-    double wall_time_;
-    double cpu_enter_;
-    double wall_enter_;
-    double flops_;
-    double flops_enter_;
-
-    TimedRegion *insert_after(const char *name);
-    TimedRegion *insert_before(const char *name);
-  public:
-    TimedRegion(const char *name);
-    ~TimedRegion();
-    const char *name() const { return name_; }
-    TimedRegion *findinsubregion(const char *);
-    void cpu_enter(double);
-    void wall_enter(double);
-    void flops_enter(double);
-    void cpu_exit(double);
-    void wall_exit(double);
-    void flops_exit(double);
-    void cpu_add(double t) { cpu_time_ += t; }
-    void wall_add(double t) { wall_time_ += t; }
-    void flops_add(double t) { flops_ += t; }
-    TimedRegion *up() const { return up_; }
-
-    int nregion();
-    void get_region_names(const char *names[]);
-    void get_wall_times(double *);
-    void get_cpu_times(double *);
-    void get_flops(double *);
-    void get_depth(int *, int depth = 0);
-};
-
 //////////////////////////////////////////////////////////////////////
 
 TimedRegion::TimedRegion(const char *name)
@@ -427,22 +390,30 @@ RegionTimer::enter(const char *name)
 }
 
 void
-RegionTimer::exit(const char *name)
+RegionTimer::exit(const char *name, bool do_not_throw)
 {
   if (!current_ || (name && strcmp(name, current_->name()))) {
-      ExEnv::errn() << "TimeRegion::exit(\"" << name << "\"):"
-           << " current region"
-           << " (\"" << current_->name() << "\")"
-           << " doesn't match name"
-           << endl;
-      abort();
+      if (do_not_throw) {
+          // we have an error but cannot throw.  ignore this call
+          return;
+        }
+      else {
+          throw ProgrammingError("region mismatch",
+                                 __FILE__, __LINE__, this->class_desc());
+        }
     }
   if (cpu_time_) current_->cpu_exit(get_cpu_time());
   if (wall_time_) current_->wall_exit(get_wall_time());
   if (flops_) current_->flops_exit(get_flops());
   if (! current_->up()) {
-      ExEnv::errn() << "RegionTimer::exit: already at top level" << endl;
-      abort();
+      if (do_not_throw) {
+          // we have an error but cannot throw.  ignore this call
+          return;
+        }
+      else {
+          throw ProgrammingError("tried to exit top level",
+                                 __FILE__, __LINE__, this->class_desc());
+        }
     }
   current_ = current_->up();
 }
@@ -726,7 +697,7 @@ Timer::Timer(const Ref<RegionTimer>&t, const char *name):
 Timer::~Timer()
 {
   if (active_) {
-      timer_->exit(name_.c_str());
+      timer_->exit(name_.c_str(), true);
     }
 }
 
