@@ -28,8 +28,6 @@
 #ifndef _util_render_linkage_h
 #define _util_render_linkage_h
 
-#ifndef __PIC__
-
 #include <util/render/oogl.h>
 #include <util/render/sphere.h>
 #include <util/render/polylines.h>
@@ -47,6 +45,4 @@ static ForceLink<Transform> render_force_link_f_;
 
 }
 
-#endif /* __PIC__ */
-
 #endif
