@@ -28,8 +28,6 @@
 #ifndef _util_state_linkage_h
 #define _util_state_linkage_h
 
-#ifndef __PIC__
-
 #include <util/state/proxy.h>
 
 namespace sc {
@@ -38,6 +36,4 @@ static ForceLink<SavableStateProxy,const Ref<KeyVal> &> state_force_link_a_;
 
 }
 
-#endif /* __PIC__ */
-
 #endif
