@@ -29,7 +29,6 @@
 #pragma implementation
 #endif
 
-#include <stdexcept>
 #include <limits.h>
 
 #include <scconfig.h>
@@ -46,6 +45,7 @@
 #include <sys/types.h>
 #endif
 
+#include <util/class/scexception.h>
 #include <util/state/translate.h>
 #include <util/state/stateout.h>
 
@@ -143,13 +143,16 @@ StateOut::put_array_double(const double*p,int size)
 
 int StateOut::put(char r) { return put_array_char(&r,1); }
 int StateOut::put(unsigned int r) { return put_array_uint(&r,1); }
+int StateOut::put(bool r) { return put(int(r)); }
 int StateOut::put(int r) { return put_array_int(&r,1); }
 int StateOut::put(float r) { return put_array_float(&r,1); }
 int StateOut::put(double r) { return put_array_double(&r,1); }
 int StateOut::put(unsigned long r)
 {
   if (r > INT_MAX) {
-      throw std::runtime_error("StateOut::put max allowed size exceeded");
+      throw LimitExceeded<unsigned long>(
+          "StateOut::put max allowed size exceeded",
+          __FILE__, __LINE__, INT_MAX, r);
     }
   return put(int(r));
 }
